@@ -11,7 +11,7 @@ module HieraPuppet
     answer = hiera.lookup(key, default, scope, override, resolution_type)
 
     if answer.nil?
-      raise(Puppet::ParseError, "Could not find data item #{key} in any Hiera data file and no default supplied")
+      raise Puppet::ParseError, _("Could not find data item %{key} in any Hiera data file and no default supplied") % { key: key }
     end
 
     answer
@@ -38,7 +38,7 @@ module HieraPuppet
     end
 
     if args.empty?
-      raise(Puppet::ParseError, "Please supply a parameter to perform a Hiera lookup")
+      raise Puppet::ParseError, _("Please supply a parameter to perform a Hiera lookup")
     end
 
     key      = args[0]
@@ -67,21 +67,13 @@ module HieraPuppet
   end
 
   def hiera_config_file
-    config_file = nil
-
-    if Puppet.settings[:hiera_config].is_a?(String)
-      expanded_config_file = File.expand_path(Puppet.settings[:hiera_config])
-      if Puppet::FileSystem.exist?(expanded_config_file)
-        config_file = expanded_config_file
-      end
-    elsif Puppet.settings[:confdir].is_a?(String)
-      expanded_config_file = File.expand_path(File.join(Puppet.settings[:confdir], '/hiera.yaml'))
-      if Puppet::FileSystem.exist?(expanded_config_file)
-        config_file = expanded_config_file
-      end
+    hiera_config = Puppet.settings[:hiera_config]
+    if Puppet::FileSystem.exist?(hiera_config)
+      hiera_config
+    else
+      Puppet.warning _("Config file %{hiera_config} not found, using Hiera defaults") % { hiera_config: hiera_config }
+      nil
     end
-
-    config_file
   end
 end
 
