@@ -1,8 +1,8 @@
 require 'optparse'
 require 'puppet/util/command_line'
-require 'puppet/util/plugins'
 require 'puppet/util/constant_inflector'
 require 'puppet/error'
+require 'puppet/application_support'
 
 module Puppet
 
@@ -75,7 +75,7 @@ module Puppet
 # Refer to +OptionParser+ documentation for the exact format.
 # * If the option method is given a block, this one will be called whenever
 # the option is encountered in the command-line argument.
-# * If the option method has no block, a default functionnality will be used, that
+# * If the option method has no block, a default functionality will be used, that
 # stores the argument (or true/false if the option doesn't require an argument) in
 # the global (to the application) options array.
 # * If a given option was not defined by a the +option+ method, but it exists as a Puppet settings:
@@ -83,7 +83,7 @@ module Puppet
 #  * if +unknown+ wasn't used, then the option/argument is handed to Puppet.settings.handlearg for
 #    a default behavior
 #
-# --help is managed directly by the Puppet::Application class, but can be overriden.
+# --help is managed directly by the Puppet::Application class, but can be overridden.
 #
 # === Setup
 # Applications can use the setup block to perform any initialization.
@@ -181,23 +181,6 @@ class Application
       result
     end
 
-    SHOULD_PARSE_CONFIG_DEPRECATION_MSG = "is no longer supported; config file parsing " +
-        "is now controlled by the puppet engine, rather than by individual applications.  This " +
-        "method will be removed in a future version of puppet."
-
-    def should_parse_config
-      Puppet.deprecation_warning("should_parse_config " + SHOULD_PARSE_CONFIG_DEPRECATION_MSG)
-    end
-
-    def should_not_parse_config
-      Puppet.deprecation_warning("should_not_parse_config " + SHOULD_PARSE_CONFIG_DEPRECATION_MSG)
-    end
-
-    def should_parse_config?
-      Puppet.deprecation_warning("should_parse_config? " + SHOULD_PARSE_CONFIG_DEPRECATION_MSG)
-      true
-    end
-
     # used to declare code that handle an option
     def option(*options, &block)
       long = options.find { |opt| opt =~ /^--/ }.gsub(/^--(?:\[no-\])?([^ =]+).*$/, '\1' ).gsub('-','_')
@@ -245,7 +228,7 @@ class Application
       begin
         require @loader.expand(application_name.to_s.downcase)
       rescue LoadError => e
-        Puppet.log_and_raise(e, "Unable to find application '#{application_name}'. #{e}")
+        Puppet.log_and_raise(e, _("Unable to find application '%{application_name}'. %{error}") % { application_name: application_name, error: e })
       end
 
       class_name = Puppet::Util::ConstantInflector.file2constant(application_name.to_s)
@@ -266,7 +249,7 @@ class Application
       ################################################################
 
       if clazz.nil?
-        raise Puppet::Error.new("Unable to load application class '#{class_name}' from file 'puppet/application/#{application_name}.rb'")
+        raise Puppet::Error.new(_("Unable to load application class '%{class_name}' from file 'puppet/application/%{application_name}.rb'") % { class_name: class_name, application_name: application_name })
       end
 
       return clazz
@@ -298,6 +281,23 @@ class Application
       @run_mode = Puppet::Util::RunMode[ mode_name || Puppet.settings.preferred_run_mode ]
     end
 
+    # Sets environment_mode name
+    # @param mode_name [Symbol] The name of the environment mode to run in. May
+    #   be one of :local, :remote, or :not_required. This impacts where the
+    #   application looks for its specified environment. If :not_required or
+    #   :remote are set, the application will not fail if the environment does
+    #   not exist on the local filesystem.
+    def environment_mode(mode_name)
+      raise Puppet::Error, _("Invalid environment mode '%{mode_name}'") % { mode_name: mode_name } unless [:local, :remote, :not_required].include?(mode_name)
+      @environment_mode = mode_name
+    end
+
+    # Gets environment_mode name. If none is set with `environment_mode=`,
+    # default to :local.
+    def get_environment_mode
+      @environment_mode || :local
+    end
+
     # This is for testing only
     def clear_everything_for_tests
       @run_mode = @banner = @run_status = @option_parser_commands = nil
@@ -339,50 +339,44 @@ class Application
     @options = {}
   end
 
+  # call in setup of subclass to deprecate an application
+  def deprecate
+    @deprecated = true
+  end
+
+  def deprecated?
+    @deprecated
+  end
+
   # Execute the application.
   # @api public
   # @return [void]
   def run
 
     # I don't really like the names of these lifecycle phases.  It would be nice to change them to some more meaningful
-    # names, and make deprecated aliases.  Also, Daniel suggests that we can probably get rid of this "plugin_hook"
-    # pattern, but we need to check with PE and the community first.  --cprice 2012-03-16
-    #
+    # names, and make deprecated aliases.  --cprice 2012-03-16
 
-    exit_on_fail("get application-specific default settings") do
-      plugin_hook('initialize_app_defaults') { initialize_app_defaults }
+    exit_on_fail(_("Could not get application-specific default settings")) do
+      initialize_app_defaults
     end
 
-    Puppet.push_context(Puppet.base_context(Puppet.settings), "Update for application settings (#{self.class.run_mode})")
-    # This use of configured environment is correct, this is used to establish
-    # the defaults for an application that does not override, or where an override
-    # has not been made from the command line.
-    #
-    configured_environment_name = Puppet[:environment]
-    if self.class.run_mode.name == :agent
-      configured_environment = Puppet::Node::Environment.remote(configured_environment_name)
-    else
-      configured_environment = Puppet.lookup(:environments).get!(configured_environment_name)
+    Puppet::ApplicationSupport.push_application_context(self.class.run_mode, self.class.get_environment_mode)
+
+    exit_on_fail(_("Could not initialize"))                { preinit }
+    exit_on_fail(_("Could not parse application options")) { parse_options }
+    exit_on_fail(_("Could not prepare for execution"))     { setup }
+
+    if deprecated?
+      Puppet.deprecation_warning(_("`puppet %{name}` is deprecated and will be removed in a future release.") % { name: name })
     end
-    configured_environment = configured_environment.override_from_commandline(Puppet.settings)
 
-    # Setup a new context using the app's configuration
-    Puppet.push_context({ :current_environment => configured_environment },
-                    "Update current environment from application's configuration")
-
-    require 'puppet/util/instrumentation'
-    Puppet::Util::Instrumentation.init
-
-    exit_on_fail("initialize")                                   { plugin_hook('preinit')       { preinit } }
-    exit_on_fail("parse application options")                    { plugin_hook('parse_options') { parse_options } }
-    exit_on_fail("prepare for execution")                        { plugin_hook('setup')         { setup } }
-    exit_on_fail("configure routes from #{Puppet[:route_file]}") { configure_indirector_routes }
-    exit_on_fail("log runtime debug info")                       { log_runtime_environment }
-    exit_on_fail("run")                                          { plugin_hook('run_command')   { run_command } }
+    exit_on_fail(_("Could not configure routes from %{route_file}") % { route_file: Puppet[:route_file] }) { configure_indirector_routes }
+    exit_on_fail(_("Could not log runtime debug info"))                       { log_runtime_environment }
+    exit_on_fail(_("Could not run"))                                          { run_command }
   end
 
   def main
-    raise NotImplementedError, "No valid command or main"
+    raise NotImplementedError, _("No valid command or main")
   end
 
   def run_command
@@ -394,8 +388,10 @@ class Application
   end
 
   def setup_logs
-    if options[:debug] || options[:verbose]
-      Puppet::Util::Log.newdestination(:console)
+    unless options[:setdest]
+      if options[:debug] || options[:verbose]
+        Puppet::Util::Log.newdestination(:console)
+      end
     end
 
     set_log_level
@@ -403,10 +399,11 @@ class Application
     Puppet::Util::Log.setup_default unless options[:setdest]
   end
 
-  def set_log_level
-    if options[:debug]
+  def set_log_level(opts = nil)
+    opts ||= options
+    if opts[:debug]
       Puppet::Util::Log.level = :debug
-    elsif options[:verbose]
+    elsif opts[:verbose] && !Puppet::Util::Log.sendlevel?(:info)
       Puppet::Util::Log.level = :info
     end
   end
@@ -421,12 +418,7 @@ class Application
   end
 
   def configure_indirector_routes
-    route_file = Puppet[:route_file]
-    if Puppet::FileSystem.exist?(route_file)
-      routes = YAML.load_file(route_file)
-      application_routes = routes[name.to_s]
-      Puppet::Indirector.configure_routes(application_routes) if application_routes
-    end
+    Puppet::ApplicationSupport.configure_indirector_routes(name.to_s)
   end
 
   # Output basic information about the runtime environment for debugging
@@ -443,7 +435,7 @@ class Application
       'ruby_version'   => RUBY_VERSION,
       'run_mode'       => self.class.run_mode.name,
     }
-    runtime_info['default_encoding'] = Encoding.default_external if RUBY_VERSION >= '1.9.3'
+    runtime_info['default_encoding'] = Encoding.default_external
     runtime_info.merge!(extra_info) unless extra_info.nil?
 
     Puppet.debug 'Runtime environment: ' + runtime_info.map{|k,v| k + '=' + v.to_s}.join(', ')
@@ -497,17 +489,14 @@ class Application
   end
 
   def help
-    "No help available for puppet #{name}"
+    _("No help available for puppet %{app_name}") % { app_name: name }
   end
 
-
-
-  def plugin_hook(step,&block)
-    Puppet::Plugins.send("before_application_#{step}",:application_object => self)
-    x = yield
-    Puppet::Plugins.send("after_application_#{step}",:application_object => self, :return_value => x)
-    x
+  # The description used in top level `puppet help` output
+  # If left empty in implementations, we will attempt to extract
+  # the summary from the help text itself.
+  def summary
+    ""
   end
-  private :plugin_hook
 end
 end
