@@ -21,7 +21,7 @@ class Puppet::Application::Agent < Puppet::Application
   def preinit
     # Do an initial trap, so that cancels don't get a stack trace.
     Signal.trap(:INT) do
-      $stderr.puts "Cancelling startup"
+      $stderr.puts _("Cancelling startup")
       exit(0)
     end
 
@@ -38,6 +38,7 @@ class Puppet::Application::Agent < Puppet::Application
       :digest => 'SHA256',
       :graph => true,
       :fingerprint => false,
+      :sourceaddress => nil,
     }.each do |opt,val|
       options[opt] = val
     end
@@ -59,6 +60,8 @@ class Puppet::Application::Agent < Puppet::Application
   option("--fingerprint")
   option("--digest DIGEST")
 
+  option("--sourceaddress IP_ADDRESS")
+
   option("--detailed-exitcodes") do |arg|
     options[:detailed_exitcodes] = true
   end
@@ -71,10 +74,18 @@ class Puppet::Application::Agent < Puppet::Application
     options[:waitforcert] = arg.to_i
   end
 
-  def help
-    <<-'HELP'
+  option("--job-id ID") do |arg|
+    options[:job_id] = arg
+  end
 
-puppet-agent(8) -- The puppet agent daemon
+  def summary
+    _("The puppet agent daemon")
+  end
+
+  def help
+    <<-HELP
+
+puppet-agent(8) -- #{summary}
 ========
 
 SYNOPSIS
@@ -90,8 +101,8 @@ USAGE
 -----
 puppet agent [--certname <NAME>] [-D|--daemonize|--no-daemonize]
   [-d|--debug] [--detailed-exitcodes] [--digest <DIGEST>] [--disable [MESSAGE]] [--enable]
-  [--fingerprint] [-h|--help] [-l|--logdest syslog|eventlog|<FILE>|console]
-  [--masterport <PORT>] [--noop] [-o|--onetime] [-t|--test]
+  [--fingerprint] [-h|--help] [-l|--logdest syslog|eventlog|<ABS FILEPATH>|console]
+  [--masterport <PORT>] [--noop] [-o|--onetime] [--sourceaddress <IP_ADDRESS>] [-t|--test]
   [-v|--verbose] [-V|--version] [-w|--waitforcert <SECONDS>]
 
 
@@ -232,6 +243,10 @@ generated by running puppet agent with '--genconfig'.
 * --help:
   Print this help message
 
+* --job-id:
+  Attach the specified job id to the catalog request and the report used for
+  this agent run. This option only works when '--onetime' is used.
+
 * --logdest:
   Where to send log messages. Choose between 'syslog' (the POSIX syslog
   service), 'eventlog' (the Windows Event Log), 'console', or the path to a log
@@ -261,10 +276,14 @@ generated by running puppet agent with '--genconfig'.
   (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-'
   prefix for boolean settings on the command line.)
 
+* --sourceaddress:
+  Set the source IP address for transactions. This defaults to automatically selected.
+  (This is a Puppet setting, and can go in puppet.conf.)
+
 * --test:
   Enable the most common options used for testing. These are 'onetime',
   'verbose', 'no-daemonize', 'no-usecacheonfailure', 'detailed-exitcodes',
-  'no-splay', 'show_diff', and 'no-use_cached_catalog'.
+  'no-splay', and 'show_diff'.
 
 * --verbose:
   Turn on verbose reporting.
@@ -338,19 +357,19 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
   def fingerprint
     host = Puppet::SSL::Host.new
     unless cert = host.certificate || host.certificate_request
-      $stderr.puts "Fingerprint asked but no certificate nor certificate request have yet been issued"
+      $stderr.puts _("Fingerprint asked but no certificate nor certificate request have yet been issued")
       exit(1)
       return
     end
     unless digest = cert.digest(options[:digest].to_s)
-      raise ArgumentError, "Could not get fingerprint for digest '#{options[:digest]}'"
+      raise ArgumentError, _("Could not get fingerprint for digest '%{digest}'") % { digest: options[:digest] }
     end
     puts digest.to_s
   end
 
   def onetime(daemon)
     begin
-      exitstatus = daemon.agent.run
+      exitstatus = daemon.agent.run(:job_id => options[:job_id])
     rescue => detail
       Puppet.log_exception(detail)
     end
@@ -367,7 +386,7 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
   end
 
   def main(daemon)
-    Puppet.notice "Starting Puppet client version #{Puppet.version}"
+    Puppet.notice _("Starting Puppet client version %{version}") % { version: Puppet.version }
     daemon.start
   end
 
@@ -377,14 +396,13 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
     Puppet.settings.handlearg("--no-splay")
     Puppet.settings.handlearg("--show_diff")
     Puppet.settings.handlearg("--no-daemonize")
-    Puppet.settings.handlearg("--no-use_cached_catalog")
     options[:verbose] = true
     Puppet[:onetime] = true
     options[:detailed_exitcodes] = true
   end
 
   def setup
-    raise ArgumentError, "The puppet agent command does not take parameters" unless command_line.args.empty?
+    raise ArgumentError, _("The puppet agent command does not take parameters") unless command_line.args.empty?
 
     setup_test if options[:test]
 
@@ -404,9 +422,7 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
     # we want the last report to be persisted locally
     Puppet::Transaction::Report.indirection.cache_class = :yaml
 
-    if Puppet[:noop]
-      Puppet::Resource::Catalog.indirection.cache_class = nil
-    elsif Puppet[:catalog_cache_terminus]
+    if Puppet[:catalog_cache_terminus]
       Puppet::Resource::Catalog.indirection.cache_class = Puppet[:catalog_cache_terminus]
     end
 
