@@ -34,7 +34,8 @@ class Puppet::Application::Cert < Puppet::Application
   end
 
   option("--debug", "-d") do |arg|
-    Puppet::Util::Log.level = :debug
+    options[:debug] = true
+    set_log_level
   end
 
   option("--list", "-l") do |arg|
@@ -73,14 +74,39 @@ class Puppet::Application::Cert < Puppet::Application
     options[:allow_dns_alt_names] = value
   end
 
+  option("--[no-]allow-authorization-extensions") do |value|
+    options[:allow_authorization_extensions] = value
+  end
+
   option("--verbose", "-v") do |arg|
-    Puppet::Util::Log.level = :info
+    options[:verbose] = true
+    set_log_level
+  end
+
+  option("--human-readable", "-H") do |arg|
+    options[:format] = :human
+  end
+
+  option("--machine-readable", "-m") do |arg|
+    options[:format] = :machine
+  end
+
+  option("--interactive", "-i") do |arg|
+    options[:interactive] = true
+  end
+
+  option("--assume-yes", "-y") do |arg|
+    options[:yes] = true
+  end
+
+  def summary
+    _("Manage certificates and requests")
   end
 
   def help
-    <<-'HELP'
+    <<-HELP
 
-puppet-cert(8) -- Manage certificates and requests
+puppet-cert(8) -- #{summary}
 ========
 
 SYNOPSIS
@@ -108,6 +134,8 @@ ACTIONS
 Every action except 'list' and 'generate' requires a hostname to act on,
 unless the '--all' option is set.
 
+The most important actions for day-to-day use are 'list' and 'sign'.
+
 * clean:
   Revoke a host's certificate (if applicable) and remove all files
   related to that host from puppet cert's storage. This is useful when
@@ -128,7 +156,10 @@ unless the '--all' option is set.
   List outstanding certificate requests. If '--all' is specified, signed
   certificates are also listed, prefixed by '+', and revoked or invalid
   certificates are prefixed by '-' (the verification outcome is printed
-  in parenthesis).
+  in parenthesis). If '--human-readable' or '-H' is specified,
+  certificates are formatted in a way to improve human scan-ability. If
+  '--machine-readable' or '-m' is specified, output is formatted concisely
+  for consumption by a script.
 
 * print:
   Print the full-text version of a host's certificate.
@@ -141,7 +172,10 @@ unless the '--all' option is set.
   needs to be restarted after revoking certificates.
 
 * sign:
-  Sign an outstanding certificate request.
+  Sign an outstanding certificate request. If '--interactive' or '-i' is
+  supplied the user will be prompted to confirm that they are signing the
+  correct certificate (recommended). If '--assume-yes' or '-y' is supplied
+  the interactive prompt will assume the answer of 'yes'.
 
 * verify:
   Verify the named certificate against the local CA certificate.
@@ -160,14 +194,33 @@ setting, so you can specify '--ssldir <directory>' as an
 argument.
 
 See the configuration file documentation at
-http://docs.puppetlabs.com/references/stable/configuration.html for the
+https://docs.puppetlabs.com/puppet/latest/reference/configuration.html for the
 full list of acceptable parameters. A commented list of all
 configuration options can also be generated by running puppet cert with
 '--genconfig'.
 
 * --all:
   Operate on all items. Currently only makes sense with the 'sign',
-  'clean', 'list', and 'fingerprint' actions.
+  'list', and 'fingerprint' actions.
+
+* --allow-dns-alt-names:
+  Sign a certificate request even if it contains one or more alternate DNS
+  names. If this option isn't specified, 'puppet cert sign' will ignore any
+  requests that contain alternate names.
+
+  In general, ONLY certs intended for a Puppet master server should include
+  alternate DNS names, since Puppet agent relies on those names for identifying
+  its rightful server.
+
+  You can make Puppet agent request a certificate with alternate names by
+  setting 'dns_alt_names' in puppet.conf or specifying '--dns_alt_names' on the
+  command line. The output of 'puppet cert list' shows any requested alt names
+  for pending certificate requests.
+
+* --allow-authorization-extensions:
+  Enable the signing of a request with authorization extensions. Such requests
+  are sensitive because they can be used to write access rules in Puppet Server.
+  Currently, this is the only means by which such requests can be signed.
 
 * --digest:
   Set the digest for fingerprinting (defaults to the digest used when
@@ -201,7 +254,7 @@ Luke Kanies
 
 COPYRIGHT
 ---------
-Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
+Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
 
     HELP
   end
@@ -215,7 +268,10 @@ Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
       hosts = command_line.args.collect { |h| h.downcase }
     end
     begin
-      apply(@ca, :revoke, options.merge(:to => hosts)) if subcommand == :destroy
+      if subcommand == :destroy
+        signed_hosts = hosts - @ca.waiting?
+        apply(@ca, :revoke, options.merge(:to => signed_hosts))
+      end
       apply(@ca, subcommand, options.merge(:to => hosts, :digest => @digest))
     rescue => detail
       Puppet.log_exception(detail)
@@ -227,6 +283,9 @@ Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
     require 'puppet/ssl/certificate_authority'
     exit(Puppet.settings.print_configs ? 0 : 1) if Puppet.settings.print_configs?
 
+    Puppet::SSL::Oids.register_puppet_oids
+    Puppet::SSL::Oids.load_custom_oid_file(Puppet[:trusted_oid_mapping_file])
+
     Puppet::Util::Log.newdestination :console
 
     if [:generate, :destroy].include? subcommand
@@ -263,13 +322,14 @@ Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
         exit
       end
     end
+
     result
   end
 
   # Create and run an applicator.  I wanted to build an interface where you could do
   # something like 'ca.apply(:generate).to(:all) but I don't think it's really possible.
   def apply(ca, method, options)
-    raise ArgumentError, "You must specify the hosts to apply to; valid values are an array or the symbol :all" unless options[:to]
+    raise ArgumentError, _("You must specify the hosts to apply to; valid values are an array or the symbol :all") unless options[:to]
     applier = Puppet::SSL::CertificateAuthority::Interface.new(method, options)
     applier.apply(ca)
   end
