@@ -20,6 +20,7 @@ class Puppet::Context
   # @api private
   def initialize(initial_bindings)
     @table = initial_bindings
+    @ignores = []
     @description = "root"
     @id = 0
     @rollbacks = {}
@@ -37,7 +38,7 @@ class Puppet::Context
   # @api private
   def pop
     if @stack[-1][0] == 0
-      raise(StackUnderflow, "Attempted to pop, but already at root of the context stack.")
+      raise(StackUnderflow, _("Attempted to pop, but already at root of the context stack."))
     else
       (_, @table, @description) = @stack.pop
     end
@@ -45,13 +46,13 @@ class Puppet::Context
 
   # @api private
   def lookup(name, &block)
-    if @table.include?(name)
+    if @table.include?(name) && !@ignores.include?(name)
       value = @table[name]
       value.is_a?(Proc) ? (@table[name] = value.call) : value
     elsif block
       block.call
     else
-      raise UndefinedBindingError, "no '#{name}' in #{@table.inspect} at top of #{@stack.inspect}"
+      raise UndefinedBindingError, _("no '%{name}' in %{table} at top of %{stack}") % { name: name, table: @table.inspect, stack: @stack.inspect }
     end
   end
 
@@ -66,6 +67,20 @@ class Puppet::Context
     rollback(mark_point)
   end
 
+  # @api private
+  def ignore(name)
+    @ignores << name
+  end
+
+  # @api private
+  def restore(name)
+    if @ignores.include?(name)
+      @ignores.delete(name)
+    else
+      raise UndefinedBindingError, _("no '%{name}' in ignores %{ignores} at top of %{stack}") % { name: name, ignores: @ignores.inspect, stack: @stack.inspect }
+    end
+  end
+
   # Mark a place on the context stack to later return to with {rollback}.
   #
   # @param name [Object] The identifier for the mark
@@ -75,7 +90,7 @@ class Puppet::Context
     if @rollbacks[name].nil?
       @rollbacks[name] = @stack[-1][0]
     else
-      raise DuplicateRollbackMarkError, "Mark for '#{name}' already exists"
+      raise DuplicateRollbackMarkError, _("Mark for '%{name}' already exists") % { name: name }
     end
   end
 
@@ -89,7 +104,7 @@ class Puppet::Context
   # @api private
   def rollback(name)
     if @rollbacks[name].nil?
-      raise UnknownRollbackMarkError, "Unknown mark '#{name}'"
+      raise UnknownRollbackMarkError, _("Unknown mark '%{name}'") % { name: name }
     end
 
     while @stack[-1][0] != @rollbacks[name]
