@@ -41,7 +41,10 @@ module Puppet::Environments
 
     def clear_all
       root = Puppet.lookup(:root_environment) { nil }
-      root.instance_variable_set(:@static_catalogs, nil) unless root.nil?
+      unless root.nil?
+        root.instance_variable_set(:@static_catalogs, nil)
+        root.instance_variable_set(:@rich_data, nil)
+      end
     end
   end
 
@@ -112,7 +115,7 @@ module Puppet::Environments
     def get_conf(name)
       env = get(name)
       if env
-        Puppet::Settings::EnvironmentConf.static_for(env, 0, Puppet[:static_catalogs])
+        Puppet::Settings::EnvironmentConf.static_for(env, 0, Puppet[:static_catalogs], Puppet[:rich_data])
       else
         nil
       end
@@ -135,6 +138,23 @@ module Puppet::Environments
     end
   end
 
+  class StaticDirectory < Static
+    # Accepts a single environment in the given directory having the given name (not required to be reflected as the name
+    # of the directory)
+    # 
+    def initialize(env_name, env_dir, environment)
+      super(environment)
+      @env_dir = env_dir
+      @env_name = env_name
+    end
+
+    # @!macro loader_get_conf
+    def get_conf(name)
+      return nil unless name == @env_name
+      Puppet::Settings::EnvironmentConf.load_from(@env_dir, '')
+    end
+  end
+
   # Reads environments from a directory on disk. Each environment is
   # represented as a sub-directory. The environment's manifest setting is the
   # `manifest` directory of the environment directory. The environment's
@@ -147,8 +167,10 @@ module Puppet::Environments
     include EnvironmentLoader
 
     def initialize(environment_dir, global_module_path)
-      @environment_dir = environment_dir
-      @global_module_path = global_module_path
+      @environment_dir =  Puppet::FileSystem.expand_path(environment_dir)
+      @global_module_path = global_module_path ?
+        global_module_path.map { |p| Puppet::FileSystem.expand_path(p) } :
+        nil
     end
 
     # Generate an array of directory loaders from a path string.
@@ -292,7 +314,7 @@ module Puppet::Environments
     end
 
     # Returns the end of time (the next Mesoamerican Long Count cycle-end after 2012 (5125+2012) = 7137,
-    # of for a 32 bit machine using Ruby < 1.9.3, the year 2038.
+    # or for a 32 bit machine using Ruby < 1.9.3, the year 2038.
     def self.end_of_time
       begin
         Time.gm(7137)
@@ -360,6 +382,7 @@ module Puppet::Environments
     # (The intention is that this could be used from a MANUAL cache eviction command (TBD)
     def clear(name)
       @cache.delete(name)
+      Puppet::GettextConfig.delete_text_domain(name)
     end
 
     # Clears all cached environments.
@@ -369,6 +392,7 @@ module Puppet::Environments
       @cache = {}
       @expirations.clear
       @next_expiration = END_OF_TIME
+      Puppet::GettextConfig.delete_environment_text_domains
     end
 
     # Clears all environments that have expired, either by exceeding their time to live, or
