@@ -3,7 +3,7 @@ module Puppet
   class Error < RuntimeError
     attr_accessor :original
     def initialize(message, original=nil)
-      super(message)
+      super(Puppet::Util::CharacterEncoding.scrub(message))
       @original = original
     end
   end
@@ -27,22 +27,12 @@ module Puppet
       @line = line
       @pos = pos
     end
+
     def to_s
       msg = super
       @file = nil if (@file.is_a?(String) && @file.empty?)
-      if @file and @line and @pos
-        "#{msg} at #{@file}:#{@line}:#{@pos}"
-      elsif @file and @line
-        "#{msg} at #{@file}:#{@line}"
-      elsif @line and @pos
-          "#{msg} at line #{@line}:#{@pos}"
-      elsif @line
-        "#{msg} at line #{@line}"
-      elsif @file
-        "#{msg} in #{@file}"
-      else
-        msg
-      end
+      msg += Puppet::Util::Errors.error_location_with_space(@file, @line, @pos)
+      msg
     end
   end
 
@@ -74,10 +64,27 @@ module Puppet
 
     def to_s
       msg = super
-      msg = "Could not parse for environment #{environment}: #{msg}" if environment
-      msg = "#{msg} on node #{node}" if node
+      msg = _("Could not parse for environment %{environment}: %{message}") % { environment: environment, message: msg } if environment
+      msg = _("%{message} on node %{node}") % { message: msg, node: node } if node
       msg
     end
+
+    def self.from_issue_and_stack(issue, args = {})
+      stacktrace = Puppet::Pops::PuppetStack.stacktrace()
+      if stacktrace.size > 0
+        filename, line = stacktrace[0]
+      else
+        filename = nil
+        line = nil
+      end
+      self.new(
+            issue.format(args),
+            filename,
+            line,
+            nil,
+            nil,
+            issue.issue_code)
+    end
   end
 
   # An error that already contains location information in the message text
@@ -89,4 +96,12 @@ module Puppet
   class DevError < Puppet::Error
     include ExternalFileError
   end
+
+  class MissingCommand < Puppet::Error
+  end
+
+  # Raised when we failed to acquire a lock
+  class LockError < Puppet::Error
+  end
+
 end
