@@ -1,10 +1,10 @@
 require 'puppet/indirector/face'
 
 Puppet::Indirector::Face.define(:certificate_request, '0.0.1') do
-  copyright "Puppet Labs", 2011
+  copyright "Puppet Inc.", 2011
   license   "Apache 2 license; see COPYING"
 
-  summary "Manage certificate requests."
+  summary _("Manage certificate requests.")
   description <<-EOT
     This subcommand retrieves and submits certificate signing requests (CSRs).
   EOT
@@ -51,4 +51,6 @@ Puppet::Indirector::Face.define(:certificate_request, '0.0.1') do
 
   get_action(:save).summary "API only: submit a certificate signing request."
   get_action(:save).arguments "<x509_CSR>"
+
+  deprecate
 end
