@@ -1,21 +1,20 @@
 require 'puppet/indirector/face'
 
 Puppet::Indirector::Face.define(:status, '0.0.1') do
-  copyright "Puppet Labs", 2011
-  license   "Apache 2 license; see COPYING"
+  copyright "Puppet Inc.", 2011
+  license   _("Apache 2 license; see COPYING")
 
-  summary "View puppet server status."
+  summary _("View puppet server status.")
 
-  get_action(:destroy).summary "Invalid for this subcommand."
-  get_action(:save).summary "Invalid for this subcommand."
-  get_action(:save).description "Invalid for this subcommand."
-  get_action(:search).summary "Invalid for this subcommand."
+  deactivate_action(:destroy)
+  deactivate_action(:save)
+  deactivate_action(:search)
 
   find = get_action(:find)
   find.default = true
-  find.summary "Check status of puppet master server."
-  find.arguments "<dummy_text>"
-  find.returns <<-'EOT'
+  find.summary _("Check status of puppet master server.")
+  #TRANSLATORS the string 'Puppet::Status' is a Puppet language object and should not be translated
+  find.returns _(<<-'EOT')
     A "true" response or a low-level connection error. When used from the Ruby
     API: returns a Puppet::Status object.
   EOT
@@ -32,22 +31,21 @@ Puppet::Indirector::Face.define(:status, '0.0.1') do
   EOT
   find.short_description <<-EOT
     Checks whether a Puppet server is properly receiving and processing HTTP
-    requests. Due to a known bug, this action requires a dummy argument, the
-    content of which is irrelevant. This action is only useful when used with
-    '--terminus rest', and will always return true when invoked locally.
+    requests. This action is only useful when used with '--terminus rest',
+    and will always return true when invoked locally.
   EOT
   find.notes <<-'EOT'
     This action requires that the server's `auth.conf` file allow find
     access to the `status` REST terminus. Puppet agent does not use this
     facility, and it is turned off by default. See
-    <http://docs.puppetlabs.com/guides/rest_auth_conf.html> for more details.
-
-    Although this action always returns an unnamed status object, it requires a
-    dummy argument. This is a known bug.
+    <https://docs.puppetlabs.com/puppet/latest/reference/config_file_auth.html>
+    for more details.
   EOT
   find.examples <<-'EOT'
     Check the status of the configured puppet master:
 
-    $ puppet status find x --terminus rest
+    $ puppet status find --terminus rest
   EOT
+  
+  deprecate
 end
