@@ -1,5 +1,5 @@
 require 'puppet/util/feature'
 
 if Puppet.features.microsoft_windows?
-  Puppet.features.add(:eventlog, :libs => %{win32/eventlog})
+  Puppet.features.add(:eventlog)
 end
