@@ -20,7 +20,7 @@ class Puppet::FileServing::Base
   end
 
   # Return the full path to our file.  Fails if there's no path set.
-  def full_path(dummy_argument=:work_arround_for_ruby_GC_bug)
+  def full_path
     if relative_path.nil? or relative_path == "" or relative_path == "."
        full_path = path
      else
@@ -46,14 +46,15 @@ class Puppet::FileServing::Base
   def links=(value)
     value = value.to_sym
     value = :manage if value == :ignore
-    raise(ArgumentError, ":links can only be set to :manage or :follow") unless [:manage, :follow].include?(value)
+    #TRANSLATORS ':link', ':manage', ':follow' should not be translated
+    raise(ArgumentError, _(":links can only be set to :manage or :follow")) unless [:manage, :follow].include?(value)
     @links = value
   end
 
   # Set our base path.
   attr_reader :path
   def path=(path)
-    raise ArgumentError.new("Paths must be fully qualified") unless Puppet::FileServing::Base.absolute?(path)
+    raise ArgumentError.new(_("Paths must be fully qualified")) unless Puppet::FileServing::Base.absolute?(path)
     @path = path
   end
 
@@ -61,7 +62,7 @@ class Puppet::FileServing::Base
   # the file's path relative to the initial recursion point.
   attr_reader :relative_path
   def relative_path=(path)
-    raise ArgumentError.new("Relative paths must not be fully qualified") if Puppet::FileServing::Base.absolute?(path)
+    raise ArgumentError.new(_("Relative paths must not be fully qualified")) if Puppet::FileServing::Base.absolute?(path)
     @relative_path = path
   end
 
@@ -75,17 +76,7 @@ class Puppet::FileServing::Base
     {
       'path'          => @path,
       'relative_path' => @relative_path,
-      'links'         => @links
-    }
-  end
-
-  def to_pson_data_hash
-    {
-      # No 'document_type' since we don't send these bare
-      'data'       => to_data_hash,
-      'metadata' => {
-        'api_version' => 1
-        }
+      'links'         => @links.to_s
     }
   end
 
