@@ -12,7 +12,7 @@ class Puppet::Indirector::CertificateStatus::File < Puppet::Indirector::Code
     on the CA."
 
   def ca
-    raise ArgumentError, "This process is not configured as a certificate authority" unless Puppet::SSL::CertificateAuthority.ca?
+    raise ArgumentError, _("This process is not configured as a certificate authority") unless Puppet::SSL::CertificateAuthority.ca?
     Puppet::SSL::CertificateAuthority.new
   end
 
@@ -28,21 +28,21 @@ class Puppet::Indirector::CertificateStatus::File < Puppet::Indirector::Code
       end
     end
 
-    return "Nothing was deleted" if deleted.empty?
-    "Deleted for #{request.key}: #{deleted.join(", ")}"
+    return _("Nothing was deleted") if deleted.empty?
+    _("Deleted for %{request}: %{deleted}") % { request: request.key, deleted: deleted.join(", ") }
   end
 
   def save(request)
     if request.instance.desired_state == "signed"
       certificate_request = Puppet::SSL::CertificateRequest.indirection.find(request.key)
-      raise Puppet::Error, "Cannot sign for host #{request.key} without a certificate request" unless certificate_request
+      raise Puppet::Error, _("Cannot sign for host %{request} without a certificate request") % { request: request.key } unless certificate_request
       ca.sign(request.key)
     elsif request.instance.desired_state == "revoked"
       certificate = Puppet::SSL::Certificate.indirection.find(request.key)
-      raise Puppet::Error, "Cannot revoke host #{request.key} because has it doesn't have a signed certificate" unless certificate
+      raise Puppet::Error, _("Cannot revoke host %{request} because has it doesn't have a signed certificate") % { request: request.key } unless certificate
       ca.revoke(request.key)
     else
-      raise Puppet::Error, "State #{request.instance.desired_state} invalid; Must specify desired state of 'signed' or 'revoked' for host #{request.key}"
+      raise Puppet::Error, _("State %{state} invalid; Must specify desired state of 'signed' or 'revoked' for host %{request}") % { state: request.instance.desired_state, request: request.key }
     end
 
   end
@@ -83,4 +83,9 @@ class Puppet::Indirector::CertificateStatus::File < Puppet::Indirector::Code
       nil
     end
   end
+
+  def validate_key(request)
+    # We only use desired_state from the instance and use request.key
+    # otherwise, so the name does not need to match
+  end
 end
