@@ -6,23 +6,35 @@ class Puppet::Node::Facts::Facter < Puppet::Indirector::Code
     between Puppet and Facter.  It's only `somewhat` abstract because it always
     returns the local host's facts, regardless of what you attempt to find."
 
+  def allow_remote_requests?
+    false
+  end
+
   def destroy(facts)
-    raise Puppet::DevError, 'You cannot destroy facts in the code store; it is only used for getting facts from Facter'
+    raise Puppet::DevError, _('You cannot destroy facts in the code store; it is only used for getting facts from Facter')
   end
 
   def save(facts)
-    raise Puppet::DevError, 'You cannot save facts to the code store; it is only used for getting facts from Facter'
+    raise Puppet::DevError, _('You cannot save facts to the code store; it is only used for getting facts from Facter')
   end
 
   # Lookup a host's facts up in Facter.
   def find(request)
     Facter.reset
-    self.class.setup_external_search_paths(request) if Puppet.features.external_facts?
+
+    # Note: we need to setup puppet's external search paths before adding the puppetversion
+    # fact. This is because in Facter 2.x, the first `Facter.add` causes Facter to create
+    # its directory loaders which cannot be changed, meaning other external facts won't
+    # be resolved. (PUP-4607)
+    self.class.setup_external_search_paths(request)
     self.class.setup_search_paths(request)
 
+    # Initialize core Puppet facts, such as puppetversion
+    Puppet.initialize_facts
+
     result = Puppet::Node::Facts.new(request.key, Facter.to_hash)
     result.add_local_facts
-    Puppet[:stringify_facts] ? result.stringify : result.sanitize
+    result.sanitize
     result
   end
 
@@ -43,7 +55,7 @@ class Puppet::Node::Facts::Facter < Puppet::Indirector::Code
       # print out each .rb in the facts directory as module
       # developers may find that information useful for debugging purposes
       if Puppet::Util::Log.sendlevel?(:info)
-        Puppet.info "Loading facts"
+        Puppet.info _("Loading facts")
         Dir.glob("#{dir}/*.rb").each do |file|
           Puppet.debug "Loading facts from #{file}"
         end
