@@ -1,5 +1,4 @@
 require 'net/http'
-require 'semver'
 require 'json'
 require 'puppet/util/colors'
 
@@ -37,10 +36,13 @@ module Puppet::ModuleTool
         @metadata = Puppet::ModuleTool::Metadata.new
 
         unless @path
-          raise ArgumentError, "Could not determine module path"
+          raise ArgumentError, _("Could not determine module path")
+        end
+
+        if require_metadata && !Puppet::ModuleTool.is_module_root?(@path)
+          raise ArgumentError, _("Unable to find metadata.json in module root at %{path} See https://docs.puppet.com/puppet/latest/reference/modules_publishing.html for required file format.") % { path: @path }
         end
 
-        modulefile_path = File.join(@path, 'Modulefile')
         metadata_path   = File.join(@path, 'metadata.json')
 
         if File.file?(metadata_path)
@@ -48,24 +50,13 @@ module Puppet::ModuleTool
             begin
               @metadata.update(JSON.load(f))
             rescue JSON::ParserError => ex
-              raise ArgumentError, "Could not parse JSON #{metadata_path}", ex.backtrace
+              raise ArgumentError, _("Could not parse JSON %{metadata_path}") % { metadata_path: metadata_path }, ex.backtrace
             end
           end
         end
 
-        if File.file?(modulefile_path)
-          if File.file?(metadata_path)
-            Puppet.warning "Modulefile is deprecated. Merging your Modulefile and metadata.json."
-          else
-            Puppet.warning "Modulefile is deprecated. Building metadata.json from Modulefile."
-          end
-
-          Puppet::ModuleTool::ModulefileReader.evaluate(@metadata, modulefile_path)
-        end
-
-        has_metadata = File.file?(modulefile_path) || File.file?(metadata_path)
-        if !has_metadata && require_metadata
-          raise ArgumentError, "No metadata found for module #{@path}"
+        if File.file?(File.join(@path, 'Modulefile'))
+          Puppet.warning _("A Modulefile was found in the root directory of the module. This file will be ignored and can safely be removed.")
         end
 
         return @metadata
@@ -77,14 +68,14 @@ module Puppet::ModuleTool
       end
 
       def parse_filename(filename)
-        if match = /^((.*?)-(.*?))-(\d+\.\d+\.\d+.*?)$/.match(File.basename(filename,'.tar.gz'))
+        if match = /^((.*?)-(.*?))-(\d+\.\d+\.\d+.*?)$/.match(File.basename(filename, '.tar.gz'))
           module_name, author, shortname, version = match.captures
         else
-          raise ArgumentError, "Could not parse filename to obtain the username, module name and version.  (#{@release_name})"
+          raise ArgumentError, _("Could not parse filename to obtain the username, module name and version.  (%{release_name})") % { release_name: @release_name }
         end
 
-        unless SemVer.valid?(version)
-          raise ArgumentError, "Invalid version format: #{version} (Semantic Versions are acceptable: http://semver.org)"
+        unless SemanticPuppet::Version.valid?(version)
+          raise ArgumentError, _("Invalid version format: %{version} (Semantic Versions are acceptable: http://semver.org)") % { version: version }
         end
 
         return {
