@@ -25,6 +25,7 @@ module Puppet::ModuleTool
         @ignore_dependencies = forced? || options[:ignore_dependencies]
         @name                = name
         @install_dir         = install_dir
+        @strict_semver       = !!options[:strict_semver]
 
         Puppet::Forge::Cache.clean
 
@@ -34,34 +35,37 @@ module Puppet::ModuleTool
           release = local_tarball_source.release
           @name = release.name
           options[:version] = release.version.to_s
-          Semantic::Dependency.add_source(local_tarball_source)
+          SemanticPuppet::Dependency.add_source(local_tarball_source)
 
           # If we're operating on a local tarball and ignoring dependencies, we
           # don't need to search any additional sources.  This will cut down on
           # unnecessary network traffic.
           unless @ignore_dependencies
-            Semantic::Dependency.add_source(installed_modules_source)
-            Semantic::Dependency.add_source(module_repository)
+            SemanticPuppet::Dependency.add_source(installed_modules_source)
+            SemanticPuppet::Dependency.add_source(module_repository)
           end
 
         else
-          Semantic::Dependency.add_source(installed_modules_source) unless forced?
-          Semantic::Dependency.add_source(module_repository)
+          SemanticPuppet::Dependency.add_source(installed_modules_source) unless forced?
+          SemanticPuppet::Dependency.add_source(module_repository)
         end
       end
 
       def run
+        # Disallow anything that invokes md5 to avoid un-friendly termination due to FIPS
+        raise _("Module install is prohibited in FIPS mode.") if Facter.value(:fips_enabled)
+
         name = @name.tr('/', '-')
         version = options[:version] || '>= 0.0.0'
 
         results = { :action => :install, :module_name => name, :module_version => version }
 
         begin
-          if mod = installed_modules[name]
+          if installed_module = installed_modules[name]
             unless forced?
-              if Semantic::VersionRange.parse(version).include? mod.version
+              if Puppet::Module.parse_range(version, @strict_semver).include? installed_module.version
                 results[:result] = :noop
-                results[:version] = mod.version
+                results[:version] = installed_module.version
                 return results
               else
                 changes = Checksummer.run(installed_modules[name].mod.path) rescue []
@@ -78,7 +82,7 @@ module Puppet::ModuleTool
           results[:install_dir] = @install_dir.target
 
           unless @local_tarball && @ignore_dependencies
-            Puppet.notice "Downloading from #{module_repository.host} ..."
+            Puppet.notice _("Downloading from %{host} ...") % { host: module_repository.host }
           end
 
           if @ignore_dependencies
@@ -101,19 +105,17 @@ module Puppet::ModuleTool
               # Since upgrading already installed modules can be troublesome,
               # we'll place constraints on the graph for each installed module,
               # locking it to upgrades within the same major version.
-              ">=#{version} #{version.major}.x".tap do |range|
-                graph.add_constraint('installed', mod, range) do |node|
-                  Semantic::VersionRange.parse(range).include? node.version
-                end
+              installed_range = ">=#{version} #{version.major}.x"
+              graph.add_constraint('installed', mod, installed_range) do |node|
+                Puppet::Module.parse_range(installed_range, @strict_semver).include? node.version
               end
 
               release.mod.dependencies.each do |dep|
                 dep_name = dep['name'].tr('/', '-')
 
-                dep['version_requirement'].tap do |range|
-                  graph.add_constraint("#{mod} constraint", dep_name, range) do |node|
-                    Semantic::VersionRange.parse(range).include? node.version
-                  end
+                range = dep['version_requirement']
+                graph.add_constraint("#{mod} constraint", dep_name, range) do |node|
+                  Puppet::Module.parse_range(range, @strict_semver).include? node.version
                 end
               end
             end
@@ -126,17 +128,17 @@ module Puppet::ModuleTool
           end
 
           begin
-            Puppet.info "Resolving dependencies ..."
-            releases = Semantic::Dependency.resolve(graph)
-          rescue Semantic::Dependency::UnsatisfiableGraph
+            Puppet.info _("Resolving dependencies ...")
+            releases = SemanticPuppet::Dependency.resolve(graph)
+          rescue SemanticPuppet::Dependency::UnsatisfiableGraph
             raise NoVersionsSatisfyError, results.merge(:requested_name => name)
           end
 
           unless forced?
             # Check for module name conflicts.
             releases.each do |rel|
-              if mod = installed_modules_source.by_name[rel.name.split('-').last]
-                next if mod.has_metadata? && mod.forge_name.tr('/', '-') == rel.name
+              if installed_module = installed_modules_source.by_name[rel.name.split('-').last]
+                next if installed_module.has_metadata? && installed_module.forge_name.tr('/', '-') == rel.name
 
                 if rel.name != name
                   dependency = {
@@ -149,16 +151,16 @@ module Puppet::ModuleTool
                   :requested_module  => name,
                   :requested_version => options[:version] || 'latest',
                   :dependency        => dependency,
-                  :directory         => mod.path,
-                  :metadata          => mod.metadata
+                  :directory         => installed_module.path,
+                  :metadata          => installed_module.metadata
               end
             end
           end
 
-          Puppet.info "Preparing to install ..."
+          Puppet.info _("Preparing to install ...")
           releases.each { |release| release.prepare }
 
-          Puppet.notice 'Installing -- do not interrupt ...'
+          Puppet.notice _('Installing -- do not interrupt ...')
           releases.each do |release|
             installed = installed_modules[release.name]
             if forced? || installed.nil?
@@ -187,12 +189,12 @@ module Puppet::ModuleTool
       private
 
       def module_repository
-        @repo ||= Puppet::Forge.new
+        @repo ||= Puppet::Forge.new(Puppet[:module_repository], @strict_semver)
       end
 
       def local_tarball_source
         @tarball_source ||= begin
-          Puppet::ModuleTool::LocalTarball.new(@name)
+          Puppet::ModuleTool::LocalTarball.new(@name, @strict_semver)
         rescue Puppet::Module::Error => e
           raise InvalidModuleError.new(@name, :action => @action, :error  => e)
         end
@@ -207,15 +209,15 @@ module Puppet::ModuleTool
       end
 
       def build_single_module_graph(name, version)
-        range = Semantic::VersionRange.parse(version)
-        graph = Semantic::Dependency::Graph.new(name => range)
-        releases = Semantic::Dependency.fetch_releases(name)
+        range = Puppet::Module.parse_range(version, @strict_semver)
+        graph = SemanticPuppet::Dependency::Graph.new(name => range)
+        releases = SemanticPuppet::Dependency.fetch_releases(name)
         releases.each { |release| release.dependencies.clear }
         graph << releases
       end
 
       def build_dependency_graph(name, version)
-        Semantic::Dependency.query(name => version)
+        SemanticPuppet::Dependency.query(name => version)
       end
 
       def build_install_graph(release, installed, graphed = [])
@@ -260,7 +262,7 @@ module Puppet::ModuleTool
           @remote = { "#{@module_name}@#{@version}" => { } }
           @versions = {
             @module_name => [
-              { :vstring => @version, :semver => SemVer.new(@version) }
+              { :vstring => @version, :semver => SemanticPuppet::Version.parse(@version) }
             ]
           }
         else
