@@ -20,12 +20,16 @@ module Puppet::ModuleTool
         @name                = name
         @ignore_changes      = forced? || options[:ignore_changes]
         @ignore_dependencies = forced? || options[:ignore_dependencies]
+        @strict_semver       = !!options[:strict_semver]
 
-        Semantic::Dependency.add_source(installed_modules_source)
-        Semantic::Dependency.add_source(module_repository)
+        SemanticPuppet::Dependency.add_source(installed_modules_source)
+        SemanticPuppet::Dependency.add_source(module_repository)
       end
 
       def run
+        # Disallow anything that invokes md5 to avoid un-friendly termination due to FIPS
+        raise _("Module upgrade is prohibited in FIPS mode.") if Facter.value(:fips_enabled)
+
         name = @name.tr('/', '-')
         version = options[:version] || '>= 0.0.0'
 
@@ -48,7 +52,7 @@ module Puppet::ModuleTool
 
           installed_release = installed_modules[name]
 
-          # `priority` is an attribute of a `Semantic::Dependency::Source`,
+          # `priority` is an attribute of a `SemanticPuppet::Dependency::Source`,
           # which is delegated through `ModuleRelease` instances for the sake of
           # comparison (sorting). By default, the `InstalledModules` source has
           # a priority of 10 (making it the most preferable source, so that
@@ -66,11 +70,11 @@ module Puppet::ModuleTool
           end
 
           mod = installed_release.mod
-          results[:installed_version] = Semantic::Version.parse(mod.version)
+          results[:installed_version] = SemanticPuppet::Version.parse(mod.version)
           dir = Pathname.new(mod.modulepath)
 
           vstring = mod.version ? "v#{mod.version}" : '???'
-          Puppet.notice "Found '#{name}' (#{colorize(:cyan, vstring)}) in #{dir} ..."
+          Puppet.notice _("Found '%{name}' (%{version}) in %{dir} ...") % { name: name, version: colorize(:cyan, vstring), dir: dir }
           unless @ignore_changes
             changes = Checksummer.run(mod.path) rescue []
             if mod.has_metadata? && !changes.empty?
@@ -90,13 +94,13 @@ module Puppet::ModuleTool
           if available_versions.empty?
             raise NoCandidateReleasesError, results.merge(:module_name => name, :source => module_repository.host)
           elsif results[:requested_version] != :latest
-            requested = Semantic::VersionRange.parse(results[:requested_version])
+            requested = Puppet::Module.parse_range(results[:requested_version], @strict_semver)
             unless available_versions.any? {|m| requested.include? m.version}
               raise NoCandidateReleasesError, results.merge(:module_name => name, :source => module_repository.host)
             end
           end
 
-          Puppet.notice "Downloading from #{module_repository.host} ..."
+          Puppet.notice _("Downloading from %{host} ...") % { host: module_repository.host }
           if @ignore_dependencies
             graph = build_single_module_graph(name, version)
           else
@@ -107,9 +111,9 @@ module Puppet::ModuleTool
             add_module_name_constraints_to_graph(graph)
           end
 
-          installed_modules.each do |mod, release|
-            mod = mod.tr('/', '-')
-            next if mod == name
+          installed_modules.each do |installed_module, release|
+            installed_module = installed_module.tr('/', '-')
+            next if installed_module == name
 
             version = release.version
 
@@ -117,28 +121,26 @@ module Puppet::ModuleTool
               # Since upgrading already installed modules can be troublesome,
               # we'll place constraints on the graph for each installed
               # module, locking it to upgrades within the same major version.
-              ">=#{version} #{version.major}.x".tap do |range|
-                graph.add_constraint('installed', mod, range) do |node|
-                  Semantic::VersionRange.parse(range).include? node.version
-                end
+              installed_range = ">=#{version} #{version.major}.x"
+              graph.add_constraint('installed', installed_module, installed_range) do |node|
+                Puppet::Module.parse_range(installed_range, @strict_semver).include? node.version
               end
 
               release.mod.dependencies.each do |dep|
                 dep_name = dep['name'].tr('/', '-')
 
-                dep['version_requirement'].tap do |range|
-                  graph.add_constraint("#{mod} constraint", dep_name, range) do |node|
-                    Semantic::VersionRange.parse(range).include? node.version
-                  end
+                range = dep['version_requirement']
+                graph.add_constraint("#{installed_module} constraint", dep_name, range) do |node|
+                  Puppet::Module.parse_range(range, @strict_semver).include? node.version
                 end
               end
             end
           end
 
           begin
-            Puppet.info "Resolving dependencies ..."
-            releases = Semantic::Dependency.resolve(graph)
-          rescue Semantic::Dependency::UnsatisfiableGraph
+            Puppet.info _("Resolving dependencies ...")
+            releases = SemanticPuppet::Dependency.resolve(graph)
+          rescue SemanticPuppet::Dependency::UnsatisfiableGraph
             raise NoVersionsSatisfyError, results.merge(:requested_name => name)
           end
 
@@ -183,10 +185,10 @@ module Puppet::ModuleTool
             end
           end
 
-          Puppet.info "Preparing to upgrade ..."
+          Puppet.info _("Preparing to upgrade ...")
           releases.each { |release| release.prepare }
 
-          Puppet.notice 'Upgrading -- do not interrupt ...'
+          Puppet.notice _('Upgrading -- do not interrupt ...')
           releases.each do |release|
             if installed = installed_modules[release.name]
               release.install(Pathname.new(installed.mod.modulepath))
@@ -217,7 +219,7 @@ module Puppet::ModuleTool
 
       private
       def module_repository
-        @repo ||= Puppet::Forge.new
+        @repo ||= Puppet::Forge.new(Puppet[:module_repository], @strict_semver)
       end
 
       def installed_modules_source
@@ -229,15 +231,15 @@ module Puppet::ModuleTool
       end
 
       def build_single_module_graph(name, version)
-        range = Semantic::VersionRange.parse(version)
-        graph = Semantic::Dependency::Graph.new(name => range)
-        releases = Semantic::Dependency.fetch_releases(name)
+        range = Puppet::Module.parse_range(version, @strict_semver)
+        graph = SemanticPuppet::Dependency::Graph.new(name => range)
+        releases = SemanticPuppet::Dependency.fetch_releases(name)
         releases.each { |release| release.dependencies.clear }
         graph << releases
       end
 
       def build_dependency_graph(name, version)
-        Semantic::Dependency.query(name => version)
+        SemanticPuppet::Dependency.query(name => version)
       end
 
       def build_install_graph(release, installed, graphed = [])
