@@ -68,7 +68,7 @@ module Puppet::ModuleTool
       validate_version_range(version_requirement) if version_requirement
 
       if dup = @data['dependencies'].find { |d| d.full_module_name == name && d.version_requirement != version_requirement }
-        raise ArgumentError, "Dependency conflict for #{full_module_name}: Dependency #{name} was given conflicting version requirements #{version_requirement} and #{dup.version_requirement}. Verify that there are no duplicates in the metadata.json."
+        raise ArgumentError, _("Dependency conflict for %{module_name}: Dependency %{name} was given conflicting version requirements %{version_requirement} and %{dup_version}. Verify that there are no duplicates in the metadata.json.") % { module_name: full_module_name, name: name, version_requirement: version_requirement, dup_version: dup.version_requirement }
       end
 
       dep = Dependency.new(name, version_requirement, repository)
@@ -79,7 +79,7 @@ module Puppet::ModuleTool
 
     # Provides an accessor for the now defunct 'description' property.  This
     # addresses a regression in Puppet 3.6.x where previously valid templates
-    # refering to the 'description' property were broken.
+    # referring to the 'description' property were broken.
     # @deprecated
     def description
       @data['description']
@@ -174,24 +174,24 @@ module Puppet::ModuleTool
 
       err = case modname
       when nil, '', :namespace_missing
-        "the field must be a namespaced module name"
+        _("the field must be a namespaced module name")
       when /[^a-z0-9_]/i
-        "the module name contains non-alphanumeric (or underscore) characters"
+        _("the module name contains non-alphanumeric (or underscore) characters")
       when /^[^a-z]/i
-        "the module name must begin with a letter"
+        _("the module name must begin with a letter")
       else
-        "the namespace contains non-alphanumeric characters"
+        _("the namespace contains non-alphanumeric characters")
       end
 
-      raise ArgumentError, "Invalid 'name' field in metadata.json: #{err}"
+      raise ArgumentError, _("Invalid 'name' field in metadata.json: %{err}") % { err: err }
     end
 
     # Validates that the version string can be parsed as per SemVer.
     def validate_version(version)
-      return if SemVer.valid?(version)
+      return if SemanticPuppet::Version.valid?(version)
 
-      err = "version string cannot be parsed as a valid Semantic Version"
-      raise ArgumentError, "Invalid 'version' field in metadata.json: #{err}"
+      err = _("version string cannot be parsed as a valid Semantic Version")
+      raise ArgumentError, _("Invalid 'version' field in metadata.json: %{err}") % { err: err }
     end
 
     # Validates that the given _value_ is a symbolic name that starts with a letter
@@ -200,22 +200,24 @@ module Puppet::ModuleTool
     #
     # @param value [Object] The value to be tested
     def validate_data_provider(value)
-      err = nil
       if value.is_a?(String)
         unless value =~ /^[a-zA-Z][a-zA-Z0-9_]*$/
-          err = value =~ /^[a-zA-Z]/ ? 'contains non-alphanumeric characters' : 'must begin with a letter'
+          if value =~ /^[a-zA-Z]/
+            raise ArgumentError, _("field 'data_provider' contains non-alphanumeric characters")
+          else
+            raise ArgumentError, _("field 'data_provider' must begin with a letter")
+          end
         end
       else
-        err = 'must be a string'
+        raise ArgumentError, _("field 'data_provider' must be a string")
       end
-      raise ArgumentError, "field 'data_provider' #{err}" if err
     end
 
     # Validates that the version range can be parsed by Semantic.
     def validate_version_range(version_range)
-      Semantic::VersionRange.parse(version_range)
+      SemanticPuppet::VersionRange.parse(version_range)
     rescue ArgumentError => e
-      raise ArgumentError, "Invalid 'version_range' field in metadata.json: #{e}"
+      raise ArgumentError, _("Invalid 'version_range' field in metadata.json: %{err}") % { err: e }
     end
   end
 end
