@@ -1,5 +1,6 @@
 require 'openssl'
 require 'net/http'
+require 'puppet/util/http_proxy'
 
 # Factory for <tt>Net::HTTP</tt> objects.
 #
@@ -23,17 +24,28 @@ class Puppet::Network::HTTP::Factory
     Puppet.debug("Creating new connection for #{site}")
 
     args = [site.host, site.port]
-    if Puppet[:http_proxy_host] == "none"
-      args << nil << nil
-    else
-      args << Puppet[:http_proxy_host] << Puppet[:http_proxy_port]
+
+    unless Puppet::Util::HttpProxy.no_proxy?(site)
+      if Puppet[:http_proxy_host] == "none"
+        args << nil << nil
+      else
+        args << Puppet[:http_proxy_host] << Puppet[:http_proxy_port]
+      end
     end
 
     http = Net::HTTP.new(*args)
     http.use_ssl = site.use_ssl?
-    # Use configured timeout (#1176)
-    http.read_timeout = Puppet[:configtimeout]
-    http.open_timeout = Puppet[:configtimeout]
+    http.read_timeout = Puppet[:http_read_timeout]
+    http.open_timeout = Puppet[:http_connect_timeout]
+
+    if Puppet[:sourceaddress]
+      if http.respond_to?(:local_host)
+        Puppet.debug("Using source IP #{Puppet[:sourceaddress]}")
+        http.local_host = Puppet[:sourceaddress]
+      else
+        raise ArgumentError, "Setting 'sourceaddress' is unsupported by this version of Net::HTTP."
+      end
+    end
 
     if Puppet[:http_debug]
       http.set_debug_output($stderr)
