@@ -70,8 +70,8 @@ class Puppet::Parser::TypeLoader
           Puppet.debug {"Automatically imported #{fqname} from #{filename} into #{environment}"}
           return result
         end
-      rescue TypeLoaderError => detail
-        # I'm not convienced we should just drop these errors, but this
+      rescue TypeLoaderError
+        # I'm not convinced we should just drop these errors, but this
         # preserves existing behaviours.
       end
     end
@@ -98,7 +98,7 @@ class Puppet::Parser::TypeLoader
   end
 
   def raise_no_files_found(pattern)
-    raise TypeLoaderError, "No file(s) found for import of '#{pattern}'"
+    raise TypeLoaderError, _("No file(s) found for import of '%{pattern}'") % { pattern: pattern }
   end
 
   def load_files(modname, files)
