@@ -1,5 +1,6 @@
 # Provides utility methods
-module Puppet::Pops::Utils
+module Puppet::Pops
+module Utils
   # Can the given o be converted to numeric? (or is numeric already)
   # Accepts a leading '::'
   # Returns a boolean if the value is numeric
@@ -10,11 +11,11 @@ module Puppet::Pops::Utils
     when Numeric
       true
     else
-      !!Puppet::Pops::Patterns::NUMERIC.match(relativize_name(o.to_s))
+      !!Patterns::NUMERIC.match(relativize_name(o.to_s))
     end
   end
 
-  # Convert a match from Puppet::Pops::Patterns::NUMERIC to floating point value if
+  # Convert a match from Patterns::NUMERIC to floating point value if
   # possible
   def self.match_to_fp(match)
     if match[5].to_s.length > 0
@@ -25,7 +26,7 @@ module Puppet::Pops::Utils
         nil
       else
         fp_value = Float(match[2])
-        if fp_value != Puppet::Pops::Types::TypeCalculator::TheInfinity
+        if fp_value != Float::INFINITY
           match[1] == '-' ? -fp_value : fp_value
         else
           nil
@@ -45,7 +46,7 @@ module Puppet::Pops::Utils
     begin
       case o
       when String
-        match = Puppet::Pops::Patterns::NUMERIC.match(relativize_name(o))
+        match = Patterns::NUMERIC.match(relativize_name(o))
         if !match
           nil
         elsif match[5].to_s.length > 0
@@ -84,7 +85,7 @@ module Puppet::Pops::Utils
     begin
       case o
       when String
-        match = Puppet::Pops::Patterns::NUMERIC.match(relativize_name(o))
+        match = Patterns::NUMERIC.match(relativize_name(o))
         if !match
           nil
         elsif match[5].to_s.length > 0
@@ -114,29 +115,5 @@ module Puppet::Pops::Utils
   def self.relativize_name name
     is_absolute?(name) ? name[2..-1] : name
   end
-
-  # Finds an existing adapter for o or for one of its containers, or nil, if none of the containers
-  # was adapted with the given adapter.
-  # This method can only be used with objects that respond to `:eContainer`.
-  # with true.
-  #
-  # @see #find_closest_positioned
-  #
-  def self.find_adapter(o, adapter)
-    return nil if o.nil? || (o.is_a?(Array) && o.empty?)
-    a = adapter.get(o)
-    return a if a
-    return find_adapter(o.eContainer, adapter)
-  end
-
-  # Finds the closest positioned Puppet::Pops::Model::Positioned object, or object decorated with
-  # a SourcePosAdapter, and returns
-  # a SourcePosAdapter for the first found, or nil if not found.
-  #
-  def self.find_closest_positioned(o)
-    return nil if o.nil? || o.is_a?(Puppet::Pops::Model::Program) || (o.is_a?(Array) && o.empty?)
-    return find_adapter(o, Puppet::Pops::Adapters::SourcePosAdapter) unless o.is_a?(Puppet::Pops::Model::Positioned)
-    o.offset.nil? ? find_closest_positioned(o.eContainer) : Puppet::Pops::Adapters::SourcePosAdapter.adapt(o)
-  end
-
+end
 end
