@@ -6,8 +6,7 @@ class Puppet::Provider::Exec < Puppet::Provider
 
   def run(command, check = false)
     output = nil
-    status = nil
-    dir = nil
+    sensitive = resource.parameters[:command].sensitive
 
     checkexe(command)
 
@@ -16,14 +15,14 @@ class Puppet::Provider::Exec < Puppet::Provider
         if check
           dir = nil
         else
-          self.fail "Working directory '#{dir}' does not exist"
+          self.fail _("Working directory '%{dir}' does not exist") % { dir: dir }
         end
       end
     end
 
     dir ||= Dir.pwd
 
-    debug "Executing#{check ? " check": ""} '#{command}'"
+    debug "Executing#{check ? " check": ""} '#{sensitive ? '[redacted]' : command}'"
     begin
       # Do our chdir
       Dir.chdir(dir) do
@@ -38,37 +37,29 @@ class Puppet::Provider::Exec < Puppet::Provider
               env_name = $1
               value = $2
               if environment.include?(env_name) || environment.include?(env_name.to_sym)
-                warning "Overriding environment setting '#{env_name}' with '#{value}'"
+                warning _("Overriding environment setting '%{env_name}' with '%{value}'") % { env_name: env_name, value: value }
               end
               environment[env_name] = value
             else
-              warning "Cannot understand environment setting #{setting.inspect}"
+              warning _("Cannot understand environment setting %{setting}") % { setting: setting.inspect }
             end
           end
         end
 
-        if Puppet.features.microsoft_windows?
-          exec_user = resource[:user]
-        # Etc.getpwuid() returns nil on Windows
-        elsif resource.current_username == resource[:user]
-          exec_user = nil
-        else
-          exec_user = resource[:user]
-        end
-
         # Ruby 2.1 and later interrupt execution in a way that bypasses error
         # handling by default. Passing Timeout::Error causes an exception to be
         # raised that can be rescued inside of the block by cleanup routines.
         #
         # This is backwards compatible all the way to Ruby 1.8.7.
-        Timeout.timeout(resource[:timeout], Timeout::Error) do
+        Timeout::timeout(resource[:timeout], Timeout::Error) do
           # note that we are passing "false" for the "override_locale" parameter, which ensures that the user's
           # default/system locale will be respected.  Callers may override this behavior by setting locale-related
           # environment variables (LANG, LC_ALL, etc.) in their 'environment' configuration.
           output = Puppet::Util::Execution.execute(command, :failonfail => false, :combine => true,
-                                  :uid => exec_user, :gid => resource[:group],
+                                  :uid => resource[:user], :gid => resource[:group],
                                   :override_locale => false,
-                                  :custom_environment => environment)
+                                  :custom_environment => environment,
+                                  :sensitive => sensitive)
         end
         # The shell returns 127 if the command is missing.
         if output.exitstatus == 127
@@ -100,6 +91,6 @@ class Puppet::Provider::Exec < Puppet::Provider
   def validatecmd(command)
     exe = extractexe(command)
     # if we're not fully qualified, require a path
-    self.fail "'#{command}' is not qualified and no path was specified. Please qualify the command or specify a path." if !absolute_path?(exe) and resource[:path].nil?
+    self.fail _("'%{command}' is not qualified and no path was specified. Please qualify the command or specify a path.") % { command: command } if !absolute_path?(exe) and resource[:path].nil?
   end
 end
