@@ -18,7 +18,7 @@ Puppet::Type.type(:package).provide :aptitude, :parent => :apt, :source => :dpkg
     # Yay, stupid aptitude doesn't throw an error when the package is missing.
     if args.include?(:install) and output =~ /Couldn't find any package/
       raise Puppet::Error.new(
-        "Could not find package #{self.name}"
+        _("Could not find package %{name}") % { name: self.name }
       )
     end
   end
@@ -27,4 +27,3 @@ Puppet::Type.type(:package).provide :aptitude, :parent => :apt, :source => :dpkg
     aptitude '-y', 'purge', @resource[:name]
   end
 end
-
