@@ -35,7 +35,7 @@ class Puppet::Provider::Package::Windows
           mode |= KEY_READ
           begin
             open(hive, 'Software\Microsoft\Windows\CurrentVersion\Uninstall', mode) do |uninstall|
-              uninstall.each_key do |name, wtime|
+              each_key(uninstall) do |name, wtime|
                 open(hive, "#{uninstall.keyname}\\#{name}", mode) do |key|
                   yield key, values(key)
                 end
@@ -50,7 +50,7 @@ class Puppet::Provider::Package::Windows
 
     # Get the class that knows how to install this resource
     def self.installer_class(resource)
-      fail("The source parameter is required when using the Windows provider.") unless resource[:source]
+      fail(_("The source parameter is required when using the Windows provider.")) unless resource[:source]
 
       case resource[:source]
       when /\.msi"?\Z/i
@@ -58,10 +58,10 @@ class Puppet::Provider::Package::Windows
         # REMIND: what about msp, etc
         MsiPackage
       when /\.exe"?\Z/i
-        fail("The source does not exist: '#{resource[:source]}'") unless Puppet::FileSystem.exist?(resource[:source])
+        fail(_("The source does not exist: '%{source}'") % { source: resource[:source] }) unless Puppet::FileSystem.exist?(resource[:source])
         ExePackage
       else
-        fail("Don't know how to install '#{resource[:source]}'")
+        fail(_("Don't know how to install '%{source}'") % { source: resource[:source] })
       end
     end
 
@@ -71,7 +71,7 @@ class Puppet::Provider::Package::Windows
 
     def self.replace_forward_slashes(value)
       if value.include?('/')
-        value.gsub!('/', "\\") 
+        value.gsub!('/', "\\")
         Puppet.debug('Package source parameter contained /s - replaced with \\s')
       end
       value
@@ -81,6 +81,14 @@ class Puppet::Provider::Package::Windows
       value.include?(' ') ? %Q["#{value.gsub(/"/, '\"')}"] : value
     end
 
+    def self.get_display_name(values)
+      return if values.nil?
+      return values['DisplayName'] if values['DisplayName'] && values['DisplayName'].length > 0
+      return values['QuietDisplayName'] if values['QuietDisplayName'] && values['QuietDisplayName'].length > 0
+
+      ''
+    end
+
     def initialize(name, version)
       @name = name
       @version = version
