@@ -43,7 +43,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
     elsif klass = Puppet::Util::FileType.filetype(type)
       @filetype = klass
     else
-      raise ArgumentError, "Invalid filetype #{type}"
+      raise ArgumentError, _("Invalid filetype %{type}") % { type: type }
     end
   end
 
@@ -109,7 +109,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
   # An optional regular expression matched by third party headers.
   #
   # For example, this can be used to filter the vixie cron headers as
-  # erronously exported by older cron versions.
+  # erroneously exported by older cron versions.
   #
   # @api private
   # @abstract Providers based on ParsedFile may implement this to make it
@@ -120,7 +120,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
   #   The expression must be tailored to match exactly one third party header.
   # @see drop_native_header
   # @note When specifying regular expressions in multiline mode, avoid
-  #   greedy repititions such as '.*' (use .*? instead). Otherwise, the
+  #   greedy repetitions such as '.*' (use .*? instead). Otherwise, the
   #   provider may drop file content between sparse headers.
   def self.native_header_regex
     nil
@@ -265,7 +265,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
       target_records = retrieve(target)
     rescue Puppet::Util::FileType::FileReadError => detail
       puts detail.backtrace if Puppet[:trace]
-      Puppet.err "Could not prefetch #{self.resource_type.name} provider '#{self.name}' target '#{target}': #{detail}. Treating as empty"
+      Puppet.err _("Could not prefetch %{resource} provider '%{name}' target '%{target}': %{detail}. Treating as empty") % { resource: self.resource_type.name, name: self.name, target: target, detail: detail }
       target_records = []
     end
 
@@ -277,7 +277,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
 
     target_records = prefetch_hook(target_records) if respond_to?(:prefetch_hook)
 
-    raise Puppet::DevError, "Prefetching #{target} for provider #{self.name} returned nil" unless target_records
+    raise Puppet::DevError, _("Prefetching %{target} for provider %{name} returned nil") % { target: target, name: self.name } unless target_records
 
     target_records
   end
@@ -350,7 +350,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
   def self.targets(resources = nil)
     targets = []
     # First get the default target
-    raise Puppet::DevError, "Parsed Providers must define a default target" unless self.default_target
+    raise Puppet::DevError, _("Parsed Providers must define a default target") unless self.default_target
     targets << self.default_target
 
     # Then get each of the file objects
@@ -439,7 +439,7 @@ class Puppet::Provider::ParsedFile < Puppet::Provider
 
   # Retrieve the current state from disk.
   def prefetch
-    raise Puppet::DevError, "Somehow got told to prefetch with no resource set" unless @resource
+    raise Puppet::DevError, _("Somehow got told to prefetch with no resource set") unless @resource
     self.class.prefetch(@resource[:name] => @resource)
   end
 
