@@ -11,26 +11,54 @@ Puppet::Type.type(:service).provide :base, :parent => :service do
 
   commands :kill => "kill"
 
+  # get the proper 'ps' invocation for the platform
+  # ported from the facter 2.x implementation, since facter 3.x
+  # is dropping the fact (for which this was the only use)
+  def getps
+    case Facter.value(:operatingsystem)
+    when 'OpenWrt'
+      'ps www'
+    when 'FreeBSD', 'NetBSD', 'OpenBSD', 'Darwin', 'DragonFly'
+      'ps auxwww'
+    else
+      'ps -ef'
+     end
+  end
+  private :getps
+
   # Get the process ID for a running process. Requires the 'pattern'
   # parameter.
   def getpid
     @resource.fail "Either stop/status commands or a pattern must be specified" unless @resource[:pattern]
-    ps = Facter["ps"].value
-    @resource.fail "You must upgrade Facter to a version that includes 'ps'" unless ps and ps != ""
     regex = Regexp.new(@resource[:pattern])
+    ps = getps
+
     self.debug "Executing '#{ps}'"
-    IO.popen(ps) { |table|
-      table.each_line { |line|
-        if regex.match(line)
-          self.debug "Process matched: #{line}"
-          ary = line.sub(/^\s+/, '').split(/\s+/)
-          return ary[1]
-        end
-      }
+    table = Puppet::Util::Execution.execute(ps)
+
+    # The output of the PS command can be a mashup of several different
+    # encodings depending on which processes are running and what
+    # arbitrary data has been used to set their name in the process table.
+    #
+    # First, try a polite conversion to in order to match the UTF-8 encoding
+    # of our regular expression.
+    table = Puppet::Util::CharacterEncoding.convert_to_utf_8(table)
+    # If that fails, force to UTF-8 and then scrub as most uses are scanning
+    # for ACII-compatible program names.
+    table.force_encoding(Encoding::UTF_8) unless table.encoding == Encoding::UTF_8
+    table = Puppet::Util::CharacterEncoding.scrub(table) unless table.valid_encoding?
+
+    table.each_line { |line|
+      if regex.match(line)
+        self.debug "Process matched: #{line}"
+        ary = line.sub(/^[[:space:]]+/u, '').split(/[[:space:]]+/u)
+        return ary[1]
+      end
     }
 
     nil
   end
+  private :getpid
 
   # Check if the process is running.  Prefer the 'status' parameter,
   # then 'statuscmd' method, then look in the process table.  We give
@@ -42,13 +70,13 @@ Puppet::Type.type(:service).provide :base, :parent => :service do
       # Don't fail when the exit status is not 0.
       ucommand(:status, false)
 
-      # Expicitly calling exitstatus to facilitate testing
+      # Explicitly calling exitstatus to facilitate testing
       if $CHILD_STATUS.exitstatus == 0
         return :running
       else
         return :stopped
       end
-    elsif pid = self.getpid
+    elsif pid = getpid
       self.debug "PID is #{pid}"
       return :running
     else
@@ -87,7 +115,7 @@ Puppet::Type.type(:service).provide :base, :parent => :service do
     else
       pid = getpid
       unless pid
-        self.info "#{self.name} is not running"
+        self.info _("%{name} is not running") % { name: self.name }
         return false
       end
       begin
