@@ -19,7 +19,7 @@ reference = Puppet::Util::Reference.newreference :indirection, :doc => "Indirect
         terminus_doc = Puppet::Util::Docs.scrub(term_class.doc)
         text << markdown_header("`#{terminus_name}` terminus", 3) << terminus_doc << "\n\n"
       else
-        Puppet.warning "Could not build docs for indirector #{name.inspect}, terminus #{terminus_name.inspect}: could not locate terminus."
+        Puppet.warning _("Could not build docs for indirector %{name}, terminus %{terminus}: could not locate terminus.") % { name: name.inspect, terminus: terminus_name.inspect }
       end
     end
   end
@@ -41,7 +41,7 @@ An indirector has five methods, which are mapped into HTTP verbs for the REST in
 * `find(key)` - get a single value (mapped to GET or POST with a singular endpoint)
 * `search(key)` - get a list of matching values (mapped to GET with a plural endpoint)
 * `head(key)` - return true if the key exists (mapped to HEAD)
-* `destroy(key)` - remove the key van value (mapped to DELETE)
+* `destroy(key)` - remove the key and value (mapped to DELETE)
 * `save(instance)` - write the instance to the store, using the instance's name as the key (mapped to PUT)
 
 These methods are available via the `indirection` class method on the indirected classes.  For example:
