@@ -2,34 +2,23 @@ require 'puppet/settings/errors'
 
 # The base setting type
 class Puppet::Settings::BaseSetting
-  attr_accessor :name, :desc, :section, :default, :call_on_define, :call_hook
+  attr_accessor :name, :desc, :section, :default, :call_hook
   attr_reader :short, :deprecated
 
   def self.available_call_hook_values
     [:on_define_and_write, :on_initialize_and_write, :on_write_only]
   end
 
-  def call_on_define
-    Puppet.deprecation_warning "call_on_define has been deprecated.  Please use call_hook_on_define?"
-    call_hook_on_define?
-  end
-
-  def call_on_define=(value)
-    if value
-      Puppet.deprecation_warning ":call_on_define has been changed to :call_hook => :on_define_and_write. Please change #{name}."
-      @call_hook = :on_define_and_write
-    else
-      Puppet.deprecation_warning ":call_on_define => :false has been changed to :call_hook => :on_write_only. Please change #{name}."
-      @call_hook = :on_write_only
-    end
-  end
-
   def call_hook=(value)
     if value.nil?
-      Puppet.warning "Setting :#{name} :call_hook is nil, defaulting to :on_write_only"
-      value ||= :on_write_only
+      #TRANSLATORS ':%{name}', ':call_hook', and ':on_write_only' should not be translated
+      Puppet.warning _("Setting :%{name} :call_hook is nil, defaulting to :on_write_only") % { name: name }
+      value = :on_write_only
+    end
+    unless self.class.available_call_hook_values.include?(value)
+      #TRANSLATORS 'call_hook' is a Puppet option name and should not be translated
+      raise ArgumentError, _("Invalid option %{value} for call_hook") % { value: value }
     end
-    raise ArgumentError, "Invalid option #{value} for call_hook" unless self.class.available_call_hook_values.include? value
     @call_hook = value
   end
 
@@ -41,19 +30,6 @@ class Puppet::Settings::BaseSetting
     call_hook == :on_initialize_and_write
   end
 
-  #added as a proper method, only to generate a deprecation warning
-  #and return value from
-  def setbycli
-    Puppet.deprecation_warning "Puppet.settings.setting(#{name}).setbycli is deprecated. Use Puppet.settings.set_by_cli?(#{name}) instead."
-    @settings.set_by_cli?(name)
-  end
-
-  def setbycli=(value)
-    Puppet.deprecation_warning "Puppet.settings.setting(#{name}).setbycli= is deprecated. You should not manually set that values were specified on the command line."
-    @settings.set_value(name, @settings[name], :cli) if value
-    raise ArgumentError, "Cannot unset setbycli" unless value
-  end
-
   # get the arguments in getopt format
   def getopt_args
     if short
@@ -95,16 +71,23 @@ class Puppet::Settings::BaseSetting
     @call_hook = :on_write_only if args[:hook] and not args[:call_hook]
     @has_hook = false
 
-    raise ArgumentError, "Cannot reference :call_hook for :#{@name} if no :hook is defined" if args[:call_hook] and not args[:hook]
+    if args[:call_hook] and not args[:hook]
+      #TRANSLATORS ':call_hook' and ':hook' are specific setting names and should not be translated
+      raise ArgumentError, _("Cannot reference :call_hook for :%{name} if no :hook is defined") % { name: @name }
+    end
 
     args.each do |param, value|
       method = param.to_s + "="
-      raise ArgumentError, "#{self.class} (setting '#{args[:name]}') does not accept #{param}" unless self.respond_to? method
+      unless self.respond_to? method
+        raise ArgumentError, _("%{class_name} (setting '%{setting}') does not accept %{parameter}") %
+            { class_name: self.class, setting: args[:name], parameter: param }
+      end
 
       self.send(method, value)
     end
-
-    raise ArgumentError, "You must provide a description for the #{self.name} config option" unless self.desc
+    unless self.desc
+      raise ArgumentError, _("You must provide a description for the %{class_name} config option") % { class_name: self.name }
+    end
   end
 
   def iscreated
@@ -115,18 +98,24 @@ class Puppet::Settings::BaseSetting
     @iscreated
   end
 
-  # short name for the celement
+  # short name for the element
   def short=(value)
-    raise ArgumentError, "Short names can only be one character." if value.to_s.length != 1
+    raise ArgumentError, _("Short names can only be one character.") if value.to_s.length != 1
     @short = value.to_s
   end
 
   def default(check_application_defaults_first = false)
     if @default.is_a? Proc
-      @default = @default.call
+      # Give unit tests a chance to reevaluate the call by removing the instance variable
+      unless instance_variable_defined?(:@evaluated_default)
+        @evaluated_default = @default.call
+      end
+      default_value = @evaluated_default
+    else
+      default_value = @default
     end
-    return @default unless check_application_defaults_first
-    return @settings.value(name, :application_defaults, true) || @default
+    return default_value unless check_application_defaults_first
+    return @settings.value(name, :application_defaults, true) || default_value
   end
 
   # Convert the object to a config statement.
@@ -173,7 +162,11 @@ class Puppet::Settings::BaseSetting
   end
 
   def deprecated=(deprecation)
-    raise(ArgumentError, "'#{deprecation}' is an unknown setting deprecation state.  Must be either :completely or :allowed_on_commandline") unless [:completely, :allowed_on_commandline].include?(deprecation)
+    unless [:completely, :allowed_on_commandline].include?(deprecation)
+      #TRANSLATORS 'deprecated' is a Puppet setting and ':completely' and ':allowed_on_commandline' are possible values and should not be translated
+      raise ArgumentError, _("Unsupported deprecated value '%{deprecation}'.") % { deprecation: deprecation } +
+          ' ' + _("Supported values for deprecated are ':completely' or ':allowed_on_commandline'")
+    end
     @deprecated = deprecation
   end
 
@@ -192,4 +185,8 @@ class Puppet::Settings::BaseSetting
   def allowed_on_commandline?
     @deprecated == :allowed_on_commandline
   end
+
+  def inspect
+    %Q{<#{self.class}:#{self.object_id} @name="#{@name}" @section="#{@section}" @default="#{@default}" @call_hook="#{@call_hook}">}
+  end
 end
