@@ -1,5 +1,3 @@
-require 'puppet/indirector/data_binding/hiera'
-
 require 'tmpdir'
 require 'fileutils'
 
@@ -38,7 +36,7 @@ module Puppet::Test
     def self.initialize()
       # This meta class instance variable is used as a guard to ensure that
       # before_each, and after_each are only called once. This problem occurs
-      # when there are more than one puppet test infrastructure "orchestrator in us.
+      # when there are more than one puppet test infrastructure orchestrator in use.
       # The use of both puppetabs-spec_helper, and rodjek-rspec_puppet will cause
       # two resets of the puppet environment, and will cause problem rolling back to
       # a known point as there is no way to differentiate where the calls are coming
@@ -49,13 +47,21 @@ module Puppet::Test
       #
       @@reentry_count ||= 0
 
+      @environmentpath = Dir.mktmpdir('environments')
+      Dir.mkdir("#{@environmentpath}/production")
       owner = Process.pid
       Puppet.push_context(Puppet.base_context({
-        :environmentpath => "",
+        :environmentpath => @environmentpath,
         :basemodulepath => "",
-        :manifest => "/dev/null"
       }), "Initial for specs")
       Puppet::Parser::Functions.reset
+
+      ObjectSpace.define_finalizer(Puppet.lookup(:environments), proc {
+        if Process.pid == owner
+          FileUtils.rm_rf(@environmentpath)
+        end
+      })
+      Puppet::SSL::Oids.register_puppet_oids
     end
 
     # Call this method once, when beginning a test run--prior to running
@@ -76,7 +82,7 @@ module Puppet::Test
     #
     ROLLBACK_MARK = "initial testing state"
 
-    # Call this method once per test, prior to execution of each invididual test.
+    # Call this method once per test, prior to execution of each individual test.
     # @return nil
     def self.before_each_test()
       # When using both rspec-puppet and puppet-rspec-helper, there are two packages trying
@@ -113,7 +119,13 @@ module Puppet::Test
       end
 
       # The process environment is a shared, persistent resource.
-      $old_env = ENV.to_hash
+      # Can't use Puppet.features.microsoft_windows? as it may be mocked out in a test.  This can cause test recurring test failures
+      if (!!File::ALT_SEPARATOR)
+        mode = :windows
+      else
+        mode = :posix
+      end
+      $old_env = Puppet::Util.get_environment(mode)
 
       # So is the load_path
       $old_load_path = $LOAD_PATH.dup
@@ -128,13 +140,10 @@ module Puppet::Test
         "Context for specs")
 
       Puppet::Parser::Functions.reset
-      Puppet::Node::Environment.clear
       Puppet::Application.clear!
       Puppet::Util::Profiler.clear
 
       Puppet.clear_deprecation_warnings
-
-      Puppet::DataBinding::Hiera.instance_variable_set("@hiera", nil)
     end
 
     # Call this method once per test, after execution of each individual test.
@@ -164,23 +173,23 @@ module Puppet::Test
       end
       $saved_indirection_state = nil
 
+      # Can't use Puppet.features.microsoft_windows? as it may be mocked out in a test.  This can cause test recurring test failures
+      if (!!File::ALT_SEPARATOR)
+        mode = :windows
+      else
+        mode = :posix
+      end
       # Restore the global process environment.  Can't just assign because this
       # is a magic variable, sadly, and doesn't do that™.  It is sufficiently
       # faster to use the compare-then-set model to avoid excessive work that it
       # justifies the complexity.  --daniel 2012-03-15
-      unless ENV.to_hash == $old_env
-        ENV.clear
-        $old_env.each {|k, v| ENV[k] = v }
+      unless Puppet::Util.get_environment(mode) == $old_env
+        Puppet::Util.clear_environment(mode)
+        $old_env.each {|k, v| Puppet::Util.set_env(k, v, mode) }
       end
 
-
-      # Some tests can cause us to connect, in which case the lingering
-      # connection is a resource that can cause unexpected failure in later
-      # tests, as well as sharing state accidentally.
-      # We're testing if ActiveRecord::Base is defined because some test cases
-      # may stub Puppet.features.rails? which is how we should normally
-      # introspect for this functionality.
-      ActiveRecord::Base.remove_connection if defined?(ActiveRecord::Base)
+      # Clear all environments
+      Puppet.lookup(:environments).clear_all
 
       # Restore the load_path late, to avoid messing with stubs from the test.
       $LOAD_PATH.clear
@@ -199,6 +208,7 @@ module Puppet::Test
       {
           :logdir     => "/dev/null",
           :confdir    => "/dev/null",
+          :codedir    => "/dev/null",
           :vardir     => "/dev/null",
           :rundir     => "/dev/null",
           :hiera_config => "/dev/null",
@@ -227,7 +237,6 @@ module Puppet::Test
       #
       # I would make these even shorter, but OpenSSL doesn't support anything
       # below 512 bits.  Sad, really, because a 0 bit key would be just fine.
-      Puppet[:req_bits]  = 512
       Puppet[:keylength] = 512
 
       # Although we setup a testing context during initialization, some tests
