@@ -6,7 +6,7 @@
 # drwxr-xr-x  root root system_u:object_r:root_t         /
 #
 # The context of '/' here is 'system_u:object_r:root_t'.  This is
-# three seperate fields:
+# three separate fields:
 #
 # system_u is the user context
 # object_r is the role context
@@ -17,7 +17,7 @@
 # command.  This allows the user to specify a subset of the three
 # values while leaving the others alone.
 #
-# See http://www.nsa.gov/selinux/ for complete docs on SELinux.
+# See https://www.nsa.gov/selinux/ for complete docs on SELinux.
 
 
 module Puppet
@@ -29,7 +29,12 @@ module Puppet
     def retrieve
       return :absent unless @resource.stat
       context = self.get_selinux_current_context(@resource[:path])
-      parse_selinux_context(name, context)
+      is = parse_selinux_context(name, context)
+      if name == :selrange and selinux_support?
+        self.selinux_category_to_label(is)
+      else
+        is
+      end
     end
 
     def retrieve_default_context(property)
@@ -58,6 +63,18 @@ module Puppet
       end
     end
 
+    def unsafe_munge(should)
+      if not selinux_support?
+        return should
+      end
+
+      if name == :selrange
+        self.selinux_category_to_label(should)
+      else
+        should
+      end
+    end
+
     def sync
       self.set_selinux_context(@resource[:path], @should, name)
       :file_changed
