@@ -4,7 +4,7 @@ require 'puppet/parameter/boolean'
 Puppet::Type.newtype(:resources) do
   @doc = "This is a metatype that can manage other resource types.  Any
     metaparams specified here will be passed on to any generated resources,
-    so you can purge umanaged resources but set `noop` to true so the
+    so you can purge unmanaged resources but set `noop` to true so the
     purging is only logged and does not actually happen."
 
 
@@ -12,7 +12,7 @@ Puppet::Type.newtype(:resources) do
     desc "The name of the type to be managed."
 
     validate do |name|
-      raise ArgumentError, "Could not find resource type '#{name}'" unless Puppet::Type.type(name)
+      raise ArgumentError, _("Could not find resource type '%{name}'") % { name: name } unless Puppet::Type.type(name)
     end
 
     munge { |v| v.to_s }
@@ -30,9 +30,9 @@ Puppet::Type.newtype(:resources) do
     validate do |value|
       if munge(value)
         unless @resource.resource_type.respond_to?(:instances)
-          raise ArgumentError, "Purging resources of type #{@resource[:name]} is not supported, since they cannot be queried from the system"
+          raise ArgumentError, _("Purging resources of type %{res_type} is not supported, since they cannot be queried from the system") % { res_type: @resource[:name] }
         end
-        raise ArgumentError, "Purging is only supported on types that accept 'ensure'" unless @resource.resource_type.validproperty?(:ensure)
+        raise ArgumentError, _("Purging is only supported on types that accept 'ensure'") unless @resource.resource_type.validproperty?(:ensure)
       end
     end
   end
@@ -54,7 +54,7 @@ Puppet::Type.newtype(:resources) do
         false
       when Integer; value
       else
-        raise ArgumentError, "Invalid value #{value.inspect}"
+        raise ArgumentError, _("Invalid value %{value}") % { value: value.inspect }
       end
     end
 
@@ -81,7 +81,7 @@ Puppet::Type.newtype(:resources) do
           when String
             Integer(v)
           else
-            raise ArgumentError, "Invalid value #{v.inspect}."
+            raise ArgumentError, _("Invalid value %{value}.") % { value: v.inspect }
         end
       end
     end
@@ -100,7 +100,7 @@ Puppet::Type.newtype(:resources) do
   def able_to_ensure_absent?(resource)
       resource[:ensure] = :absent
   rescue ArgumentError, Puppet::Error
-      err "The 'ensure' attribute on #{self[:name]} resources does not accept 'absent' as a value"
+      err _("The 'ensure' attribute on %{name} resources does not accept 'absent' as a value") % { name: self[:name] }
       false
   end
 
@@ -127,20 +127,13 @@ Puppet::Type.newtype(:resources) do
   def resource_type
     unless defined?(@resource_type)
       unless type = Puppet::Type.type(self[:name])
-        raise Puppet::DevError, "Could not find resource type"
+        raise Puppet::DevError, _("Could not find resource type")
       end
       @resource_type = type
     end
     @resource_type
   end
 
-  def self.deprecate_params(title,params)
-    return unless params
-    if title == 'cron' and ! params.select { |param| param.name.intern == :purge and param.value == true }.empty?
-      Puppet.deprecation_warning("Change notice: purging cron entries will be more aggressive in future versions, take care when updating your agents. See http://links.puppetlabs.com/puppet-aggressive-cron-purge")
-    end
-  end
-
   # Make sure we don't purge users with specific uids
   def user_check(resource)
     return true unless self[:name] == "user"
