@@ -11,15 +11,25 @@ Puppet::Type.newtype(:yumrepo) do
 
     Continuation lines that yum supports (for the `baseurl`, for example)
     are not supported. This type does not attempt to read or verify the
-    exinstence of files listed in the `include` attribute."
+    existence of files listed in the `include` attribute."
 
   # Ensure yumrepos can be removed too.
   ensurable
   # Doc string for properties that can be made 'absent'
   ABSENT_DOC="Set this to `absent` to remove it from the file completely."
   # False can be false/0/no and True can be true/1/yes in yum.
-  YUM_BOOLEAN=/(True|False|0|1|No|Yes)/i
-  YUM_BOOLEAN_DOC="Valid values are: False/0/No or True/1/Yes."
+  YUM_BOOLEAN=/^(true|false|0|1|no|yes)$/
+  YUM_BOOLEAN_DOC="Valid values are: false/0/no or true/1/yes."
+
+  # Common munge logic for YUM_BOOLEAN values. Munges for two requirements:
+  # 1) Because of how regex validation works in Puppet::Parameter::Value,
+  # Boolean false and lowercase false will not be considered invalid. However,
+  # if the user specified false (or true), they meant False (or True).
+  # 2) In order for parameter removal to work correctly, when absent is passed
+  # as a string it needs to be munged back to a symbol.
+  munge_yum_bool = Proc.new do |val|
+    val.to_s == 'absent' ? :absent : val.to_s.capitalize
+  end
 
   VALID_SCHEMES = %w[file http https ftp]
 
@@ -52,7 +62,7 @@ Puppet::Type.newtype(:yumrepo) do
       parsed = URI.parse(value)
 
       unless VALID_SCHEMES.include?(parsed.scheme)
-        raise "Must be a valid URL"
+        raise _("Must be a valid URL")
       end
     end
   end
@@ -69,7 +79,7 @@ Puppet::Type.newtype(:yumrepo) do
         parsed = URI.parse(uri)
 
         unless VALID_SCHEMES.include?(parsed.scheme)
-          raise "Must be a valid URL"
+          raise _("Must be a valid URL")
         end
       end
     end
@@ -81,6 +91,7 @@ Puppet::Type.newtype(:yumrepo) do
     #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:gpgcheck) do
@@ -90,6 +101,16 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
+  end
+
+  newproperty(:payload_gpgcheck) do
+    desc "Whether to check the GPG signature of the packages payload.
+      #{YUM_BOOLEAN_DOC}
+      #{ABSENT_DOC}"
+
+    newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:repo_gpgcheck) do
@@ -98,6 +119,7 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:gpgkey) do
@@ -113,12 +135,19 @@ Puppet::Type.newtype(:yumrepo) do
         parsed = URI.parse(uri)
 
         unless VALID_SCHEMES.include?(parsed.scheme)
-          raise "Must be a valid URL"
+          raise _("Must be a valid URL")
         end
       end
     end
   end
 
+  newproperty(:mirrorlist_expire) do
+    desc "Time (in seconds) after which the mirrorlist locally cached
+      will expire.\n#{ABSENT_DOC}"
+
+    newvalues(/^[0-9]+$/, :absent)
+  end
+
   newproperty(:include) do
     desc "The URL of a remote file containing additional yum configuration
       settings. Puppet does not check for this file's existence or validity.
@@ -130,7 +159,7 @@ Puppet::Type.newtype(:yumrepo) do
       parsed = URI.parse(value)
 
       unless VALID_SCHEMES.include?(parsed.scheme)
-        raise "Must be a valid URL"
+        raise _("Must be a valid URL")
       end
     end
   end
@@ -143,10 +172,24 @@ Puppet::Type.newtype(:yumrepo) do
     newvalues(/.*/, :absent)
   end
 
+  newproperty(:gpgcakey) do
+    desc "The URL for the GPG CA key for this repository. #{ABSENT_DOC}"
+
+    newvalues(/.*/, :absent)
+    validate do |value|
+      next if value.to_s == 'absent'
+      parsed = URI.parse(value)
+
+      unless VALID_SCHEMES.include?(parsed.scheme)
+        raise _("Must be a valid URL")
+      end
+    end
+  end
+
   newproperty(:includepkgs) do
     desc "List of shell globs. If this is set, only packages
       matching one of the globs will be considered for
-      update or install from this repo. #{ABSENT_DOC}"
+      update or install from this repository. #{ABSENT_DOC}"
 
     newvalues(/.*/, :absent)
   end
@@ -158,13 +201,14 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:failovermethod) do
     desc "The failover method for this repository; should be either
       `roundrobin` or `priority`. #{ABSENT_DOC}"
 
-    newvalues(/roundrobin|priority/, :absent)
+    newvalues(/^roundrobin|priority$/, :absent)
   end
 
   newproperty(:keepalive) do
@@ -173,26 +217,35 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
+  end
+
+  newproperty(:retries) do
+    desc "Set the number of times any attempt to retrieve a file should
+      retry before returning an error. Setting this to `0` makes yum
+     try forever.\n#{ABSENT_DOC}"
+
+    newvalues(/^[0-9]+$/, :absent)
   end
 
   newproperty(:http_caching) do
     desc "What to cache from this repository. #{ABSENT_DOC}"
 
-    newvalues(/(packages|all|none)/, :absent)
+    newvalues(/^(packages|all|none)$/, :absent)
   end
 
   newproperty(:timeout) do
     desc "Number of seconds to wait for a connection before timing
       out. #{ABSENT_DOC}"
 
-    newvalues(/[0-9]+/, :absent)
+    newvalues(/^\d+$/, :absent)
   end
 
   newproperty(:metadata_expire) do
     desc "Number of seconds after which the metadata will expire.
       #{ABSENT_DOC}"
 
-    newvalues(/[0-9]+/, :absent)
+    newvalues(/^([0-9]+[dhm]?|never)$/, :absent)
   end
 
   newproperty(:protect) do
@@ -202,6 +255,7 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:priority) do
@@ -213,27 +267,49 @@ Puppet::Type.newtype(:yumrepo) do
     validate do |value|
       next if value.to_s == 'absent'
       unless (1..99).include?(value.to_i)
-        fail("Must be within range 1-99")
+        fail(_("Must be within range 1-99"))
       end
     end
   end
 
+  newproperty(:throttle) do
+    desc "Enable bandwidth throttling for downloads. This option
+      can be expressed as a absolute data rate in bytes/sec or a
+      percentage `60%`. An SI prefix (k, M or G) may be appended
+      to the data rate values.\n#{ABSENT_DOC}"
+
+    newvalues(/^\d+[kMG%]?$/, :absent)
+  end
+
+  newproperty(:bandwidth) do
+    desc "Use to specify the maximum available network bandwidth
+      in bytes/second. Used with the `throttle` option. If `throttle`
+      is a percentage and `bandwidth` is `0` then bandwidth throttling
+      will be disabled. If `throttle` is expressed as a data rate then
+      this option is ignored.\n#{ABSENT_DOC}"
+
+    newvalues(/^\d+[kMG]?$/, :absent)
+  end
+
   newproperty(:cost) do
     desc "Cost of this repository. #{ABSENT_DOC}"
 
-    newvalues(/\d+/, :absent)
+    newvalues(/^\d+$/, :absent)
   end
 
   newproperty(:proxy) do
-    desc "URL to the proxy server for this repository. #{ABSENT_DOC}"
+    desc "URL of a proxy server that Yum should use when accessing this repository.
+      This attribute can also be set to `'_none_'`, which will make Yum bypass any
+      global proxy settings when accessing this repository.
+      #{ABSENT_DOC}"
 
     newvalues(/.*/, :absent)
     validate do |value|
-      next if value.to_s == 'absent'
+      next if value.to_s =~ /^(absent|_none_)$/
       parsed = URI.parse(value)
 
       unless VALID_SCHEMES.include?(parsed.scheme)
-        raise "Must be a valid URL"
+        raise _("Must be a valid URL")
       end
     end
   end
@@ -251,11 +327,12 @@ Puppet::Type.newtype(:yumrepo) do
   end
 
   newproperty(:s3_enabled) do
-    desc "Access the repo via S3.
+    desc "Access the repository via S3.
       #{YUM_BOOLEAN_DOC}
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:sslcacert) do
@@ -272,18 +349,19 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
   end
 
   newproperty(:sslclientcert) do
     desc "Path  to the SSL client certificate yum should use to connect
-      to repos/remote sites. #{ABSENT_DOC}"
+      to repositories/remote sites. #{ABSENT_DOC}"
 
     newvalues(/.*/, :absent)
   end
 
   newproperty(:sslclientkey) do
     desc "Path to the SSL client key yum should use to connect
-      to repos/remote sites. #{ABSENT_DOC}"
+      to repositories/remote sites. #{ABSENT_DOC}"
 
     newvalues(/.*/, :absent)
   end
@@ -297,7 +375,7 @@ Puppet::Type.newtype(:yumrepo) do
       parsed = URI.parse(value)
 
       unless VALID_SCHEMES.include?(parsed.scheme)
-        raise "Must be a valid URL"
+        raise _("Must be a valid URL")
       end
     end
   end
@@ -308,5 +386,33 @@ Puppet::Type.newtype(:yumrepo) do
       #{ABSENT_DOC}"
 
     newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
+  end
+
+  newproperty(:assumeyes) do
+    desc "Determines if yum prompts for confirmation of critical actions.
+      #{YUM_BOOLEAN_DOC}
+      #{ABSENT_DOC}"
+
+    newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
+  end
+
+  newproperty(:deltarpm_percentage) do
+    desc "Percentage value that determines when to use deltas for this repository.
+      When the delta is larger than this percentage value of the package, the
+      delta is not used.
+      #{ABSENT_DOC}"
+
+    newvalues(/^\d+$/, :absent)
+  end
+
+  newproperty(:deltarpm_metadata_percentage) do
+    desc "Percentage value that determines when to download deltarpm metadata.
+      When the deltarpm metadata is larger than this percentage value of the
+      package, deltarpm metadata is not downloaded.
+      #{ABSENT_DOC}"
+
+    newvalues(/^\d+$/, :absent)
   end
 end
