@@ -99,7 +99,7 @@ end
       warned = false
       while provider.processing?
         next if warned
-        info "Waiting for zone to finish processing"
+        info _("Waiting for zone to finish processing")
         warned = true
         sleep 1
       end
@@ -115,7 +115,7 @@ end
       # everything between it and us.
       self.class.state_sequence(self.retrieve, self.should).each do |state|
         method = state[direction]
-        raise Puppet::DevError, "Cannot move #{direction} from #{st[:name]}" unless method
+        raise Puppet::DevError, _("Cannot move %{direction} from %{name}") % { direction: direction, name: st[:name] } unless method
         provider_sync_send(method)
       end
 
@@ -171,8 +171,7 @@ end
 
     # overridden so that we match with self.should
     def insync?(is)
-      return true unless is
-      is = [] if is == :absent
+      is = [] if !is || is == :absent
       is.sort == self.should.sort
     end
   end
@@ -197,7 +196,7 @@ end
       Puppet to move a zone. Consequently this is a readonly property."
 
     validate do |value|
-      raise ArgumentError, "The zone base must be fully qualified" unless value =~ /^\//
+      raise ArgumentError, _("The zone base must be fully qualified") unless value =~ /^\//
     end
 
     munge do |value|
@@ -228,14 +227,13 @@ end
 
     # overridden so that we match with self.should
     def insync?(is)
-      return true unless is
-      is = [] if is == :absent
+      is = [] if !is || is == :absent
       is.sort == self.should.sort
     end
 
     validate do |value|
       unless value !~ /^\//
-        raise ArgumentError, "Datasets must be the name of a zfs filesystem"
+        raise ArgumentError, _("Datasets must be the name of a zfs filesystem")
       end
     end
   end
@@ -250,14 +248,13 @@ end
 
     # overridden so that we match with self.should
     def insync?(is)
-      return true unless is
-      is = [] if is == :absent
+      is = [] if !is || is == :absent
       is.sort == self.should.sort
     end
 
     validate do |value|
       unless value =~ /^\//
-        raise ArgumentError, "Inherited filesystems must be fully qualified"
+        raise ArgumentError, _("Inherited filesystems must be fully qualified")
       end
     end
   end
@@ -285,11 +282,11 @@ end
 
       And then call that:
 
-          zone { myzone:
-            ip           => "bge0:192.168.0.23",
-            sysidcfg     => template("site/sysidcfg.erb"),
-            path         => "/opt/zones/myzone",
-            realhostname => "fully.qualified.domain.name"
+          zone { 'myzone':
+            ip           => 'bge0:192.168.0.23',
+            sysidcfg     => template('site/sysidcfg.erb'),
+            path         => '/opt/zones/myzone',
+            realhostname => 'fully.qualified.domain.name',
           }
 
       The `sysidcfg` only matters on the first booting of the zone,
@@ -330,15 +327,15 @@ end
   def validate_ip(ip, name)
     IPAddr.new(ip) if ip
   rescue ArgumentError
-    self.fail Puppet::Error, "'#{ip}' is an invalid #{name}", $!
+    self.fail Puppet::Error, _("'%{ip}' is an invalid %{name}") % { ip: ip, name: name }, $!
   end
 
   def validate_exclusive(interface, address, router)
     return if !interface.nil? and address.nil?
-    self.fail "only interface may be specified when using exclusive IP stack: #{interface}:#{address}"
+    self.fail _("only interface may be specified when using exclusive IP stack: %{interface}:%{address}") % { interface: interface, address: address }
   end
   def validate_shared(interface, address, router)
-    self.fail "ip must contain interface name and ip address separated by a \":\"" if interface.nil? or address.nil?
+    self.fail _("ip must contain interface name and ip address separated by a \":\"") if interface.nil? or address.nil?
     [address, router].each do |ip|
       validate_ip(address, "IP address") unless ip.nil?
     end
@@ -346,7 +343,7 @@ end
 
   validate do
     return unless self[:ip]
-    # self[:ip] reflects the type passed from proeprty:ip.should. If we
+    # self[:ip] reflects the type passed from property:ip.should. If we
     # override it and pass @should, then we get an array here back.
     self[:ip].each do |ip|
       interface, address, router = ip.split(':')
