@@ -1,6 +1,8 @@
 require 'puppet/util/tagging'
 require 'puppet/util/classgen'
+require 'puppet/util/psych_support'
 require 'puppet/network/format_support'
+require 'facter'
 
 # Pass feedback to the user.  Log levels are modeled after syslog's, and it is
 # expected that that will be the most common log destination.  Supports
@@ -8,6 +10,7 @@ require 'puppet/network/format_support'
 class Puppet::Util::Log
   include Puppet::Util
   extend Puppet::Util::ClassGen
+  include Puppet::Util::PsychSupport
   include Puppet::Util::Tagging
   include Puppet::Network::FormatSupport
 
@@ -60,7 +63,8 @@ class Puppet::Util::Log
     destinations.keys.each { |dest|
       close(dest)
     }
-    raise Puppet::DevError.new("Log.close_all failed to close #{@destinations.keys.inspect}") if !@destinations.empty?
+    #TRANSLATORS "Log.close_all" is a method name and should not be translated
+    raise Puppet::DevError.new(_("Log.close_all failed to close %{destinations}") % { destinations: @destinations.keys.inspect }) if !@destinations.empty?
   end
 
   # Flush any log destinations that support such operations.
@@ -79,8 +83,8 @@ class Puppet::Util::Log
   # Create a new log message.  The primary role of this method is to
   # avoid creating log messages below the loglevel.
   def Log.create(hash)
-    raise Puppet::DevError, "Logs require a level" unless hash.include?(:level)
-    raise Puppet::DevError, "Invalid log level #{hash[:level]}" unless @levels.index(hash[:level])
+    raise Puppet::DevError, _("Logs require a level") unless hash.include?(:level)
+    raise Puppet::DevError, _("Invalid log level %{level}") % { level: hash[:level] } unless @levels.index(hash[:level])
     @levels.index(hash[:level]) >= @loglevel ? Puppet::Util::Log.new(hash) : nil
   end
 
@@ -102,9 +106,12 @@ class Puppet::Util::Log
   def Log.level=(level)
     level = level.intern unless level.is_a?(Symbol)
 
-    raise Puppet::DevError, "Invalid loglevel #{level}" unless @levels.include?(level)
+    raise Puppet::DevError, _("Invalid loglevel %{level}") % { level: level } unless @levels.include?(level)
 
     @loglevel = @levels.index(level)
+
+    # Enable or disable Facter debugging
+    Facter.debugging(level == :debug) if Facter.respond_to? :debugging
   end
 
   def Log.levels
@@ -118,7 +125,7 @@ class Puppet::Util::Log
       return
     end
 
-    name, type = @desttypes.find do |name, klass|
+    _, type = @desttypes.find do |name, klass|
       klass.match?(dest)
     end
 
@@ -126,7 +133,7 @@ class Puppet::Util::Log
       return
     end
 
-    raise Puppet::DevError, "Unknown destination type #{dest}" unless type
+    raise Puppet::DevError, _("Unknown destination type %{dest}") % { dest: dest} unless type
 
     begin
       if type.instance_method(:initialize).arity == 1
@@ -157,6 +164,20 @@ class Puppet::Util::Log
     end
   end
 
+  private
+  # produces UTF-8 strings or dumps strings when they cannot be re-encoded
+  def Log.coerce_string(str)
+    return Puppet::Util::CharacterEncoding.convert_to_utf_8(str) if str.valid_encoding?
+
+    # We only select the last 10 callers in the stack to avoid being spammy
+    message = _("Received a Log attribute with invalid encoding:%{log_message}") %
+        { log_message: Puppet::Util::CharacterEncoding.convert_to_utf_8(str.dump)}
+    message += '\n' + _("Backtrace:\n%{backtrace}") % { backtrace: caller[0..10].join("\n") }
+    message
+  end
+
+  public
+
   # Route the actual message. FIXME There are lots of things this method
   # should do, like caching and a bit more.  It's worth noting that there's
   # a potential for a loop here, if the machine somehow gets the destination set as
@@ -164,6 +185,9 @@ class Puppet::Util::Log
   def Log.newmessage(msg)
     return if @levels.index(msg.level) < @loglevel
 
+    msg.message = coerce_string(msg.message)
+    msg.source = coerce_string(msg.source)
+
     queuemessage(msg) if @destinations.length == 0
 
     @destinations.each do |name, dest|
@@ -203,7 +227,7 @@ class Puppet::Util::Log
 
   # Reopen all of our logs.
   def Log.reopen
-    Puppet.notice "Reopening log files"
+    Puppet.notice _("Reopening log files")
     types = @destinations.keys
     @destinations.each { |type, dest|
       dest.close if dest.respond_to?(:close)
@@ -239,11 +263,31 @@ class Puppet::Util::Log
     obj
   end
 
-  def self.from_pson(data)
-    Puppet.deprecation_warning("from_pson is being removed in favour of from_data_hash.")
-    self.from_data_hash(data)
+  # Log output using scope and level
+  #
+  # @param [Puppet::Parser::Scope] scope
+  # @param [Symbol] level log level
+  # @param [Array<Object>] vals the values to log (will be converted to string and joined with space)
+  #
+  def self.log_func(scope, level, vals)
+    # NOTE: 3x, does this: vals.join(" ")
+    # New implementation uses the evaluator to get proper formatting per type
+    vals = vals.map { |v| Puppet::Pops::Evaluator::EvaluatorImpl.new.string(v, scope) }
+
+    # Bypass Puppet.<level> call since it picks up source from "self" which is not applicable in the 4x
+    # Function API.
+    # TODO: When a function can obtain the file, line, pos of the call merge those in (3x supports
+    #       options :file, :line. (These were never output when calling the 3x logging functions since
+    #       3x scope does not know about the calling location at that detailed level, nor do they
+    #       appear in a report to stdout/error when included). Now, the output simply uses scope (like 3x)
+    #       as this is good enough, but does not reflect the true call-stack, but is a rough estimate
+    #       of where the logging call originates from).
+    #
+    Puppet::Util::Log.create({:level => level, :source => scope, :message => vals.join(" ")})
+    nil
   end
 
+
   attr_accessor :time, :remote, :file, :line, :pos, :source, :issue_code, :environment, :node, :backtrace
   attr_reader :level, :message
 
@@ -289,7 +333,7 @@ class Puppet::Util::Log
 
   def to_data_hash
     {
-      'level' => @level,
+      'level' => @level.to_s,
       'message' => to_s,
       'source' => @source,
       'tags' => @tags.to_a,
@@ -314,20 +358,19 @@ class Puppet::Util::Log
     hash
   end
 
-  def to_pson(*args)
-    to_data_hash.to_pson(*args)
-  end
-
   def message=(msg)
-    raise ArgumentError, "Puppet::Util::Log requires a message" unless msg
+    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    raise ArgumentError, _("Puppet::Util::Log requires a message") unless msg
     @message = msg.to_s
   end
 
   def level=(level)
-    raise ArgumentError, "Puppet::Util::Log requires a log level" unless level
-    raise ArgumentError, "Puppet::Util::Log requires a symbol or string" unless level.respond_to? "to_sym"
+    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    raise ArgumentError, _("Puppet::Util::Log requires a log level") unless level
+    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    raise ArgumentError, _("Puppet::Util::Log requires a symbol or string") unless level.respond_to? "to_sym"
     @level = level.to_sym
-    raise ArgumentError, "Invalid log level #{@level}" unless self.class.validlevel?(@level)
+    raise ArgumentError, _("Invalid log level %{level}") % { level: @level } unless self.class.validlevel?(@level)
 
     # Tag myself with my log level
     tag(level)
@@ -356,19 +399,9 @@ class Puppet::Util::Log
     # Issue based messages do not have details in the message. It
     # must be appended here
     unless issue_code.nil?
-      msg = "Could not parse for environment #{environment}: #{msg}" unless environment.nil?
-      if file && line && pos
-        msg = "#{msg} at #{file}:#{line}:#{pos}"
-      elsif file and line
-        msg = "#{msg}  at #{file}:#{line}"
-      elsif line && pos
-        msg = "#{msg}  at line #{line}:#{pos}"
-      elsif line
-        msg = "#{msg}  at line #{line}"
-      elsif file
-        msg = "#{msg}  in #{file}"
-      end
-      msg = "#{msg} on node #{node}" unless node.nil?
+      msg = _("Could not parse for environment %{environment}: %{msg}") % { environment: environment, msg: msg } unless environment.nil?
+      msg += Puppet::Util::Errors.error_location_with_space(file, line, pos)
+      msg = _("%{msg} on node %{node}") % { msg: msg, node: node } unless node.nil?
       if @backtrace.is_a?(Array)
         msg += "\n"
         msg += @backtrace.join("\n")
@@ -379,7 +412,7 @@ class Puppet::Util::Log
 
 end
 
-# This is for backward compatibility from when we changed the constant to Puppet::Util::Log
-# because the reports include the constant name.  Apparently the alias was created in
-# March 2007, should could probably be removed soon.
+# This is for backward compatibility from when we changed the constant to
+# Puppet::Util::Log because the reports include the constant name. It was
+# considered for removal but left in due to risk of breakage (PUP-7502).
 Puppet::Log = Puppet::Util::Log
