@@ -18,7 +18,7 @@ Puppet::Util::Log.newdesttype :syslog do
     begin
       facility = Syslog.const_get("LOG_#{str.upcase}")
     rescue NameError
-      raise Puppet::Error, "Invalid syslog facility #{str}", $!.backtrace
+      raise Puppet::Error, _("Invalid syslog facility %{str}") % { str: str }, $!.backtrace
     end
 
     @syslog = Syslog.open(name, options, facility)
@@ -72,7 +72,7 @@ Puppet::Util::Log.newdesttype :file do
     # specified a "special" destination.
     unless Puppet::FileSystem.exist?(Puppet::FileSystem.dir(path))
       FileUtils.mkdir_p(File.dirname(path), :mode => 0755)
-      Puppet.info "Creating log directory #{File.dirname(path)}"
+      Puppet.info _("Creating log directory %{dir}") % { dir: File.dirname(path) }
     end
 
     # create the log file, if it doesn't already exist
@@ -93,10 +93,12 @@ Puppet::Util::Log.newdesttype :file do
     file.puts('[') if need_array_start
 
     # Give ownership to the user and group puppet will run as
-    begin
-      FileUtils.chown(Puppet[:user], Puppet[:group], path) unless Puppet::Util::Platform.windows?
-    rescue ArgumentError, Errno::EPERM
-      Puppet.err "Unable to set ownership of log file"
+    if Puppet.features.root? && !Puppet::Util::Platform.windows?
+      begin
+        FileUtils.chown(Puppet[:user], Puppet[:group], path)
+      rescue ArgumentError, Errno::EPERM
+        Puppet.err _("Unable to set ownership to %{user}:%{group} for log file: %{path}") % { user: Puppet[:user], group: Puppet[:group], path: path }
+      end
     end
 
     @file = file
@@ -123,7 +125,6 @@ Puppet::Util::Log.newdesttype :logstash_event do
     # logstash_event format is documented at
     # https://logstash.jira.com/browse/LOGSTASH-675
 
-    data = {}
     data = msg.to_hash
     data['version'] = 1
     data['@timestamp'] = data['time']
@@ -134,7 +135,7 @@ Puppet::Util::Log.newdesttype :logstash_event do
 
   def handle(msg)
     message = format(msg)
-    $stdout.puts message.to_pson
+    $stdout.puts message.to_json
   end
 end
 
@@ -150,15 +151,15 @@ Puppet::Util::Log.newdesttype :console do
 
   def handle(msg)
     levels = {
-      :emerg   => { :name => 'Emergency', :color => :hred,  :stream => $stderr },
-      :alert   => { :name => 'Alert',     :color => :hred,  :stream => $stderr },
-      :crit    => { :name => 'Critical',  :color => :hred,  :stream => $stderr },
-      :err     => { :name => 'Error',     :color => :hred,  :stream => $stderr },
-      :warning => { :name => 'Warning',   :color => :hred,  :stream => $stderr },
+      :emerg   => { :name => 'Emergency', :color => :hred,     :stream => $stderr },
+      :alert   => { :name => 'Alert',     :color => :hred,     :stream => $stderr },
+      :crit    => { :name => 'Critical',  :color => :hred,     :stream => $stderr },
+      :err     => { :name => 'Error',     :color => :hred,     :stream => $stderr },
+      :warning => { :name => 'Warning',   :color => :hyellow,  :stream => $stderr },
 
-      :notice  => { :name => 'Notice',    :color => :reset, :stream => $stdout },
-      :info    => { :name => 'Info',      :color => :green, :stream => $stdout },
-      :debug   => { :name => 'Debug',     :color => :cyan,  :stream => $stdout },
+      :notice  => { :name => 'Notice',    :color => :reset,    :stream => $stdout },
+      :info    => { :name => 'Info',      :color => :green,    :stream => $stdout },
+      :debug   => { :name => 'Debug',     :color => :cyan,     :stream => $stdout },
     }
 
     str = msg.respond_to?(:multiline) ? msg.multiline : msg.to_s
@@ -210,37 +211,41 @@ Puppet::Util::Log.newdesttype :array do
 end
 
 Puppet::Util::Log.newdesttype :eventlog do
+  # Leaving these in for backwards compatibility - duplicates the same in
+  # Puppet::Util::Windows::EventLog
   Puppet::Util::Log::DestEventlog::EVENTLOG_ERROR_TYPE       = 0x0001
   Puppet::Util::Log::DestEventlog::EVENTLOG_WARNING_TYPE     = 0x0002
   Puppet::Util::Log::DestEventlog::EVENTLOG_INFORMATION_TYPE = 0x0004
+  Puppet::Util::Log::DestEventlog::EVENTLOG_CHARACTER_LIMIT  = 31838
 
   def self.suitable?(obj)
-    Puppet.features.eventlog?
+    Puppet.features.microsoft_windows?
   end
 
   def initialize
-    @eventlog = Win32::EventLog.open("Application")
+    @eventlog = Puppet::Util::Windows::EventLog.open("Puppet")
   end
 
   def to_native(level)
-    case level
-    when :debug,:info,:notice
-      [self.class::EVENTLOG_INFORMATION_TYPE, 0x01]
-    when :warning
-      [self.class::EVENTLOG_WARNING_TYPE, 0x02]
-    when :err,:alert,:emerg,:crit
-      [self.class::EVENTLOG_ERROR_TYPE, 0x03]
-    end
+    Puppet::Util::Windows::EventLog.to_native(level)
   end
 
   def handle(msg)
     native_type, native_id = to_native(msg.level)
 
+    stringified_msg = msg.message.to_s
+    if stringified_msg.length > self.class::EVENTLOG_CHARACTER_LIMIT
+      warning = "...Message exceeds character length limit, truncating."
+      truncated_message_length = self.class::EVENTLOG_CHARACTER_LIMIT - warning.length
+      stringified_truncated_msg = stringified_msg[0..truncated_message_length]
+      stringified_truncated_msg << warning
+      msg.message = stringified_truncated_msg
+    end
+
     @eventlog.report_event(
-      :source      => "Puppet",
       :event_type  => native_type,
       :event_id    => native_id,
-      :data        => (msg.source and msg.source != 'Puppet' ? "#{msg.source}: " : '') + msg.to_s
+      :data        => (msg.source && msg.source != 'Puppet' ? "#{msg.source}: " : '') + msg.to_s
     )
   end
 
