@@ -63,13 +63,13 @@ module Puppet::Util::ProviderFeatures
   # @todo How methods that determine if the feature is present are specified.
   def feature(name, docs, hash = {})
     @features ||= {}
-    raise(Puppet::DevError, "Feature #{name} is already defined") if @features.include?(name)
+    raise Puppet::DevError, _("Feature %{name} is already defined") % { name: name } if @features.include?(name)
     begin
       obj = ProviderFeature.new(name, docs, hash)
       @features[obj.name] = obj
     rescue ArgumentError => detail
       error = ArgumentError.new(
-        "Could not create feature #{name}: #{detail}"
+        _("Could not create feature %{name}: %{detail}") % { name: name, detail: detail }
       )
       error.set_backtrace(detail.backtrace)
       raise error
@@ -84,7 +84,7 @@ module Puppet::Util::ProviderFeatures
     names = @features.keys.sort { |a,b| a.to_s <=> b.to_s }
     names.each do |name|
       doc = @features[name].docs.gsub(/\n\s+/, " ")
-      str += "- *#{name}*: #{doc}\n"
+      str << "- *#{name}*: #{doc}\n"
     end
 
     if providers.length > 0
@@ -101,7 +101,7 @@ module Puppet::Util::ProviderFeatures
           end
         end
       end
-      str += doctable(headers, data)
+      str << doctable(headers, data)
     end
     str
   end
@@ -113,7 +113,7 @@ module Puppet::Util::ProviderFeatures
   end
 
   # Generates a module that sets up the boolean predicate methods to test for given features.
-  # 
+  #
   def feature_module
     unless defined?(@feature_module)
       @features ||= {}
