@@ -4,8 +4,13 @@ module Puppet::Util::Windows
     class UserProfile; end
     class Group; end
   end
+  module File; end
   module Registry
   end
+  module SID
+    class Principal; end
+  end
+  class EventLog; end
 
   if Puppet::Util::Platform.windows?
     # these reference platform specific gems
@@ -14,6 +19,7 @@ module Puppet::Util::Windows
     require 'puppet/util/windows/error'
     require 'puppet/util/windows/com'
     require 'puppet/util/windows/sid'
+    require 'puppet/util/windows/principal'
     require 'puppet/util/windows/file'
     require 'puppet/util/windows/security'
     require 'puppet/util/windows/user'
@@ -24,5 +30,6 @@ module Puppet::Util::Windows
     require 'puppet/util/windows/security_descriptor'
     require 'puppet/util/windows/adsi'
     require 'puppet/util/windows/registry'
+    require 'puppet/util/windows/eventlog'
   end
 end
