@@ -35,27 +35,27 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
   context "#verify" do
     it "should report if there is no certificate" do
-      subject.verify('random-host').should == {
+      expect(subject.verify('random-host')).to eq({
         :host => 'random-host', :valid => false,
         :error => 'Could not find a certificate for random-host'
-      }
+      })
     end
 
     it "should report that it cannot find a certificate when there is only a request" do
       given_certificate_requests_for('random-host')
 
-      subject.verify('random-host').should == {
+      expect(subject.verify('random-host')).to eq({
         :host => 'random-host', :valid => false,
         :error => 'Could not find a certificate for random-host'
-      }
+      })
     end
 
     it "should verify a signed certificate" do
       given_certificates_for('random-host')
 
-      subject.verify('random-host').should == {
+      expect(subject.verify('random-host')).to eq({
         :host => 'random-host', :valid => true
-      }
+      })
     end
 
     it "should not verify a revoked certificate" do
@@ -63,10 +63,10 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       subject.revoke('random-host')
 
-      subject.verify('random-host').should == {
+      expect(subject.verify('random-host')).to eq({
         :host => 'random-host', :valid => false,
         :error => 'certificate revoked'
-      }
+      })
     end
 
     it "should verify a revoked certificate if CRL use was turned off" do
@@ -75,9 +75,9 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       Puppet[:certificate_revocation] = false
 
-      subject.verify('random-host').should == {
+      expect(subject.verify('random-host')).to eq({
         :host => 'random-host', :valid => true
-      }
+      })
     end
   end
 
@@ -85,39 +85,39 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
     let(:fingerprint_re) { /^\([0-9A-Z]+\) [0-9A-F:]+$/ }
 
     it "should be nil if there is no certificate" do
-      subject.fingerprint('random-host').should be_nil
+      expect(subject.fingerprint('random-host')).to be_nil
     end
 
     it "should fingerprint a CSR" do
       given_certificate_requests_for('random-host')
 
-      subject.fingerprint('random-host').should =~ fingerprint_re
+      expect(subject.fingerprint('random-host')).to match(fingerprint_re)
     end
 
     it "should fingerprint a certificate" do
       given_certificates_for('random-host')
 
-      subject.fingerprint('random-host').should =~ fingerprint_re
+      expect(subject.fingerprint('random-host')).to match(fingerprint_re)
     end
 
     %w{md5 MD5 sha1 SHA1 RIPEMD160 sha256 sha512}.each do |digest|
       it "should fingerprint with #{digest.inspect}" do
         given_certificates_for('random-host')
 
-        subject.fingerprint('random-host', :digest => digest).should =~ fingerprint_re
+        expect(subject.fingerprint('random-host', :digest => digest)).to match(fingerprint_re)
       end
     end
   end
 
   context "#print" do
     it "should be nil if there is no certificate" do
-      subject.print('random-host').should be_nil
+      expect(subject.print('random-host')).to be_nil
     end
 
     it "should return nothing if there is only a CSR" do
       given_certificate_requests_for('random-host')
 
-      subject.print('random-host').should be_nil
+      expect(subject.print('random-host')).to be_nil
     end
 
     it "should return the certificate content if there is a cert" do
@@ -125,32 +125,32 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       text = subject.print('random-host')
 
-      text.should be_an_instance_of String
-      text.should =~ /^Certificate:/
-      text.should =~ /Issuer: CN=Puppet CA: /
-      text.should =~ /Subject: CN=random-host$/
+      expect(text).to be_an_instance_of String
+      expect(text).to match(/^Certificate:/)
+      expect(text).to match(/Issuer: CN=Puppet CA: /)
+      expect(text).to match(/Subject: CN=random-host$/)
     end
   end
 
   context "#sign" do
     it "should report that there is no CSR" do
-      subject.sign('random-host').should == 'Could not find certificate request for random-host'
+      expect(subject.sign('random-host')).to eq('Could not find certificate request for random-host')
     end
 
     it "should report that there is no CSR when even when there is a certificate" do
       given_certificates_for('random-host')
 
-      subject.sign('random-host').should == 'Could not find certificate request for random-host'
+      expect(subject.sign('random-host')).to eq('Could not find certificate request for random-host')
     end
 
     it "should sign a CSR if one exists" do
       given_certificate_requests_for('random-host')
 
-      subject.sign('random-host').should be_an_instance_of Puppet::SSL::Certificate
+      expect(subject.sign('random-host')).to be_an_instance_of Puppet::SSL::Certificate
 
       list = subject.list(:signed => true)
-      list.length.should == 1
-      list.first.name.should == 'random-host'
+      expect(list.length).to eq(1)
+      expect(list.first.name).to eq('random-host')
     end
 
     describe "when the CSR specifies DNS alt names" do
@@ -163,7 +163,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
       it "should sign the CSR if DNS alt names are allowed" do
         subject.sign('someone', :allow_dns_alt_names => true)
 
-        host.certificate.should be_a(Puppet::SSL::Certificate)
+        expect(host.certificate).to be_a(Puppet::SSL::Certificate)
       end
 
       it "should refuse to sign the CSR if DNS alt names are not allowed" do
@@ -172,32 +172,32 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
           subject.sign(certname)
         end.to raise_error(Puppet::SSL::CertificateAuthority::CertificateSigningError, /CSR '#{certname}' contains subject alternative names \(.*\), which are disallowed. Use `puppet cert --allow-dns-alt-names sign #{certname}` to sign this request./i)
 
-        host.certificate.should be_nil
+        expect(host.certificate).to be_nil
       end
     end
   end
 
   context "#generate" do
     it "should generate a certificate if requested" do
-      subject.list(:all => true).should == []
+      expect(subject.list(:all => true)).to eq([])
 
       subject.generate('random-host')
 
       list = subject.list(:signed => true)
-      list.length.should == 1
-      list.first.name.should == 'random-host'
+      expect(list.length).to eq(1)
+      expect(list.first.name).to eq('random-host')
     end
 
     it "should report if a CSR with that name already exists" do
       given_certificate_requests_for('random-host')
 
-      subject.generate('random-host').should =~ /already has a certificate request/
+      expect(subject.generate('random-host')).to match(/already has a certificate request/)
     end
 
     it "should report if the certificate with that name already exists" do
       given_certificates_for('random-host')
 
-      subject.generate('random-host').should =~ /already has a certificate/
+      expect(subject.generate('random-host')).to match(/already has a certificate/)
     end
 
     it "should include the specified DNS alt names" do
@@ -205,16 +205,16 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       host = subject.list(:signed => true).first
 
-      host.name.should == 'some-host'
-      host.certificate.subject_alt_names.should =~ %w[DNS:some DNS:alt DNS:names DNS:some-host]
+      expect(host.name).to eq('some-host')
+      expect(host.certificate.subject_alt_names).to match_array(%w[DNS:some DNS:alt DNS:names DNS:some-host])
 
-      subject.list(:pending => true).should be_empty
+      expect(subject.list(:pending => true)).to be_empty
     end
   end
 
   context "#revoke" do
     it "should let the user know what went wrong when there is nothing to revoke" do
-      subject.revoke('nonesuch').should == 'Nothing was revoked'
+      expect(subject.revoke('nonesuch')).to eq('Nothing was revoked')
     end
 
     it "should revoke a certificate" do
@@ -223,14 +223,14 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
       subject.revoke('random-host')
 
       found = subject.list(:all => true, :subject => 'random-host')
-      subject.get_action(:list).when_rendering(:console).call(found, {}).
-        should =~ /^- random-host  \(\w+\) [:0-9A-F]+ \(certificate revoked\)/
+      expect(subject.get_action(:list).when_rendering(:console).call(found, {})).
+        to match(/^- random-host  \(\w+\) [:0-9A-F]+ \(certificate revoked\)/)
     end
   end
 
   context "#destroy" do
     it "should let the user know if nothing was deleted" do
-      subject.destroy('nonesuch').should == "Nothing was deleted"
+      expect(subject.destroy('nonesuch')).to eq("Nothing was deleted")
     end
 
     it "should destroy a CSR, if we have one" do
@@ -238,7 +238,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       subject.destroy('random-host')
 
-      subject.list(:pending => true, :subject => 'random-host').should == []
+      expect(subject.list(:pending => true, :subject => 'random-host')).to eq([])
     end
 
     it "should destroy a certificate, if we have one" do
@@ -246,16 +246,16 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
       subject.destroy('random-host')
 
-      subject.list(:signed => true, :subject => 'random-host').should == []
+      expect(subject.list(:signed => true, :subject => 'random-host')).to eq([])
     end
 
     it "should tell the user something was deleted" do
       given_certificates_for('random-host')
 
-      subject.list(:signed => true, :subject => 'random-host').should_not == []
+      expect(subject.list(:signed => true, :subject => 'random-host')).not_to eq([])
 
-      subject.destroy('random-host').
-        should == "Deleted for random-host: Puppet::SSL::Certificate"
+      expect(subject.destroy('random-host')).
+        to eq("Deleted for random-host: Puppet::SSL::Certificate")
     end
   end
 
@@ -268,16 +268,16 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
         { :all => true },
       ].each do |type|
         it "should return nothing for #{type.inspect}" do
-          subject.list(type).should == []
+          expect(subject.list(type)).to eq([])
         end
 
         it "should return nothing when a matcher is passed" do
-          subject.list(type.merge :subject => '.').should == []
+          expect(subject.list(type.merge :subject => '.')).to eq([])
         end
 
         context "when_rendering :console" do
           it "should return nothing for #{type.inspect}" do
-            subject.get_action(:list).when_rendering(:console).call(subject.list(type), {}).should == ""
+            expect(subject.get_action(:list).when_rendering(:console).call(subject.list(type), {})).to eq("")
           end
         end
       end
@@ -301,7 +301,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
           given_certificate_requests_for(*csr_names)
           given_certificates_for(*crt_names)
 
-          subject.list(input).map(&:name).should =~ expect
+          expect(subject.list(input).map(&:name)).to match_array(expect)
         end
 
         ['', '.', '2', 'none'].each do |pattern|
@@ -311,7 +311,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
             given_certificate_requests_for(*csr_names)
             given_certificates_for(*crt_names)
 
-            subject.list(input.merge :subject => pattern).map(&:name).should =~ filtered
+            expect(subject.list(input.merge :subject => pattern).map(&:name)).to match_array(filtered)
           end
         end
       end
@@ -328,7 +328,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
             text = subject.get_action(:list).when_rendering(:console).call(subject.list(:all => true), {})
 
             pattern.each do |item|
-              text.should =~ item
+              expect(text).to match(item)
             end
           end
         end
@@ -338,7 +338,7 @@ describe Puppet::Face[:ca, '0.1.0'], :unless => Puppet.features.microsoft_window
 
   actions = %w{destroy list revoke generate sign print verify fingerprint}
   actions.each do |action|
-    it { should be_action action }
+    it { is_expected.to be_action action }
     it "should fail #{action} when not a CA" do
       Puppet[:ca] = false
       expect {
