@@ -97,13 +97,13 @@ describe Puppet::Network::AuthConfig do
     it 'should warn about missing path before allow_ip in stanza' do
       expect {
         add_raw_stanza("allow_ip 10.0.0.1\n")
-      }.to raise_error Puppet::ConfigurationError, /Missing or invalid 'path' before right directive at line.*/
+      }.to raise_error Puppet::ConfigurationError, /Missing or invalid 'path' before right directive at \(line: .*\)/
     end
 
     it 'should warn about missing path before allow in stanza' do
       expect {
         add_raw_stanza("allow host.domain.com\n")
-      }.to raise_error Puppet::ConfigurationError, /Missing or invalid 'path' before right directive at line.*/
+      }.to raise_error Puppet::ConfigurationError, /Missing or invalid 'path' before right directive at \(line: .*\)/
     end
 
     it "should support hostname backreferences" do
