@@ -96,7 +96,7 @@ describe "A catalog" do
   def master_and_agent_catalogs_for(manifest)
     compiler = Puppet::Resource::Catalog::Compiler.new
     master_catalog = compiler.filter(compile_to_catalog(manifest, node))
-    agent_catalog = Puppet::Resource::Catalog.convert_from(:pson, master_catalog.render(:pson))
+    agent_catalog = Puppet::Resource::Catalog.convert_from(:json, master_catalog.render(:json))
     [master_catalog, agent_catalog]
   end
 
