@@ -3,6 +3,11 @@ require 'spec_helper'
 require 'puppet_spec/files'
 
 describe Puppet::Transaction::Report do
+  before :each do
+    # Enable persistence during tests
+    Puppet::Transaction::Persistence.any_instance.stubs(:enabled?).returns(true)
+  end
+
   describe "when using the indirector" do
     after do
       Puppet.settings.stubs(:use)
@@ -15,7 +20,7 @@ describe Puppet::Transaction::Report do
 
       Facter.stubs(:value).returns "host.domain.com"
 
-      report = Puppet::Transaction::Report.new("apply")
+      report = Puppet::Transaction::Report.new
 
       terminus.expects(:process).with(report)
 
@@ -31,7 +36,7 @@ describe Puppet::Transaction::Report do
 
       log = Puppet::Util::Log.new(:level => :info, :message => "foo")
 
-      report = Puppet::Transaction::Report.new("apply")
+      report = Puppet::Transaction::Report.new
       report.add_resource_status(status)
       report << log
 
