@@ -139,7 +139,7 @@ describe Puppet::Application::Cert => true do
   describe "when running" do
     before :each do
       @cert_app.all = false
-      @ca = stub_everything 'ca'
+      @ca = stub_everything( 'ca', :waiting? => ['unsigned-node'] )
       @cert_app.ca = @ca
       @cert_app.command_line.stubs(:args).returns([])
       @iface = stub_everything 'iface'
@@ -186,6 +186,33 @@ describe Puppet::Application::Cert => true do
 
       @cert_app.main
     end
+
+    it "should not revoke cert if node does not have a signed certificate" do
+      @cert_app.subcommand = :destroy
+      @cert_app.command_line.stubs(:args).returns(["unsigned-node"])
+
+      Puppet::SSL::CertificateAuthority::Interface.expects(:new).returns(@iface).with { |cert_mode,to| cert_mode == :destroy
+        to[:to] == ["unsigned-node"]
+      }
+
+      @cert_app.main
+    end
+
+    it "should only revoke signed certificate and destroy certificate signing requests" do
+      @cert_app.subcommand = :destroy
+      @cert_app.command_line.stubs(:args).returns(["host","unsigned-node"])
+
+      Puppet::SSL::CertificateAuthority::Interface.expects(:new).returns(@iface).with { |cert_mode,to|
+        cert_mode == :revoke
+        to[:to] == ["host"]
+      }
+      Puppet::SSL::CertificateAuthority::Interface.expects(:new).returns(@iface).with { |cert_mode,to|
+        cert_mode == :destroy
+        to[:to] == ["host","unsigned-node"]
+      }
+
+      @cert_app.main
+    end
   end
 
   describe "when identifying subcommands" do
