@@ -9,7 +9,6 @@ describe 'Capability types' do
   let(:loaders) { Puppet::Pops::Loaders.new(env) }
 
   around :each do |example|
-    Puppet[:app_management] = true
     Puppet::Parser::Compiler.any_instance.stubs(:loaders).returns(loaders)
     Puppet.override(:loaders => loaders, :current_environment => env) do
       Puppet::Type.newtype :cap, :is_capability => true do
@@ -19,7 +18,6 @@ describe 'Capability types' do
       example.run
       Puppet::Type.rmtype(:cap)
     end
-    Puppet[:app_management] = false
   end
 
   context 'annotations' do
@@ -402,10 +400,8 @@ test { one: hostname => "ahost", export => Cap[two] }
         ensure => directory
       }
 
-      if !defined(File["${same_dir}"]) {
-        file { $same_dir:
-          ensure => directory
-        }
+      file { $same_dir:
+        ensure => directory
       }
     PUPPET
 
