@@ -11,18 +11,18 @@ describe Puppet::Configurer::Downloader do
   let(:source) { 'puppet://puppet/plugins' }
 
   it "should require a name" do
-    lambda { Puppet::Configurer::Downloader.new }.should raise_error(ArgumentError)
+    expect { Puppet::Configurer::Downloader.new }.to raise_error(ArgumentError)
   end
 
   it "should require a path and a source at initialization" do
-    lambda { Puppet::Configurer::Downloader.new("name") }.should raise_error(ArgumentError)
+    expect { Puppet::Configurer::Downloader.new("name") }.to raise_error(ArgumentError)
   end
 
   it "should set the name, path and source appropriately" do
     dler = Puppet::Configurer::Downloader.new("facts", "path", "source")
-    dler.name.should == "facts"
-    dler.path.should == "path"
-    dler.source.should == "source"
+    expect(dler.name).to eq("facts")
+    expect(dler.path).to eq("path")
+    expect(dler.source).to eq("source")
   end
 
   def downloader(options = {})
@@ -55,19 +55,25 @@ describe Puppet::Configurer::Downloader do
     it "should always recurse" do
       file = generate_file_resource
 
-      expect(file[:recurse]).to be_true
+      expect(file[:recurse]).to be_truthy
+    end
+
+    it "should follow links by default" do
+      file = generate_file_resource
+
+      expect(file[:links]).to eq(:follow)
     end
 
     it "should always purge" do
       file = generate_file_resource
 
-      expect(file[:purge]).to be_true
+      expect(file[:purge]).to be_truthy
     end
 
     it "should never be in noop" do
       file = generate_file_resource
 
-      expect(file[:noop]).to be_false
+      expect(file[:noop]).to be_falsey
     end
 
     it "should set source_permissions to ignore by default" do
@@ -76,13 +82,13 @@ describe Puppet::Configurer::Downloader do
       expect(file[:source_permissions]).to eq(:ignore)
     end
 
-    it "should allow source_permissions to be overridden" do
-      file = generate_file_resource(:source_permissions => :use)
+    describe "on POSIX", :if => Puppet.features.posix? do
+      it "should allow source_permissions to be overridden" do
+        file = generate_file_resource(:source_permissions => :use)
 
-      expect(file[:source_permissions]).to eq(:use)
-    end
+        expect(file[:source_permissions]).to eq(:use)
+      end
 
-    describe "on POSIX", :as_platform => :posix do
       it "should always set the owner to the current UID" do
         Process.expects(:uid).returns 51
 
@@ -98,7 +104,7 @@ describe Puppet::Configurer::Downloader do
       end
     end
 
-    describe "on Windows", :as_platform => :windows do
+    describe "on Windows", :if => Puppet.features.microsoft_windows? do
       it "should omit the owner" do
         file = generate_file_resource(:path => 'C:/path')
 
@@ -115,13 +121,13 @@ describe Puppet::Configurer::Downloader do
     it "should always force the download" do
       file = generate_file_resource
 
-      expect(file[:force]).to be_true
+      expect(file[:force]).to be_truthy
     end
 
     it "should never back up when downloading" do
       file = generate_file_resource
 
-      expect(file[:backup]).to be_false
+      expect(file[:backup]).to be_falsey
     end
 
     it "should support providing an 'ignore' parameter" do
@@ -145,13 +151,13 @@ describe Puppet::Configurer::Downloader do
 
     it "should create a catalog and add the file to it" do
       catalog = @dler.catalog
-      catalog.resources.size.should == 1
-      catalog.resources.first.class.should == Puppet::Type::File
-      catalog.resources.first.name.should == @path
+      expect(catalog.resources.size).to eq(1)
+      expect(catalog.resources.first.class).to eq(Puppet::Type::File)
+      expect(catalog.resources.first.name).to eq(@path)
     end
 
     it "should specify that it is not managing a host catalog" do
-      @dler.catalog.host_config.should == false
+      expect(@dler.catalog.host_config).to eq(false)
     end
 
   end
@@ -169,7 +175,7 @@ describe Puppet::Configurer::Downloader do
       Puppet[:tags] = 'maytag'
       @dler.evaluate
 
-      Puppet::FileSystem.exist?(@dl_name).should be_true
+      expect(Puppet::FileSystem.exist?(@dl_name)).to be_truthy
     end
 
     it "should log that it is downloading" do
@@ -190,7 +196,7 @@ describe Puppet::Configurer::Downloader do
 
       trans.expects(:changed?).returns([resource])
 
-      @dler.evaluate.should == %w{/changed/file}
+      expect(@dler.evaluate).to eq(%w{/changed/file})
     end
 
     it "should yield the resources if a block is given" do
@@ -207,7 +213,7 @@ describe Puppet::Configurer::Downloader do
 
       yielded = nil
       @dler.evaluate { |r| yielded = r }
-      yielded.should == resource
+      expect(yielded).to eq(resource)
     end
 
     it "should catch and log exceptions" do
@@ -216,7 +222,7 @@ describe Puppet::Configurer::Downloader do
       # that it is possible to stub for the purpose of generating a puppet error
       Puppet::Resource::Catalog.any_instance.stubs(:apply).raises(Puppet::Error, "testing")
 
-      lambda { @dler.evaluate }.should_not raise_error
+      expect { @dler.evaluate }.not_to raise_error
     end
   end
 end
