@@ -42,36 +42,6 @@ describe "Defaults" do
     end
   end
 
-  describe 'cfacter' do
-
-    before :each do
-      Facter.reset
-    end
-
-    it 'should default to false' do
-      expect(Puppet.settings[:cfacter]).to be_falsey
-    end
-
-    it 'should raise an error if cfacter is not installed' do
-      Puppet.features.stubs(:cfacter?).returns false
-      expect { Puppet.settings[:cfacter] = true }.to raise_exception ArgumentError, 'cfacter version 0.2.0 or later is not installed.'
-    end
-
-    it 'should raise an error if facter has already evaluated facts' do
-      Facter[:facterversion]
-      Puppet.features.stubs(:cfacter?).returns true
-      expect { Puppet.settings[:cfacter] = true }.to raise_exception ArgumentError, 'facter has already evaluated facts.'
-    end
-
-    it 'should initialize cfacter when set to true' do
-      Puppet.features.stubs(:cfacter?).returns true
-      CFacter = mock
-      CFacter.stubs(:initialize)
-      Puppet.settings[:cfacter] = true
-    end
-
-  end
-
   describe 'strict' do
     it 'should accept the valid value :off' do
       expect {Puppet.settings[:strict] = 'off'}.to_not raise_exception
@@ -90,18 +60,53 @@ describe "Defaults" do
     end
   end
 
-  describe 'supported_checksum_types' do
-    it 'should default to md5,sha256' do
-      expect(Puppet.settings[:supported_checksum_types]).to eq(['md5', 'sha256'])
+  describe '.default_digest_algorithm' do
+    it 'defaults to md5 when FIPS is not enabled' do
+      Puppet::Util::Platform.stubs(:fips_enabled?).returns false
+      expect(Puppet.default_digest_algorithm).to eq('md5')
+    end
+
+    it 'defaults to sha256 when FIPS is enabled' do
+      Puppet::Util::Platform.stubs(:fips_enabled?).returns true
+      expect(Puppet.default_digest_algorithm).to eq('sha256')
+    end
+  end
+
+  describe '.supported_checksum_types' do
+    it 'defaults to md5, sha256, sha384, sha512, sha224 when FIPS is not enabled' do
+      Puppet::Util::Platform.stubs(:fips_enabled?).returns false
+      expect(Puppet.default_file_checksum_types).to eq(%w[md5 sha256 sha384 sha512 sha224])
+    end
+
+    it 'defaults to sha256, sha384, sha512, sha224 when FIPS is enabled' do
+      Puppet::Util::Platform.stubs(:fips_enabled?).returns true
+      expect(Puppet.default_file_checksum_types).to eq(%w[sha256 sha384 sha512 sha224])
+    end
+  end
+
+  describe 'Puppet[:supported_checksum_types]' do
+    it 'defaults to md5, sha256, sha512, sha384, sha224' do
+      expect(Puppet.settings[:supported_checksum_types]).to eq(%w[md5 sha256 sha384 sha512 sha224])
     end
 
     it 'should raise an error on an unsupported checksum type' do
-      expect { Puppet.settings[:supported_checksum_types] = ['md5', 'foo'] }.to raise_exception ArgumentError, 'Unrecognized checksum types ["foo"] are not supported. Valid values are ["md5", "md5lite", "sha256", "sha256lite", "sha1", "sha1lite", "mtime", "ctime"].'
+      expect {
+        Puppet.settings[:supported_checksum_types] = %w[md5 foo]
+      }.to raise_exception ArgumentError,
+                           /Invalid value 'foo' for parameter supported_checksum_types. Allowed values are/
     end
 
     it 'should not raise an error on setting a valid list of checksum types' do
-      Puppet.settings[:supported_checksum_types] = ['sha256', 'md5lite', 'mtime']
-      expect(Puppet.settings[:supported_checksum_types]).to eq(['sha256', 'md5lite', 'mtime'])
+      Puppet.settings[:supported_checksum_types] = %w[sha256 md5lite mtime]
+      expect(Puppet.settings[:supported_checksum_types]).to eq(%w[sha256 md5lite mtime])
+    end
+
+    it 'raises when setting md5 in FIPS mode' do
+      Puppet::Util::Platform.stubs(:fips_enabled?).returns true
+      expect {
+        Puppet.settings[:supported_checksum_types] = %w[md5]
+      }.to raise_error(ArgumentError,
+                       /Invalid value 'md5' for parameter supported_checksum_types. Allowed values are 'sha256'/)
     end
   end
 
