@@ -18,8 +18,8 @@ describe Puppet::Face[:config, '0.0.1'] do
     Puppet[:syslogfacility] = "file"
 
     expect { subject.print("trace", "syslogfacility") }.to have_printed(<<-OUTPUT)
-trace = true
 syslogfacility = file
+trace = true
     OUTPUT
   end
 
@@ -82,7 +82,6 @@ syslogfacility = file
 
       manipulator.expects(:set).with("baz", "foo", "bar")
       subject.set('foo', 'bar', {:section => "baz"})
-
     end
 
     it "opens the file with UTF-8 encoding" do
@@ -91,6 +90,52 @@ syslogfacility = file
     end
   end
 
+  context 'when the puppet.conf file does not exist' do
+    let(:config_file) { '/foo/puppet.conf' }
+    let(:path) { Pathname.new(config_file).expand_path }
+    before(:each) do
+      Puppet[:config] = config_file
+      Puppet::FileSystem.stubs(:pathname).with(path.to_s).returns(path)
+    end
+
+    it 'prints a message when the puppet.conf file does not exist' do
+      Puppet::FileSystem.stubs(:exist?).with(path).returns(false)
+      Puppet.expects(:warning).with("The puppet.conf file does not exist #{path.to_s}")
+      subject.delete('setting', {:section => 'main'})
+    end
+  end
+
+  context 'when deleting config values' do
+    let(:config_file) { '/foo/puppet.conf' }
+    let(:path) { Pathname.new(config_file).expand_path }
+    before(:each) do
+      Puppet[:config] = config_file
+      Puppet::FileSystem.stubs(:pathname).with(path.to_s).returns(path)
+      Puppet::FileSystem.stubs(:exist?).with(path).returns(true)
+    end
+
+    it 'prints a message about what was deleted' do
+      Puppet::FileSystem.stubs(:open).with(path, anything, anything).yields(StringIO.new)
+      config = Puppet::Settings::IniFile.new([Puppet::Settings::IniFile::DefaultSection.new])
+      manipulator = Puppet::Settings::IniFile::Manipulator.new(config)
+      Puppet::Settings::IniFile::Manipulator.stubs(:new).returns(manipulator)
+
+      manipulator.expects(:delete).with('main', 'setting').returns('    setting=value')
+      expect { subject.delete('setting', {:section => 'main'}) }.to have_printed("Deleted setting from 'main': 'setting=value'")
+    end
+
+    it 'prints a warning when a setting is not found to delete' do
+      Puppet::FileSystem.stubs(:open).with(path, anything, anything).yields(StringIO.new)
+      config = Puppet::Settings::IniFile.new([Puppet::Settings::IniFile::DefaultSection.new])
+      manipulator = Puppet::Settings::IniFile::Manipulator.new(config)
+      Puppet::Settings::IniFile::Manipulator.stubs(:new).returns(manipulator)
+
+      manipulator.expects(:delete).with('main', 'setting').returns(nil)
+      Puppet.expects(:warning).with("No setting found in configuration file for section 'main' setting name 'setting'")
+      subject.delete('setting', {:section => 'main'})
+    end
+  end
+
   shared_examples_for :config_printing_a_section do |section|
 
     def add_section_option(args, section)
@@ -108,11 +153,11 @@ syslogfacility = file
       ) do
         args = "environmentpath","manifest","modulepath","environment","basemodulepath"
         expect { subject.print(*add_section_option(args, section)) }.to have_printed(<<-OUTPUT)
+basemodulepath = #{File.expand_path("/some/base")}
+environment = production
 environmentpath = #{File.expand_path("/dev/null/environments")}
 manifest = #{File.expand_path("/dev/null/environments/production/manifests")}
 modulepath = #{File.expand_path("/dev/null/environments/production/modules")}#{File::PATH_SEPARATOR}#{File.expand_path("/some/base")}
-environment = production
-basemodulepath = #{File.expand_path("/some/base")}
         OUTPUT
       end
     end
@@ -129,17 +174,16 @@ basemodulepath = #{File.expand_path("/some/base")}
       ) do
         args = "environmentpath","manifest","modulepath","environment","basemodulepath"
         expect { subject.print(*add_section_option(args, section)) }.to have_printed(<<-OUTPUT)
+basemodulepath = #{File.expand_path("/some/base")}
+environment = production
 environmentpath = #{File.expand_path("/dev/null/environments")}
 manifest = #{File.expand_path("/dev/null/environments/production/manifests")}
 modulepath = #{File.expand_path("/custom/modules")}#{File::PATH_SEPARATOR}#{File.expand_path("/some/base")}
-environment = production
-basemodulepath = #{File.expand_path("/some/base")}
         OUTPUT
       end
     end
 
     it "prints the default configured env settings for an env that does not exist" do
-      pending "This case no longer exists because Application will through an error before we even get here because of the non-existent environment"
       Puppet[:environment] = 'doesnotexist'
 
       FS.overlay(
@@ -149,11 +193,11 @@ basemodulepath = #{File.expand_path("/some/base")}
       ) do
         args = "environmentpath","manifest","modulepath","environment","basemodulepath"
         expect { subject.print(*add_section_option(args, section)) }.to have_printed(<<-OUTPUT)
-environmentpath = #{File.expand_path("/dev/null/environments")}
-manifest = no_manifest
-modulepath = 
-environment = doesnotexist
 basemodulepath = #{File.expand_path("/some/base")}
+environment = doesnotexist
+environmentpath = #{File.expand_path("/dev/null/environments")}
+manifest = 
+modulepath = 
         OUTPUT
       end
     end
