@@ -18,8 +18,13 @@ describe Puppet::FileServing::Metadata do
     expect(Puppet::FileServing::Metadata.new(foobar)).to respond_to(:collect)
   end
 
-  it "should support pson serialization" do
-    expect(Puppet::FileServing::Metadata.new(foobar)).to respond_to(:to_pson)
+  it "should default to json" do
+    expect(Puppet::FileServing::Metadata.default_format).to eq(:json)
+  end
+
+  it "should support json, pson, yaml" do
+    # msgpack is optional, so using include instead of eq
+    expect(Puppet::FileServing::Metadata.supported_formats).to include(:json, :pson, :yaml)
   end
 
   it "should support deserialization" do
@@ -41,8 +46,8 @@ describe Puppet::FileServing::Metadata do
       expect(metadata.to_data_hash['relative_path']).to eq(metadata.relative_path)
     end
 
-    it "should pass the links in the hash verbatim" do
-      expect(metadata.to_data_hash['links']).to eq(metadata.links)
+    it "should pass the links in the hash as a string" do
+      expect(metadata.to_data_hash['links']).to eq(metadata.links.to_s)
     end
 
     it "should pass the path owner in the hash verbatim" do
@@ -107,6 +112,27 @@ describe Puppet::FileServing::Metadata do
         expect(metadata.content_uri).to eq(uri)
       end
 
+      it "should accept UTF-8 characters" do
+        # different UTF-8 widths
+        # 1-byte A
+        # 2-byte ۿ - http://www.fileformat.info/info/unicode/char/06ff/index.htm - 0xDB 0xBF / 219 191
+        # 3-byte ᚠ - http://www.fileformat.info/info/unicode/char/16A0/index.htm - 0xE1 0x9A 0xA0 / 225 154 160
+        # 4-byte <U+070E> - http://www.fileformat.info/info/unicode/char/2070E/index.htm - 0xF0 0xA0 0x9C 0x8E / 240 160 156 142
+        mixed_utf8 = "A\u06FF\u16A0\u{2070E}" # Aۿᚠ<U+070E>
+
+        uri = "puppet:///modules/foo/files/ #{mixed_utf8}"
+        metadata.content_uri = uri
+        expect(metadata.content_uri).to eq(uri)
+        expect(metadata.content_uri.encoding).to eq(Encoding::UTF_8)
+      end
+
+      it "should always set it as UTF-8" do
+        uri = "puppet:///modules/foo/files/".encode(Encoding::ASCII)
+        metadata.content_uri = uri
+        expect(metadata.content_uri).to eq(uri)
+        expect(metadata.content_uri.encoding).to eq(Encoding::UTF_8)
+      end
+
       it "should fail if uri is opaque" do
         expect { metadata.content_uri = 'scheme:www.example.com' }.to raise_error ArgumentError, "Cannot use opaque URLs 'scheme:www.example.com'"
       end
@@ -172,7 +198,7 @@ describe Puppet::FileServing::Metadata, :uses_checksums => true do
         end
 
         it "should validate against the schema" do
-          expect(metadata.to_pson).to validate_against('api/schemas/file_metadata.json')
+          expect(metadata.to_json).to validate_against('api/schemas/file_metadata.json')
         end
 
         describe "when a source and content_uri are set" do
@@ -182,7 +208,7 @@ describe Puppet::FileServing::Metadata, :uses_checksums => true do
           end
 
           it "should validate against the schema" do
-            expect(metadata.to_pson).to validate_against('api/schemas/file_metadata.json')
+            expect(metadata.to_json).to validate_against('api/schemas/file_metadata.json')
           end
         end
       end
@@ -209,7 +235,7 @@ describe Puppet::FileServing::Metadata, :uses_checksums => true do
 
         it "should validate against the schema" do
           metadata.collect
-          expect(metadata.to_pson).to validate_against('api/schemas/file_metadata.json')
+          expect(metadata.to_json).to validate_against('api/schemas/file_metadata.json')
         end
       end
     end
@@ -278,7 +304,7 @@ describe Puppet::FileServing::Metadata, :uses_checksums => true do
         end
 
         it "should validate against the schema" do
-          expect(metadata.to_pson).to validate_against('api/schemas/file_metadata.json')
+          expect(metadata.to_json).to validate_against('api/schemas/file_metadata.json')
         end
       end
     end
@@ -312,7 +338,7 @@ describe Puppet::FileServing::Metadata, :uses_checksums => true do
       end
 
       it "should validate against the schema" do
-        expect(metadata.to_pson).to validate_against('api/schemas/file_metadata.json')
+        expect(metadata.to_json).to validate_against('api/schemas/file_metadata.json')
       end
     end
   end
