@@ -53,22 +53,22 @@ describe "Puppet::Indirector::CertificateStatus::File" do
   end
 
   it "should be a terminus on SSL::Host" do
-    @terminus.should be_instance_of(Puppet::Indirector::CertificateStatus::File)
+    expect(@terminus).to be_instance_of(Puppet::Indirector::CertificateStatus::File)
   end
 
   it "should create a CA instance if none is present" do
-    @terminus.ca.should be_instance_of(Puppet::SSL::CertificateAuthority)
+    expect(@terminus.ca).to be_instance_of(Puppet::SSL::CertificateAuthority)
   end
 
   describe "when creating the CA" do
     it "should fail if it is not a valid CA" do
       Puppet::SSL::CertificateAuthority.expects(:ca?).returns false
-      lambda { @terminus.ca }.should raise_error(ArgumentError, "This process is not configured as a certificate authority")
+      expect { @terminus.ca }.to raise_error(ArgumentError, "This process is not configured as a certificate authority")
     end
   end
 
   it "should be indirected with the name 'certificate_status'" do
-    Puppet::SSL::Host.indirection.name.should == :certificate_status
+    expect(Puppet::SSL::Host.indirection.name).to eq(:certificate_status)
   end
 
   describe "when finding" do
@@ -83,8 +83,8 @@ describe "Puppet::Indirector::CertificateStatus::File" do
 
       retrieved_host = @terminus.find(request)
 
-      retrieved_host.name.should == @host.name
-      retrieved_host.certificate_request.content.to_s.chomp.should == @host.certificate_request.content.to_s.chomp
+      expect(retrieved_host.name).to eq(@host.name)
+      expect(retrieved_host.certificate_request.content.to_s.chomp).to eq(@host.certificate_request.content.to_s.chomp)
     end
 
     it "should return the Puppet::SSL::Host when a public key exists for the host" do
@@ -93,13 +93,13 @@ describe "Puppet::Indirector::CertificateStatus::File" do
 
       retrieved_host = @terminus.find(request)
 
-      retrieved_host.name.should == @host.name
-      retrieved_host.certificate.content.to_s.chomp.should == @host.certificate.content.to_s.chomp
+      expect(retrieved_host.name).to eq(@host.name)
+      expect(retrieved_host.certificate.content.to_s.chomp).to eq(@host.certificate.content.to_s.chomp)
     end
 
     it "should return nil when neither a CSR nor public key exist for the host" do
       request = Puppet::Indirector::Request.new(:certificate_status, :find, "foo", @host)
-      @terminus.find(request).should == nil
+      expect(@terminus.find(request)).to eq(nil)
     end
   end
 
@@ -116,14 +116,14 @@ describe "Puppet::Indirector::CertificateStatus::File" do
       end
 
       it "should fail if no CSR is on disk" do
-        lambda { @terminus.save(@request) }.should raise_error(Puppet::Error, /certificate request/)
+        expect { @terminus.save(@request) }.to raise_error(Puppet::Error, /certificate request/)
       end
 
       it "should sign the on-disk CSR when it is present" do
         signed_host = generate_signed_cert(@host)
 
-        signed_host.state.should == "signed"
-        Puppet::SSL::Certificate.indirection.find("foobar").should be_instance_of(Puppet::SSL::Certificate)
+        expect(signed_host.state).to eq("signed")
+        expect(Puppet::SSL::Certificate.indirection.find("foobar")).to be_instance_of(Puppet::SSL::Certificate)
       end
     end
 
@@ -134,13 +134,13 @@ describe "Puppet::Indirector::CertificateStatus::File" do
 
       it "should fail if no certificate is on disk" do
         @host.desired_state = "revoked"
-        lambda { @terminus.save(@request) }.should raise_error(Puppet::Error, /Cannot revoke/)
+        expect { @terminus.save(@request) }.to raise_error(Puppet::Error, /Cannot revoke/)
       end
 
       it "should revoke the certificate when it is present" do
         generate_revoked_cert(@host)
 
-        @host.state.should == 'revoked'
+        expect(@host.state).to eq('revoked')
       end
     end
   end
@@ -153,19 +153,19 @@ describe "Puppet::Indirector::CertificateStatus::File" do
     it "should not delete anything if no certificate, request, or key is on disk" do
       host = Puppet::SSL::Host.new("clean_me")
       request = Puppet::Indirector::Request.new(:certificate_status, :delete, "clean_me", host)
-      @terminus.destroy(request).should == "Nothing was deleted"
+      expect(@terminus.destroy(request)).to eq("Nothing was deleted")
     end
 
     it "should clean certs, cert requests, keys" do
       signed_host = Puppet::SSL::Host.new("clean_signed_cert")
       generate_signed_cert(signed_host)
       signed_request = Puppet::Indirector::Request.new(:certificate_status, :delete, "clean_signed_cert", signed_host)
-      @terminus.destroy(signed_request).should == "Deleted for clean_signed_cert: Puppet::SSL::Certificate, Puppet::SSL::Key"
+      expect(@terminus.destroy(signed_request)).to eq("Deleted for clean_signed_cert: Puppet::SSL::Certificate, Puppet::SSL::Key")
 
       requested_host = Puppet::SSL::Host.new("clean_csr")
       generate_csr(requested_host)
       csr_request = Puppet::Indirector::Request.new(:certificate_status, :delete, "clean_csr", requested_host)
-      @terminus.destroy(csr_request).should == "Deleted for clean_csr: Puppet::SSL::CertificateRequest, Puppet::SSL::Key"
+      expect(@terminus.destroy(csr_request)).to eq("Deleted for clean_csr: Puppet::SSL::CertificateRequest, Puppet::SSL::Key")
     end
   end
 
@@ -185,7 +185,7 @@ describe "Puppet::Indirector::CertificateStatus::File" do
       retrieved_hosts = @terminus.search(Puppet::Indirector::Request.new(:certificate_status, :search, "all", signed_host))
 
       results = retrieved_hosts.map {|h| [h.name, h.state]}.sort{ |h,i| h[0] <=> i[0] }
-      results.should == [["ca","signed"],["requested_host","requested"],["revoked_host","revoked"],["signed_host","signed"]]
+      expect(results).to eq([["ca","signed"],["requested_host","requested"],["revoked_host","revoked"],["signed_host","signed"]])
     end
   end
 end
