@@ -14,42 +14,7 @@ shared_examples_for "Indirection Delegator" do
     @indirection.send(@method, "mystuff", :one => :two)
   end
 
-  it "should let the :select_terminus method choose the terminus using the created request if the :select_terminus method is available" do
-    # Define the method, so our respond_to? hook matches.
-    class << @indirection
-      def select_terminus(request)
-      end
-    end
-
-    request = Puppet::Indirector::Request.new(:indirection, :find, "me", nil)
-
-    @indirection.stubs(:request).returns request
-
-    @indirection.expects(:select_terminus).with(request).returns :test_terminus
-
-    @indirection.stubs(:check_authorization)
-    @terminus.expects(@method)
-
-    @indirection.send(@method, "me")
-  end
-
-  it "should fail if the :select_terminus hook does not return a terminus name" do
-    # Define the method, so our respond_to? hook matches.
-    class << @indirection
-      def select_terminus(request)
-      end
-    end
-
-    request = Puppet::Indirector::Request.new(:indirection, :find, "me", nil)
-
-    @indirection.stubs(:request).returns request
-
-    @indirection.expects(:select_terminus).with(request).returns nil
-
-    expect { @indirection.send(@method, "me") }.to raise_error(ArgumentError)
-  end
-
-  it "should choose the terminus returned by the :terminus_class method if no :select_terminus method is available" do
+  it "should choose the terminus returned by the :terminus_class" do
     @indirection.expects(:terminus_class).returns :test_terminus
 
     @terminus.expects(@method)
@@ -294,6 +259,14 @@ describe Puppet::Indirector::Indirection do
           @indirection.find("/my/key", :ignore_cache => true)
         end
 
+        it "should not save to the cache if told to skip updating the cache" do
+          @terminus.expects(:find).returns @instance
+          @cache.expects(:find).returns nil
+          @cache.expects(:save).never
+
+          @indirection.find("/my/key", :ignore_cache_save => true)
+        end
+
         it "should only look in the cache if the request specifies not to use the terminus" do
           @terminus.expects(:find).never
           @cache.expects(:find)
@@ -494,7 +467,7 @@ describe Puppet::Indirector::Indirection do
         end
 
         it "should return the result of saving to the terminus" do
-          request = stub 'request', :instance => @instance, :node => nil
+          request = stub 'request', :instance => @instance, :node => nil, :ignore_cache_save? => false
 
           @indirection.expects(:request).returns request
 
@@ -504,7 +477,7 @@ describe Puppet::Indirector::Indirection do
         end
 
         it "should use a request to save the object to the cache" do
-          request = stub 'request', :instance => @instance, :node => nil
+          request = stub 'request', :instance => @instance, :node => nil, :ignore_cache_save? => false
 
           @indirection.expects(:request).returns request
 
@@ -522,6 +495,13 @@ describe Puppet::Indirector::Indirection do
           @terminus.expects(:save).raises "eh"
           expect { @indirection.save(@instance) }.to raise_error(RuntimeError, /eh/)
         end
+
+        it "should not save to the cache if told to ignore saving to the cache" do
+          @terminus.expects(:save)
+          @cache.expects(:save).never
+
+          @indirection.save(@instance, '/my/key', :ignore_cache_save => true)
+        end
       end
     end
 
@@ -657,6 +637,13 @@ describe Puppet::Indirector::Indirection do
           @indirection.expire("/my/key")
         end
 
+        it "does not expire an instance if told to skip cache saving" do
+          @indirection.cache.expects(:find).never
+          @indirection.cache.expects(:save).never
+
+          @indirection.expire("/my/key", :ignore_cache_save => true)
+        end
+
         it "should use a request to save the expired resource to the cache" do
           @cache.expects(:find).returns @cached
 
