@@ -60,7 +60,7 @@ describe Puppet::Indirector::JSON do
 
     def with_content(text)
       FileUtils.mkdir_p(File.dirname(file))
-      File.open(file, 'w') {|f| f.puts text }
+      File.binwrite(file, text)
       yield if block_given?
     end
 
@@ -77,11 +77,11 @@ describe Puppet::Indirector::JSON do
       end
 
       it "raises a descriptive error when the file can't be read" do
-        with_content(model.new('foo').to_pson) do
+        with_content(model.new('foo').to_json) do
           # I don't like this, but there isn't a credible alternative that
           # also works on Windows, so a stub it is. At least the expectation
           # will fail if the implementation changes. Sorry to the next dev.
-          Puppet::FileSystem.expects(:read).with(file).raises(Errno::EPERM)
+          Puppet::FileSystem.expects(:read).with(file, anything).raises(Errno::EPERM)
           expect { subject.find(request) }.
             to raise_error Puppet::Error, /Could not read JSON/
         end
@@ -94,8 +94,18 @@ describe Puppet::Indirector::JSON do
         end
       end
 
+      it "raises if the content contains binary" do
+        binary = "\xC0\xFF".force_encoding(Encoding::BINARY)
+
+        with_content(binary) do
+          expect {
+            subject.find(request)
+          }.to raise_error Puppet::Error, /Could not parse JSON data/
+        end
+      end
+
       it "should return an instance of the indirected object when valid" do
-        with_content(model.new(1).to_pson) do
+        with_content(model.new(1).to_json) do
           instance = subject.find(request)
           expect(instance).to be_an_instance_of model
           expect(instance.value).to eq(1)
@@ -160,8 +170,8 @@ describe Puppet::Indirector::JSON do
     end
 
     def create_file(name, value = 12)
-      File.open(subject.path(name, ''), 'w') do |f|
-        f.puts Puppet::IndirectorTesting.new(value).to_pson
+      File.open(subject.path(name, ''), 'wb') do |f|
+        f.puts Puppet::IndirectorTesting.new(value).to_json
       end
     end
 
