@@ -6,19 +6,19 @@ require 'puppet/indirector/node/yaml'
 
 describe Puppet::Node::Yaml do
   it "should be a subclass of the Yaml terminus" do
-    Puppet::Node::Yaml.superclass.should equal(Puppet::Indirector::Yaml)
+    expect(Puppet::Node::Yaml.superclass).to equal(Puppet::Indirector::Yaml)
   end
 
   it "should have documentation" do
-    Puppet::Node::Yaml.doc.should_not be_nil
+    expect(Puppet::Node::Yaml.doc).not_to be_nil
   end
 
   it "should be registered with the configuration store indirection" do
     indirection = Puppet::Indirector::Indirection.instance(:node)
-    Puppet::Node::Yaml.indirection.should equal(indirection)
+    expect(Puppet::Node::Yaml.indirection).to equal(indirection)
   end
 
   it "should have its name set to :node" do
-    Puppet::Node::Yaml.name.should == :yaml
+    expect(Puppet::Node::Yaml.name).to eq(:yaml)
   end
 end
