@@ -5,6 +5,6 @@ require 'puppet/indirector/status/rest'
 
 describe Puppet::Indirector::Status::Rest do
   it "should be a subclass of Puppet::Indirector::REST" do
-    Puppet::Indirector::Status::Rest.superclass.should equal(Puppet::Indirector::REST)
+    expect(Puppet::Indirector::Status::Rest.superclass).to equal(Puppet::Indirector::REST)
   end
 end
