@@ -429,4 +429,11 @@ symlinkfile
 
     it_behaves_like "a packagable module"
   end
+
+  context 'when in FIPS mode...' do
+    it 'module builder refuses to run' do
+      Facter.stubs(:value).with(:fips_enabled).returns(true)
+      expect { builder.run }.to raise_error(/Module building is prohibited in FIPS mode/)
+    end 
+  end
 end
