@@ -2,7 +2,6 @@ require 'spec_helper'
 require 'puppet/module_tool/applications'
 require 'puppet_spec/module_tool/shared_functions'
 require 'puppet_spec/module_tool/stub_source'
-require 'semver'
 
 require 'tmpdir'
 
@@ -367,6 +366,14 @@ describe Puppet::ModuleTool::Applications::Installer do
         end
       end
     end
+
+    context 'when in FIPS mode...' do
+      it 'module installer refuses to run' do
+        Facter.stubs(:value).with(:fips_enabled).returns(true)
+        expect {application.run}.to raise_error(/Module install is prohibited in FIPS mode./)
+      end 
+    end
+
   end
 
 end
