@@ -162,4 +162,12 @@ describe Puppet::ModuleTool::Applications::Uninstaller do
       end
     end
   end
+
+  context 'when in FIPS mode...' do
+    it 'module uninstaller refuses to run' do
+      Facter.stubs(:value).with(:fips_enabled).returns(true)
+      expect {application.run}.to raise_error(/Module uninstall is prohibited in FIPS mode/)
+    end 
+  end
+
 end
