@@ -50,7 +50,7 @@ describe Puppet::Network::FormatHandler do
     end
   end
 
-  describe "#most_suitable_format_for" do
+  describe "#most_suitable_formats_for" do
     before :each do
       Puppet::Network::FormatHandler.create(:one, :extension => "foo", :mime => "text/one")
       Puppet::Network::FormatHandler.create(:two, :extension => "bar", :mime => "application/two")
@@ -60,35 +60,35 @@ describe Puppet::Network::FormatHandler do
     let(:format_two) { Puppet::Network::FormatHandler.format(:two) }
 
     def suitable_in_setup_formats(accepted)
-      Puppet::Network::FormatHandler.most_suitable_format_for(accepted, [:one, :two])
+      Puppet::Network::FormatHandler.most_suitable_formats_for(accepted, [:one, :two])
     end
 
     it "finds the most preferred format when anything is acceptable" do
-      expect(Puppet::Network::FormatHandler.most_suitable_format_for(["*/*"], [:two, :one])).to eq(format_two)
+      expect(Puppet::Network::FormatHandler.most_suitable_formats_for(["*/*"], [:two, :one])).to eq([format_two])
     end
 
     it "finds no format when none are acceptable" do
-      expect(suitable_in_setup_formats(["three"])).to be_nil
+      expect(suitable_in_setup_formats(["three"])).to eq([])
     end
 
-    it "skips unsupported, but accepted, formats" do
-      expect(suitable_in_setup_formats(["three", "two"])).to eq(format_two)
+    it "returns only the accepted and supported format" do
+      expect(suitable_in_setup_formats(["three", "two"])).to eq([format_two])
     end
 
-    it "gives the first acceptable and suitable format" do
-      expect(suitable_in_setup_formats(["three", "one", "two"])).to eq(format_one)
+    it "returns only accepted and supported formats, in order of accepted" do
+      expect(suitable_in_setup_formats(["three", "two", "one"])).to eq([format_two, format_one])
     end
 
     it "allows specifying acceptable formats by mime type" do
-      expect(suitable_in_setup_formats(["text/one"])).to eq(format_one)
+      expect(suitable_in_setup_formats(["text/one"])).to eq([format_one])
     end
 
     it "ignores quality specifiers" do
-      expect(suitable_in_setup_formats(["two;q=0.8", "text/one;q=0.9"])).to eq(format_two)
+      expect(suitable_in_setup_formats(["two;q=0.8", "text/one;q=0.9"])).to eq([format_two, format_one])
     end
 
     it "allows specifying acceptable formats by canonical name" do
-      expect(suitable_in_setup_formats([:one])).to eq(format_one)
+      expect(suitable_in_setup_formats([:one])).to eq([format_one])
     end
   end
 end
