@@ -492,4 +492,20 @@ describe Puppet::Node::Environment do
     end
   end
 
+  describe "managing module translations" do
+    it "creates a new text domain the first time we try to use the text domain" do
+      Puppet::GettextConfig.expects(:reset_text_domain).with(env.name)
+      Puppet::ModuleTranslations.expects(:load_from_modulepath)
+
+      env.use_text_domain
+    end
+
+    it "uses the existing text domain once it has been created" do
+      env.use_text_domain
+
+      Puppet::GettextConfig.expects(:use_text_domain).with(env.name)
+      env.use_text_domain
+    end
+  end
+
 end
