@@ -9,21 +9,21 @@ describe Puppet::Parameter::ValueCollection do
   end
 
   it "should have a method for defining new values" do
-    @collection.should respond_to(:newvalues)
+    expect(@collection).to respond_to(:newvalues)
   end
 
   it "should have a method for adding individual values" do
-    @collection.should respond_to(:newvalue)
+    expect(@collection).to respond_to(:newvalue)
   end
 
   it "should be able to retrieve individual values" do
     value = @collection.newvalue(:foo)
-    @collection.value(:foo).should equal(value)
+    expect(@collection.value(:foo)).to equal(value)
   end
 
   it "should be able to add an individual value with a block" do
     @collection.newvalue(:foo) { raise "testing" }
-    @collection.value(:foo).block.should be_instance_of(Proc)
+    expect(@collection.value(:foo).block).to be_instance_of(Proc)
   end
 
   it "should be able to add values that are empty strings" do
@@ -32,72 +32,67 @@ describe Puppet::Parameter::ValueCollection do
 
   it "should be able to add values that are empty strings" do
     value = @collection.newvalue('')
-    @collection.match?('').should equal(value)
-  end
-
-  it "should set :call to :none when adding a value with no block" do
-    value = @collection.newvalue(:foo)
-    value.call.should == :none
+    expect(@collection.match?('')).to equal(value)
   end
 
   describe "when adding a value with a block" do
     it "should set the method name to 'set_' plus the value name" do
       value = @collection.newvalue(:myval) { raise "testing" }
-      value.method.should == "set_myval"
+      expect(value.method).to eq("set_myval")
     end
   end
 
   it "should be able to add an individual value with options" do
-    value = @collection.newvalue(:foo, :call => :bar)
-    value.call.should == :bar
+    value = @collection.newvalue(:foo, :method => 'set_myval')
+    expect(value.method).to eq('set_myval')
   end
 
   it "should have a method for validating a value" do
-    @collection.should respond_to(:validate)
+    expect(@collection).to respond_to(:validate)
   end
 
   it "should have a method for munging a value" do
-    @collection.should respond_to(:munge)
+    expect(@collection).to respond_to(:munge)
   end
 
   it "should be able to generate documentation when it has both values and regexes" do
     @collection.newvalues :foo, "bar", %r{test}
-    @collection.doc.should be_instance_of(String)
+    expect(@collection.doc).to be_instance_of(String)
   end
 
   it "should correctly generate documentation for values" do
     @collection.newvalues :foo
-    @collection.doc.should be_include("Valid values are `foo`")
+    expect(@collection.doc).to be_include("Valid values are `foo`")
   end
 
   it "should correctly generate documentation for regexes" do
     @collection.newvalues %r{\w+}
-    @collection.doc.should be_include("Values can match `/\\w+/`")
+    expect(@collection.doc).to be_include("Values can match `/\\w+/`")
   end
 
   it "should be able to find the first matching value" do
     @collection.newvalues :foo, :bar
-    @collection.match?("foo").should be_instance_of(Puppet::Parameter::Value)
+    expect(@collection.match?("foo")).to be_instance_of(Puppet::Parameter::Value)
   end
 
   it "should be able to match symbols" do
     @collection.newvalues :foo, :bar
-    @collection.match?(:foo).should be_instance_of(Puppet::Parameter::Value)
+    expect(@collection.match?(:foo)).to be_instance_of(Puppet::Parameter::Value)
   end
 
   it "should be able to match symbols when a regex is provided" do
     @collection.newvalues %r{.}
-    @collection.match?(:foo).should be_instance_of(Puppet::Parameter::Value)
+    expect(@collection.match?(:foo)).to be_instance_of(Puppet::Parameter::Value)
   end
 
   it "should be able to match values using regexes" do
     @collection.newvalues %r{.}
-    @collection.match?("foo").should_not be_nil
+    expect(@collection.match?("foo")).not_to be_nil
   end
 
   it "should prefer value matches to regex matches" do
     @collection.newvalues %r{.}, :foo
-    @collection.match?("foo").name.should == :foo
+    expect(@collection.match?("foo").name).to eq(:foo)
   end
 
   describe "when validating values" do
@@ -139,28 +134,28 @@ describe Puppet::Parameter::ValueCollection do
 
   describe "when munging values" do
     it "should do nothing if no values or regexes have been defined" do
-      @collection.munge("foo").should == "foo"
+      expect(@collection.munge("foo")).to eq("foo")
     end
 
     it "should return return any matching defined values" do
       @collection.newvalues :foo, :bar
-      @collection.munge("foo").should == :foo
+      expect(@collection.munge("foo")).to eq(:foo)
     end
 
     it "should return any matching aliases" do
       @collection.newvalues :foo
       @collection.aliasvalue :bar, :foo
-      @collection.munge("bar").should == :foo
+      expect(@collection.munge("bar")).to eq(:foo)
     end
 
     it "should return the value if it matches a regex" do
       @collection.newvalues %r{\w}
-      @collection.munge("bar").should == "bar"
+      expect(@collection.munge("bar")).to eq("bar")
     end
 
     it "should return the value if no other option is matched" do
       @collection.newvalues :foo
-      @collection.munge("bar").should == "bar"
+      expect(@collection.munge("bar")).to eq("bar")
     end
   end
 end
