@@ -12,19 +12,28 @@ describe Puppet::Parser::TypeLoader do
 
   let(:empty_hostclass) { Puppet::Parser::AST::Hostclass.new('') }
   let(:loader) { Puppet::Parser::TypeLoader.new(:myenv) }
+  let(:my_env) { Puppet::Node::Environment.create(:myenv, []) }
+
+  around do |example|
+    envs = Puppet::Environments::Static.new(my_env)
+
+    Puppet.override(:environments => envs) do
+      example.run
+    end
+  end
 
   it "should support an environment" do
     loader = Puppet::Parser::TypeLoader.new(:myenv)
-    loader.environment.name.should == :myenv
+    expect(loader.environment.name).to eq(:myenv)
   end
 
   it "should delegate its known resource types to its environment" do
-    loader.known_resource_types.should be_instance_of(Puppet::Resource::TypeCollection)
+    expect(loader.known_resource_types).to be_instance_of(Puppet::Resource::TypeCollection)
   end
 
   describe "when loading names from namespaces" do
     it "should do nothing if the name to import is an empty string" do
-      loader.try_load_fqname(:hostclass, "").should be_nil
+      expect(loader.try_load_fqname(:hostclass, "")).to be_nil
     end
 
     it "should attempt to import each generated name" do
@@ -50,12 +59,6 @@ describe Puppet::Parser::TypeLoader do
       Puppet::Parser::ParserFactory.stubs(:parser).with(anything).returns(stub_parser)
     end
 
-    it "should return immediately when imports are being ignored" do
-      Puppet::Parser::Files.expects(:find_manifests_in_modules).never
-      Puppet[:ignoreimport] = true
-      loader.import("foo", "/path").should be_nil
-    end
-
     it "should find all manifests matching the file or pattern" do
       Puppet::Parser::Files.expects(:find_manifests_in_modules).with("myfile", anything).returns ["modname", %w{one}]
       loader.import("myfile", "/path")
@@ -68,7 +71,7 @@ describe Puppet::Parser::TypeLoader do
 
     it "should fail if no files are found" do
       Puppet::Parser::Files.expects(:find_manifests_in_modules).returns [nil, []]
-      lambda { loader.import("myfile", "/path") }.should raise_error(Puppet::ImportError)
+      expect { loader.import("myfile", "/path") }.to raise_error(/No file\(s\) found for import/)
     end
 
     it "should parse each found file" do
@@ -81,23 +84,22 @@ describe Puppet::Parser::TypeLoader do
       loader = Puppet::Parser::TypeLoader.new(:myenv)
 
       Puppet::Parser::Files.expects(:find_manifests_in_modules).twice.returns ["modname", %w{/one}]
-      loader.import("myfile", "/path").should_not be_empty
+      expect(loader.import("myfile", "/path")).not_to be_empty
 
-      loader.import("myfile", "/path").should be_empty
+      expect(loader.import("myfile", "/path")).to be_empty
     end
   end
 
   describe "when importing all" do
+    let(:base) { tmpdir("base") }
+    let(:modulebase1) { File.join(base, "first") }
+    let(:modulebase2) { File.join(base, "second") }
+    let(:my_env) { Puppet::Node::Environment.create(:myenv, [modulebase1, modulebase2]) }
+
     before do
-      @base = tmpdir("base")
-
       # Create two module path directories
-      @modulebase1 = File.join(@base, "first")
-      FileUtils.mkdir_p(@modulebase1)
-      @modulebase2 = File.join(@base, "second")
-      FileUtils.mkdir_p(@modulebase2)
-
-      Puppet[:modulepath] = "#{@modulebase1}#{File::PATH_SEPARATOR}#{@modulebase2}"
+      FileUtils.mkdir_p(modulebase1)
+      FileUtils.mkdir_p(modulebase2)
     end
 
     def mk_module(basedir, name)
@@ -106,107 +108,85 @@ describe Puppet::Parser::TypeLoader do
 
     # We have to pass the base path so that we can
     # write to modules that are in the second search path
-    def mk_manifests(base, mod, type, files)
-      exts = {"ruby" => ".rb", "puppet" => ".pp"}
+    def mk_manifests(base, mod, files)
       files.collect do |file|
         name = mod.name + "::" + file.gsub("/", "::")
-        path = File.join(base, mod.name, "manifests", file + exts[type])
+        path = File.join(base, mod.name, "manifests", file + ".pp")
         FileUtils.mkdir_p(File.split(path)[0])
 
         # write out the class
-        if type == "ruby"
-          File.open(path, "w") { |f| f.print "hostclass '#{name}' do\nend" }
-        else
-          File.open(path, "w") { |f| f.print "class #{name} {}" }
-        end
+        File.open(path, "w") { |f| f.print "class #{name} {}" }
         name
       end
     end
 
     it "should load all puppet manifests from all modules in the specified environment" do
-      @module1 = mk_module(@modulebase1, "one")
-      @module2 = mk_module(@modulebase2, "two")
+      module1 = mk_module(modulebase1, "one")
+      module2 = mk_module(modulebase2, "two")
 
-      mk_manifests(@modulebase1, @module1, "puppet", %w{a b})
-      mk_manifests(@modulebase2, @module2, "puppet", %w{c d})
+      mk_manifests(modulebase1, module1, %w{a b})
+      mk_manifests(modulebase2, module2, %w{c d})
 
       loader.import_all
 
-      loader.environment.known_resource_types.hostclass("one::a").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("one::b").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("two::c").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("two::d").should be_instance_of(Puppet::Resource::Type)
-    end
-
-    it "should load all ruby manifests from all modules in the specified environment" do
-      Puppet.expects(:deprecation_warning).at_least(1)
-
-      @module1 = mk_module(@modulebase1, "one")
-      @module2 = mk_module(@modulebase2, "two")
-
-      mk_manifests(@modulebase1, @module1, "ruby", %w{a b})
-      mk_manifests(@modulebase2, @module2, "ruby", %w{c d})
-
-      loader.import_all
-
-      loader.environment.known_resource_types.hostclass("one::a").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("one::b").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("two::c").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("two::d").should be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("one::a")).to be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("one::b")).to be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("two::c")).to be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("two::d")).to be_instance_of(Puppet::Resource::Type)
     end
 
     it "should not load manifests from duplicate modules later in the module path" do
-      @module1 = mk_module(@modulebase1, "one")
+      module1 = mk_module(modulebase1, "one")
 
       # duplicate
-      @module2 = mk_module(@modulebase2, "one")
+      module2 = mk_module(modulebase2, "one")
 
-      mk_manifests(@modulebase1, @module1, "puppet", %w{a})
-      mk_manifests(@modulebase2, @module2, "puppet", %w{c})
+      mk_manifests(modulebase1, module1, %w{a})
+      mk_manifests(modulebase2, module2, %w{c})
 
       loader.import_all
 
-      loader.environment.known_resource_types.hostclass("one::c").should be_nil
+      expect(loader.environment.known_resource_types.hostclass("one::c")).to be_nil
     end
 
     it "should load manifests from subdirectories" do
-      @module1 = mk_module(@modulebase1, "one")
+      module1 = mk_module(modulebase1, "one")
 
-      mk_manifests(@modulebase1, @module1, "puppet", %w{a a/b a/b/c})
+      mk_manifests(modulebase1, module1, %w{a a/b a/b/c})
 
       loader.import_all
 
-      loader.environment.known_resource_types.hostclass("one::a::b").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("one::a::b::c").should be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("one::a::b")).to be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("one::a::b::c")).to be_instance_of(Puppet::Resource::Type)
     end
 
     it "should skip modules that don't have manifests" do
-      @module1 = mk_module(@modulebase1, "one")
-      @module2 = mk_module(@modulebase2, "two")
-      mk_manifests(@modulebase2, @module2, "ruby", %w{c d})
+      module1 = mk_module(modulebase1, "one")
+      module2 = mk_module(modulebase2, "two")
+      mk_manifests(modulebase2, module2, %w{c d})
 
       loader.import_all
 
-      loader.environment.known_resource_types.hostclass("one::a").should be_nil
-      loader.environment.known_resource_types.hostclass("two::c").should be_instance_of(Puppet::Resource::Type)
-      loader.environment.known_resource_types.hostclass("two::d").should be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("one::a")).to be_nil
+      expect(loader.environment.known_resource_types.hostclass("two::c")).to be_instance_of(Puppet::Resource::Type)
+      expect(loader.environment.known_resource_types.hostclass("two::d")).to be_instance_of(Puppet::Resource::Type)
     end
   end
 
   describe "when parsing a file" do
-    it "should create a new parser instance for each file using the current environment" do
+    it "requests a new parser instance for each file" do
       parser = stub 'Parser', :file= => nil, :parse => empty_hostclass
 
-      Puppet::Parser::ParserFactory.expects(:parser).twice.with(loader.environment).returns(parser)
+      Puppet::Parser::ParserFactory.expects(:parser).twice.returns(parser)
 
       loader.parse_file("/my/file")
       loader.parse_file("/my/other_file")
     end
 
-    it "should assign the parser its file and parse" do
+    it "assigns the parser its file and then parses" do
       parser = mock 'parser'
 
-      Puppet::Parser::ParserFactory.expects(:parser).with(loader.environment).returns(parser)
+      Puppet::Parser::ParserFactory.expects(:parser).returns(parser)
       parser.expects(:file=).with("/my/file")
       parser.expects(:parse).returns(empty_hostclass)
 
@@ -219,6 +199,6 @@ describe Puppet::Parser::TypeLoader do
     File.open(file, "w") { |f| f.puts "class foo {}" }
     loader.import(File.basename(file), File.dirname(file))
 
-    loader.known_resource_types.hostclass("foo").should be_instance_of(Puppet::Resource::Type)
+    expect(loader.known_resource_types.hostclass("foo")).to be_instance_of(Puppet::Resource::Type)
   end
 end
