@@ -29,7 +29,7 @@ describe Puppet::Pops::Adaptable::Adapter do
   it "should create specialized adapter instance on call to adapt" do
     d = Duck.new
     a = ValueAdapter.adapt(d)
-    a.class.should == ValueAdapter
+    expect(a.class).to eq(ValueAdapter)
   end
 
   it "should produce the same instance on multiple adaptations" do
@@ -37,7 +37,7 @@ describe Puppet::Pops::Adaptable::Adapter do
     a = ValueAdapter.adapt(d)
     a.value = 10
     b = ValueAdapter.adapt(d)
-    b.value.should == 10
+    expect(b.value).to eq(10)
   end
 
   it "should return the correct adapter if there are several" do
@@ -46,61 +46,61 @@ describe Puppet::Pops::Adaptable::Adapter do
     a = ValueAdapter.adapt(d)
     a.value = 10
     b = ValueAdapter.adapt(d)
-    b.value.should == 10
+    expect(b.value).to eq(10)
   end
 
   it "should allow specialization to override creating" do
     d = Duck.new
     a = OtherAdapter.adapt(d)
-    a.value.should == "I am calling you Daffy."
+    expect(a.value).to eq("I am calling you Daffy.")
   end
 
   it "should create a new adapter overriding existing" do
     d = Duck.new
     a = OtherAdapter.adapt(d)
-    a.value.should == "I am calling you Daffy."
+    expect(a.value).to eq("I am calling you Daffy.")
     a.value = "Something different"
-    a.value.should == "Something different"
+    expect(a.value).to eq("Something different")
     b = OtherAdapter.adapt(d)
-    b.value.should == "Something different"
+    expect(b.value).to eq("Something different")
     b = OtherAdapter.adapt_new(d)
-    b.value.should == "I am calling you Daffy."
+    expect(b.value).to eq("I am calling you Daffy.")
   end
 
   it "should not create adapter on get" do
     d = Duck.new
     a = OtherAdapter.get(d)
-    a.should == nil
+    expect(a).to eq(nil)
   end
 
   it "should return same adapter from get after adapt" do
     d = Duck.new
     a = OtherAdapter.get(d)
-    a.should == nil
+    expect(a).to eq(nil)
     a = OtherAdapter.adapt(d)
-    a.value.should == "I am calling you Daffy."
+    expect(a.value).to eq("I am calling you Daffy.")
     b = OtherAdapter.get(d)
-    b.value.should == "I am calling you Daffy."
-    a.should == b
+    expect(b.value).to eq("I am calling you Daffy.")
+    expect(a).to eq(b)
   end
 
   it "should handle adapters in nested namespaces" do
     d = Duck.new
     a = Farm::FarmAdapter.get(d)
-    a.should == nil
+    expect(a).to eq(nil)
     a = Farm::FarmAdapter.adapt(d)
     a.value = 10
     b = Farm::FarmAdapter.get(d)
-    b.value.should == 10
+    expect(b.value).to eq(10)
   end
 
   it "should be able to clear the adapter" do
     d = Duck.new
     a = OtherAdapter.adapt(d)
-    a.value.should == "I am calling you Daffy."
+    expect(a.value).to eq("I am calling you Daffy.")
     # The adapter cleared should be returned
-    OtherAdapter.clear(d).value.should == "I am calling you Daffy."
-    OtherAdapter.get(d).should == nil
+    expect(OtherAdapter.clear(d).value).to eq("I am calling you Daffy.")
+    expect(OtherAdapter.get(d)).to eq(nil)
   end
 
   context "When adapting with #adapt it" do
@@ -109,7 +109,7 @@ describe Puppet::Pops::Adaptable::Adapter do
       a = OtherAdapter.adapt(d) do |x|
         x.value = "Donald"
       end
-      a.value.should == "Donald"
+      expect(a.value).to eq("Donald")
     end
 
     it "should be possible to pass a block to configure the adapter and get the adapted" do
@@ -117,7 +117,7 @@ describe Puppet::Pops::Adaptable::Adapter do
       a = OtherAdapter.adapt(d) do |x, o|
         x.value = "Donald, the #{o.class.name}"
       end
-      a.value.should == "Donald, the Duck"
+      expect(a.value).to eq("Donald, the Duck")
     end
   end
 
@@ -127,7 +127,7 @@ describe Puppet::Pops::Adaptable::Adapter do
       a = OtherAdapter.adapt_new(d) do |x|
         x.value = "Donald"
       end
-      a.value.should == "Donald"
+      expect(a.value).to eq("Donald")
     end
 
     it "should be possible to pass a block to configure the adapter and get the adapted" do
@@ -135,7 +135,7 @@ describe Puppet::Pops::Adaptable::Adapter do
       a = OtherAdapter.adapt_new(d) do |x, o|
         x.value = "Donald, the #{o.class.name}"
       end
-      a.value.should == "Donald, the Duck"
+      expect(a.value).to eq("Donald, the Duck")
     end
   end
 end
