@@ -230,6 +230,17 @@ describe 'loaders' do
       expect(function.call({})).to eql("usee2::callee() was told 'passed value' + I am user::caller2()")
     end
 
+    it 'all other modules are visible when tasks are enabled' do
+      Puppet[:tasks] = true
+
+      env = environment_for(File.join(dependent_modules_with_metadata, 'modules'))
+      loaders = Puppet::Pops::Loaders.new(env)
+
+      moduleb_loader = loaders.private_loader_for_module('user')
+      function = moduleb_loader.load_typed(typed_name(:function, 'user::caller')).value
+      expect(function.call({})).to eql("usee::callee() was told 'passed value' + I am user::caller()")
+    end
+
     [ 'outside a function', 'a puppet function declared under functions', 'a puppet function declared in init.pp', 'a ruby function'].each_with_index do |from, from_idx|
       [ {:from => from, :called => 'a puppet function declared under functions', :expects => "I'm the function usee::usee_puppet()"},
         {:from => from, :called => 'a puppet function declared in init.pp', :expects => "I'm the function usee::usee_puppet_init()"},
@@ -476,6 +487,9 @@ describe 'loaders' do
 
       let(:env_dir_files) do
         {
+          'types' => {
+            'c.pp' => 'type C = Integer'
+          },
           'modules' => {
             'a' => {
               'manifests' => {
@@ -496,7 +510,27 @@ describe 'loaders' do
             },
             'c' => {
               'types' => {
-                'c.pp' => 'type C::C = Integer'
+                'init_typeset.pp' => <<-PUPPET.unindent,
+                  type C = TypeSet[{
+                    pcore_version => '1.0.0',
+                    types => {
+                      C => Integer,
+                      D => Float
+                    }
+                  }]
+                  PUPPET
+                'd.pp' => <<-PUPPET.unindent,
+                  type C::D = TypeSet[{
+                    pcore_version => '1.0.0',
+                    types => {
+                      X => String,
+                      Y => Float
+                    }
+                  }]
+                  PUPPET
+                'd' => {
+                  'y.pp' => 'type C::D::Y = Integer'
+                }
               },
               'metadata.json' => sprintf(metadata_json, 'c', '')
             },
@@ -545,6 +579,51 @@ describe 'loaders' do
         expect(type).to be_a(Puppet::Pops::Types::PTypeReferenceType)
         expect(type.type_string).to eql('A::A')
       end
+
+      it 'does not resolve init_typeset when more qualified type is found in typeset' do
+        type = Puppet::Pops::Types::TypeParser.singleton.parse('C::D::X', Puppet::Pops::Loaders.find_loader('c'))
+        expect(type).to be_a(Puppet::Pops::Types::PTypeAliasType)
+        expect(type.resolved_type).to be_a(Puppet::Pops::Types::PStringType)
+      end
+
+      it 'defined TypeSet type shadows type defined inside of TypeSet' do
+        type = Puppet::Pops::Types::TypeParser.singleton.parse('C::D', Puppet::Pops::Loaders.find_loader('c'))
+        expect(type).to be_a(Puppet::Pops::Types::PTypeSetType)
+      end
+
+      it 'parent name search does not traverse parent loaders' do
+        type = Puppet::Pops::Types::TypeParser.singleton.parse('C::C', Puppet::Pops::Loaders.find_loader('c'))
+        expect(type).to be_a(Puppet::Pops::Types::PTypeAliasType)
+        expect(type.resolved_type).to be_a(Puppet::Pops::Types::PIntegerType)
+      end
+
+      it 'global type defined in environment trumps modules init_typeset type' do
+        type = Puppet::Pops::Types::TypeParser.singleton.parse('C', Puppet::Pops::Loaders.find_loader('c'))
+        expect(type).to be_a(Puppet::Pops::Types::PTypeAliasType)
+        expect(type.resolved_type).to be_a(Puppet::Pops::Types::PIntegerType)
+      end
+
+      it 'hit on qualified name trumps hit on typeset using parent name + traversal' do
+        type = Puppet::Pops::Types::TypeParser.singleton.parse('C::D::Y', Puppet::Pops::Loaders.find_loader('c'))
+        expect(type).to be_a(Puppet::Pops::Types::PTypeAliasType)
+        expect(type.resolved_type).to be_a(Puppet::Pops::Types::PIntegerType)
+      end
+
+      it 'hit on qualified name and subsequent hit in typeset when searching for other name causes collision' do
+        l = Puppet::Pops::Loaders.find_loader('c')
+        p = Puppet::Pops::Types::TypeParser.singleton
+        p.parse('C::D::Y', l)
+        expect { p.parse('C::D::X', l) }.to raise_error(/Attempt to redefine entity 'http:\/\/puppet.com\/2016.1\/runtime\/type\/c::d::y'/)
+      end
+
+      it 'hit in typeset using parent name and subsequent search that would cause hit on fqn does not cause collision (fqn already loaded from typeset)' do
+        l = Puppet::Pops::Loaders.find_loader('c')
+        p = Puppet::Pops::Types::TypeParser.singleton
+        p.parse('C::D::X', l)
+        type = p.parse('C::D::Y', l)
+        expect(type).to be_a(Puppet::Pops::Types::PTypeAliasType)
+        expect(type.resolved_type).to be_a(Puppet::Pops::Types::PFloatType)
+      end
     end
   end
 
