@@ -1,28 +1,62 @@
 #! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet'
-require 'puppet/data_providers/hiera_config'
-require 'puppet/data_providers/hiera_interpolate'
 
 module Puppet::Pops
 describe 'Puppet::Pops::Lookup::Interpolation' do
+  include Lookup::SubLookup
+
+  class InterpolationTestAdapter < Lookup::LookupAdapter
+    include Lookup::SubLookup
+
+    def initialize(data, interpolator)
+      @data = data
+      @interpolator = interpolator
+    end
+
+    def track(name)
+    end
+
+    def lookup(name, lookup_invocation, merge)
+      track(name)
+      segments = split_key(name)
+      root_key = segments.shift
+      found = @data[root_key]
+      found = sub_lookup(name, lookup_invocation, segments, found) unless segments.empty?
+      @interpolator.interpolate(found, lookup_invocation, true)
+    end
+  end
 
   let(:interpolator) { Class.new { include Lookup::Interpolation }.new }
   let(:scope) { {} }
+  let(:data) { {} }
+  let(:adapter) { InterpolationTestAdapter.new(data, interpolator) }
   let(:lookup_invocation) { Lookup::Invocation.new(scope, {}, {}, nil) }
 
+  before(:each) do
+    Lookup::Invocation.any_instance.stubs(:lookup_adapter).returns(adapter)
+  end
+
   def expect_lookup(*keys)
-    keys.each { |key| Lookup.expects(:lookup).with(key, nil, '', true, nil, lookup_invocation).returns(data[key]) }
+    keys.each { |key| adapter.expects(:track).with(key) }
   end
 
   context 'when interpolating nested data' do
     let(:nested_hash) { {'a' => {'aa' => "%{alias('aaa')}"}} }
 
+    let(:scope) {
+      {
+        'ds1' => 'a',
+        'ds2' => 'b'
+      }
+    }
+
     let(:data) {
       {
         'aaa' => {'b' => {'bb' => "%{alias('bbb')}"}},
         'bbb' => ["%{alias('ccc')}"],
-        'ccc' => 'text'
+        'ccc' => 'text',
+        'ddd' => "%{literal('%')}{ds1}_%{literal('%')}{ds2}",
       }
     }
 
@@ -30,6 +64,16 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
       expect_lookup('aaa', 'bbb', 'ccc')
       expect(interpolator.interpolate(nested_hash, lookup_invocation, true)).to eq('a' => {'aa' => {'b' => {'bb' => ['text']}}})
     end
+
+    it "'%{lookup('key')} will interpolate the returned value'" do
+      expect_lookup('ddd')
+      expect(interpolator.interpolate("%{lookup('ddd')}", lookup_invocation, true)).to eq('a_b')
+    end
+
+    it "'%{alias('key')} will not interpolate the returned value'" do
+      expect_lookup('ddd')
+      expect(interpolator.interpolate("%{alias('ddd')}", lookup_invocation, true)).to eq('%{ds1}_%{ds2}')
+    end
   end
 
   context 'when interpolating boolean scope values' do
@@ -160,12 +204,12 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should find an entry using a quoted interpolation with method lookup' do
-      expect_lookup('a.b')
+      expect_lookup("'a.b'")
       expect(interpolator.interpolate("a dot c: %{lookup(\"'a.b'\")}", lookup_invocation, true)).to eq('a dot c: (lookup) a dot b')
     end
 
     it 'should find an entry using a quoted interpolation with method alias' do
-      expect_lookup('a.b')
+      expect_lookup("'a.b'")
       expect(interpolator.interpolate("%{alias(\"'a.b'\")}", lookup_invocation, true)).to eq('(lookup) a dot b')
     end
 
@@ -173,8 +217,12 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
       expect(interpolator.interpolate('a dot e: %{a.d}', lookup_invocation, true)).to eq('a dot e: (scope) a dot d is a hash entry')
     end
 
-    it 'should use a dotted key to navigate into a structure when when it is not quoted with method lookup' do
-      expect_lookup('a')
+    it 'should report a key missing and replace with empty string when a dotted key is used to navigate into a structure and then not found' do
+      expect(interpolator.interpolate('a dot n: %{a.n}', lookup_invocation, true)).to eq('a dot n: ')
+    end
+
+    it 'should use a dotted key to navigate into a structure when it is not quoted with method lookup' do
+      expect_lookup('a.d')
       expect(interpolator.interpolate("a dot e: %{lookup('a.d')}", lookup_invocation, true)).to eq('a dot e: (lookup) a dot d is a hash entry')
     end
 
@@ -183,7 +231,7 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should use a mix of quoted and dotted keys to navigate into a structure containing dotted keys and quoted key is last and method is lookup' do
-      expect_lookup('a')
+      expect_lookup("a.'d.x'")
       expect(interpolator.interpolate("a dot ex: %{lookup(\"a.'d.x'\")}", lookup_invocation, true)).to eq('a dot ex: (lookup) a dot d.x is a hash entry')
     end
 
@@ -192,7 +240,7 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should use a mix of quoted and dotted keys to navigate into a structure containing dotted keys and quoted key is first and method is lookup' do
-      expect_lookup('a.x')
+      expect_lookup("'a.x'.d")
       expect(interpolator.interpolate("a dot xe: %{lookup(\"'a.x'.d\")}", lookup_invocation, true)).to eq('a dot xe: (lookup) a.x dot d is a hash entry')
     end
 
@@ -201,7 +249,7 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should use a mix of quoted and dotted keys to navigate into a structure containing dotted keys and quoted key is in the middle and method is lookup' do
-      expect_lookup('a')
+      expect_lookup("a.'d.z'.g")
       expect(interpolator.interpolate("a dot xm: %{lookup(\"a.'d.z'.g\")}", lookup_invocation, true)).to eq('a dot xm: (lookup) a dot d.z dot g is a hash entry')
     end
 
@@ -210,7 +258,7 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should use a mix of several quoted and dotted keys to navigate into a structure containing dotted keys and quoted key is in the middle and method is lookup' do
-      expect_lookup('a.x')
+      expect_lookup("'a.x'.'d.z'.g")
       expect(interpolator.interpolate("a dot xx: %{lookup(\"'a.x'.'d.z'.g\")}", lookup_invocation, true)).to eq('a dot xx: (lookup) a.x dot d.z dot g is a hash entry')
     end
 
@@ -219,7 +267,7 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should find an entry using using a quoted interpolation on dotted key containing numbers using method lookup' do
-      expect_lookup('x.1')
+      expect_lookup("'x.1'")
       expect(interpolator.interpolate("x dot 2: %{lookup(\"'x.1'\")}", lookup_invocation, true)).to eq('x dot 2: (lookup) x dot 1')
     end
 
@@ -228,13 +276,13 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'should not find a subkey when the dotted key is quoted with method lookup' do
-      expect_lookup('a.d')
+      expect_lookup("'a.d'")
       expect(interpolator.interpolate("a dot f: %{lookup(\"'a.d'\")}", lookup_invocation, true)).to eq('a dot f: ')
     end
 
     it 'should not find a subkey that is matched within a string' do
-      expect_lookup('key')
-      expect{ interpolator.interpolate('%{hiera("key.subkey")}', lookup_invocation, true) }.to raise_error(/Got String when a hash-like object was expected to access value using 'subkey' from key 'key.subkey'/)
+      expect{ interpolator.interpolate("%{lookup('key.subkey')}", lookup_invocation, true) }.to raise_error(
+        /Got String when a hash-like object was expected to access value using 'subkey' from key 'key.subkey'/)
     end
   end
 
@@ -267,27 +315,27 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
 
     it 'allows dotted keys with non alphanumeric characters' do
-      expect_lookup('very_angry', '!$\%!')
+      expect_lookup('very_angry', '!$\%!.\#@!&%|')
       expect(interpolator.interpolate("%{lookup('very_angry')}", lookup_invocation, true)).to eq('not happy at all')
     end
 
     it 'allows dotted keys with nested white space' do
-      expect_lookup('a key with')
+      expect_lookup('a key with.nested whitespace')
       expect(interpolator.interpolate("%{lookup('a key with.nested whitespace')}", lookup_invocation, true)).to eq('value for nested ws key')
     end
 
     it 'will trim each key element' do
-      expect_lookup('a key with')
+      expect_lookup(' a key with . nested whitespace ')
       expect(interpolator.interpolate("%{lookup(' a key with . nested whitespace ')}", lookup_invocation, true)).to eq('value for nested ws key')
     end
 
     it 'will not trim quoted key element' do
-      expect_lookup('a key with')
+      expect_lookup(' a key with ." untrimmed whitespace "')
       expect(interpolator.interpolate("%{lookup(' a key with .\" untrimmed whitespace \"')}", lookup_invocation, true)).to eq('value for untrimmed ws key')
     end
 
     it 'will not trim spaces outside of quoted key element' do
-      expect_lookup('a key with')
+      expect_lookup(' a key with .  " untrimmed whitespace "  ')
       expect(interpolator.interpolate("%{lookup(' a key with .  \" untrimmed whitespace \"  ')}", lookup_invocation, true)).to eq('value for untrimmed ws key')
     end
   end
@@ -322,4 +370,4 @@ describe 'Puppet::Pops::Lookup::Interpolation' do
     end
   end
 end
-end
\ No newline at end of file
+end
