@@ -94,38 +94,28 @@ describe 'Lexer2' do
     "private"  => :PRIVATE,
     "type"     => :TYPE,
     "attr"     => :ATTR,
+    "application"  => :APPLICATION,
+    "consumes"     => :CONSUMES,
+    "produces"     => :PRODUCES,
+    "site"         => :SITE,
   }.each do |string, name|
     it "should lex a keyword from '#{string}'" do
       expect(tokens_scanned_from(string)).to match_tokens2(name)
     end
   end
 
-  context 'when app_management is off (by default)' do
-    {
-      "application"  => :APPLICATION_R,
-      "consumes"     => :CONSUMES_R,
-      "produces"     => :PRODUCES_R,
-      "site"         => :SITE_R,
-    }.each do |string, name|
-      it "should lex a (future reserved) keyword from '#{string}'" do
-        expect(tokens_scanned_from(string)).to match_tokens2(name)
-      end
+  context 'when --no-tasks (the default)' do
+    it "should lex a NAME from 'plan'" do
+      expect(tokens_scanned_from('plan')).to match_tokens2(:NAME)
     end
   end
 
-  context 'when app_managment is (turned) on' do
-    before(:each) { Puppet[:app_management] = true }
-    after(:each) { Puppet[:app_management] = false }
+  context 'when --tasks' do
+    before(:each) { Puppet[:tasks] = true }
+    after(:each) { Puppet[:tasks] = false }
 
-    {
-      "application"  => :APPLICATION,
-      "consumes"     => :CONSUMES,
-      "produces"     => :PRODUCES,
-      "site"         => :SITE,
-    }.each do |string, name|
-      it "should lex a keyword from '#{string}'" do
-        expect(tokens_scanned_from(string)).to match_tokens2(name)
-      end
+    it "should lex a keyword from 'plan'" do
+      expect(tokens_scanned_from('plan')).to match_tokens2(:PLAN)
     end
   end
 
@@ -473,6 +463,36 @@ describe 'Lexer2' do
         )
     end
 
+    it 'strips only last newline when using trim option' do
+      code = <<-CODE.unindent
+        @(END)
+        Line 1
+        
+        Line 2
+        -END
+        CODE
+      expect(tokens_scanned_from(code)).to match_tokens2(
+        [:HEREDOC, ''],
+        [:SUBLOCATE, ["Line 1\n", "\n", "Line 2\n"]],
+        [:STRING, "Line 1\n\nLine 2"],
+      )
+    end
+
+    it 'strips only one newline at the end when using trim option' do
+      code = <<-CODE.unindent
+        @(END)
+        Line 1
+        Line 2
+        
+        -END
+      CODE
+      expect(tokens_scanned_from(code)).to match_tokens2(
+        [:HEREDOC, ''],
+        [:SUBLOCATE, ["Line 1\n", "Line 2\n", "\n"]],
+        [:STRING, "Line 1\nLine 2\n"],
+      )
+    end
+
     context 'with bad syntax' do
       def expect_issue(code, issue)
         expect { tokens_scanned_from(code) }.to raise_error(Puppet::ParseErrorWithIssue) { |e|
