@@ -15,28 +15,265 @@ describe 'Puppet Ruby Generator' do
   let!(:parser) { TypeParser.singleton }
   let(:generator) { RubyGenerator.new }
 
-  context 'when generating from Object types' do
-    def source
-      <<-CODE
-        type MyModule::FirstGenerated = Object[{
-          attributes => {
-            name => String,
-            age  => { type => Integer, value => 30 },
-            what => { type => String, value => 'what is this', kind => constant }
-          }
-        }]
-        type MyModule::SecondGenerated = Object[{
-          parent => MyModule::FirstGenerated,
-          attributes => {
-            address => String,
-            zipcode => String,
-            email => String,
-            another => { type => Optional[MyModule::FirstGenerated], value => undef },
-            number => Integer
-          }
-        }]
-      CODE
+  context 'when generating classes for Objects having attribute names that are Ruby reserved words' do
+    let (:source) { <<-PUPPET }
+      type MyObject = Object[{
+        attributes => {
+          alias => String,
+          begin => String,
+          break => String,
+          def => String,
+          do => String,
+          end => String,
+          ensure => String,
+          for => String,
+          module => String,
+          next => String,
+          nil => String,
+          not => String,
+          redo => String,
+          rescue => String,
+          retry => String,
+          return => String,
+          self => String,
+          super => String,
+          then => String,
+          until => String,
+          when => String,
+          while => String,
+          yield => String,
+        },
+      }]
+      $x = MyObject({
+        alias => 'value of alias',
+        begin => 'value of begin',
+        break => 'value of break',
+        def => 'value of def',
+        do => 'value of do',
+        end => 'value of end',
+        ensure => 'value of ensure',
+        for => 'value of for',
+        module => 'value of module',
+        next => 'value of next',
+        nil => 'value of nil',
+        not => 'value of not',
+        redo => 'value of redo',
+        rescue => 'value of rescue',
+        retry => 'value of retry',
+        return => 'value of return',
+        self => 'value of self',
+        super => 'value of super',
+        then => 'value of then',
+        until => 'value of until',
+        when => 'value of when',
+        while => 'value of while',
+        yield => 'value of yield',
+      })
+      notice($x.alias)
+      notice($x.begin)
+      notice($x.break)
+      notice($x.def)
+      notice($x.do)
+      notice($x.end)
+      notice($x.ensure)
+      notice($x.for)
+      notice($x.module)
+      notice($x.next)
+      notice($x.nil)
+      notice($x.not)
+      notice($x.redo)
+      notice($x.rescue)
+      notice($x.retry)
+      notice($x.return)
+      notice($x.self)
+      notice($x.super)
+      notice($x.then)
+      notice($x.until)
+      notice($x.when)
+      notice($x.while)
+      notice($x.yield)
+    PUPPET
+
+    it 'can create an instance and access all attributes' do
+      expect(eval_and_collect_notices(source)).to eql([
+        'value of alias',
+        'value of begin',
+        'value of break',
+        'value of def',
+        'value of do',
+        'value of end',
+        'value of ensure',
+        'value of for',
+        'value of module',
+        'value of next',
+        'value of nil',
+        'value of not',
+        'value of redo',
+        'value of rescue',
+        'value of retry',
+        'value of return',
+        'value of self',
+        'value of super',
+        'value of then',
+        'value of until',
+        'value of when',
+        'value of while',
+        'value of yield',
+      ])
     end
+  end
+
+  context 'when generating classes for Objects having function names that are Ruby reserved words' do
+    let (:source) { <<-PUPPET }
+      type MyObject = Object[{
+        functions => {
+          alias  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of alias'" }}},
+          begin  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of begin'" }}},
+          break  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of break'" }}},
+          def    => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of def'" }}},
+          do     => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of do'" }}},
+          end    => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of end'" }}},
+          ensure => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of ensure'" }}},
+          for    => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of for'" }}},
+          module => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of module'" }}},
+          next   => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of next'" }}},
+          nil    => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of nil'" }}},
+          not    => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of not'" }}},
+          redo   => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of redo'" }}},
+          rescue => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of rescue'" }}},
+          retry  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of retry'" }}},
+          return => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of return'" }}},
+          self   => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of self'" }}},
+          super  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of super'" }}},
+          then   => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of then'" }}},
+          until  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of until'" }}},
+          when   => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of when'" }}},
+          while  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of while'" }}},
+          yield  => { type => Callable[[0,0],String], annotations => {RubyMethod => { 'body' => "'value of yield'" }}},
+        },
+      }]
+      $x = MyObject()
+      notice($x.alias)
+      notice($x.begin)
+      notice($x.break)
+      notice($x.def)
+      notice($x.do)
+      notice($x.end)
+      notice($x.ensure)
+      notice($x.for)
+      notice($x.module)
+      notice($x.next)
+      notice($x.nil)
+      notice($x.not)
+      notice($x.redo)
+      notice($x.rescue)
+      notice($x.retry)
+      notice($x.return)
+      notice($x.self)
+      notice($x.super)
+      notice($x.then)
+      notice($x.until)
+      notice($x.when)
+      notice($x.while)
+      notice($x.yield)
+    PUPPET
+
+    it 'can create an instance and call all functions' do
+      expect(eval_and_collect_notices(source)).to eql([
+        'value of alias',
+        'value of begin',
+        'value of break',
+        'value of def',
+        'value of do',
+        'value of end',
+        'value of ensure',
+        'value of for',
+        'value of module',
+        'value of next',
+        'value of nil',
+        'value of not',
+        'value of redo',
+        'value of rescue',
+        'value of retry',
+        'value of return',
+        'value of self',
+        'value of super',
+        'value of then',
+        'value of until',
+        'value of when',
+        'value of while',
+        'value of yield',
+      ])
+    end
+  end
+
+  context 'when generating from Object types' do
+    let (:type_decls) { <<-CODE.unindent }
+      type MyModule::FirstGenerated = Object[{
+        attributes => {
+          name => String,
+          age  => { type => Integer, value => 30 },
+          what => { type => String, value => 'what is this', kind => constant },
+          uc_name => {
+            type => String,
+            kind => derived,
+            annotations => {
+              RubyMethod => { body => '@name.upcase' }
+            }
+          },
+          other_name => {
+            type => String,
+            kind => derived
+          },
+        },
+        functions => {
+          some_other => {
+            type => Callable[1,1]
+          },
+          name_and_age => {
+            type => Callable[1,1],
+            annotations => {
+              RubyMethod => {
+                parameters => 'joiner',
+                body => '"\#{@name}\#{joiner}\#{@age}"'
+              }
+            }
+          },
+          '[]' => {
+            type => Callable[1,1],
+            annotations => {
+              RubyMethod => {
+                parameters => 'key',
+                body => @(EOF)
+                  case key
+                  when 'name'
+                    name
+                  when 'age'
+                    age
+                  else
+                    nil
+                  end
+                |-EOF
+              }
+            }
+          }
+        }
+      }]
+      type MyModule::SecondGenerated = Object[{
+        parent => MyModule::FirstGenerated,
+        attributes => {
+          address => String,
+          zipcode => String,
+          email => String,
+          another => { type => Optional[MyModule::FirstGenerated], value => undef },
+          number => Integer,
+          aref => { type => Optional[MyModule::FirstGenerated], value => undef, kind => reference }
+        }
+      }]
+      CODE
+
+    let(:type_usage) { '' }
+    let(:source) { type_decls + type_usage }
 
     context 'when generating anonymous classes' do
 
@@ -46,11 +283,12 @@ describe 'Puppet Ruby Generator' do
       let(:second_type) { parser.parse('MyModule::SecondGenerated', loader) }
       let(:first) { generator.create_class(first_type) }
       let(:second) { generator.create_class(second_type) }
+      let(:notices) { [] }
 
       before(:each) do
-        eval_and_collect_notices(source) do |topscope|
+        notices.concat(eval_and_collect_notices(source) do |topscope|
           loader = topscope.compiler.loaders.find_loader(nil)
-        end
+        end)
       end
 
       after(:each) { typeset = nil }
@@ -78,6 +316,12 @@ describe 'Puppet Ruby Generator' do
           expect(inst.age).to eq(52)
         end
 
+        it 'created instance has a [] method' do
+          inst = first.create('Bob Builder', 52)
+          expect(inst['name']).to eq('Bob Builder')
+          expect(inst['age']).to eq(52)
+        end
+
         it 'will perform type assertion of the arguments' do
           expect { first.create('Bob Builder', '52') }.to(
             raise_error(TypeAssertionError,
@@ -103,6 +347,21 @@ describe 'Puppet Ruby Generator' do
           expect(inst.age).to eql(30)
           expect(inst.another).to be_nil
         end
+
+        it 'generates a code body for derived attribute from a RubyMethod body attribute' do
+          inst = first.create('Bob Builder', 52)
+          expect(inst.uc_name).to eq('BOB BUILDER')
+        end
+
+        it "generates a code body with 'not implemented' in the absense of a RubyMethod body attribute" do
+          inst = first.create('Bob Builder', 52)
+          expect { inst.other_name }.to raise_error(/no method is implemented for derived attribute MyModule::FirstGenerated\[other_name\]/)
+        end
+
+        it 'generates parameter list and a code body for derived function from a RubyMethod body attribute' do
+          inst = first.create('Bob Builder', 52)
+          expect(inst.name_and_age(' of age ')).to eq('Bob Builder of age 52')
+        end
       end
 
       context 'the #from_hash class method' do
@@ -137,6 +396,26 @@ describe 'Puppet Ruby Generator' do
         it 'that the TypeCalculator infers to the Object type' do
           expect(TypeCalculator.infer(first.from_hash('name' => 'Bob Builder'))).to eq(first_type)
         end
+
+        it "where attributes of kind 'reference' are not considered part of #_pcore_all_contents" do
+          inst = first.from_hash('name' => 'Bob Builder')
+          wrinst = second.create('Bob Builder', '42 Cool Street', '12345', 'bob@example.com', 23, 40, inst, inst)
+          results = []
+          wrinst._pcore_all_contents([]) { |v| results << v }
+          expect(results).to eq([inst])
+        end
+      end
+
+      context 'when used from Puppet' do
+        let(:type_usage) { <<-PUPPET.unindent }
+          $i = MyModule::FirstGenerated('Bob Builder', 52)
+          notice($i['name'])
+          notice($i['age'])
+        PUPPET
+
+        it 'The [] method is present on a created instance' do
+          expect(notices).to eql(['Bob Builder', '52'])
+        end
       end
     end
 
@@ -175,20 +454,14 @@ describe 'Puppet Ruby Generator' do
         PuppetSpec.send(:remove_const, :RubyGenerator)
       end
 
-      it 'the #_ptype class method returns a resolved Type' do
-        first_type = PuppetSpec::RubyGenerator::FirstGenerated._ptype
+      it 'the #_pcore_type class method returns a resolved Type' do
+        first_type = PuppetSpec::RubyGenerator::FirstGenerated._pcore_type
         expect(first_type).to be_a(PObjectType)
-        second_type = PuppetSpec::RubyGenerator::SecondGenerated._ptype
+        second_type = PuppetSpec::RubyGenerator::SecondGenerated._pcore_type
         expect(second_type).to be_a(PObjectType)
         expect(second_type.parent).to eql(first_type)
       end
 
-      it 'the #_plocation class method returns a file URI' do
-        loc = PuppetSpec::RubyGenerator::SecondGenerated._plocation
-        expect(loc).to be_a(URI)
-        expect(loc.to_s).to match(/^file:\/.*ruby_generator_spec.rb\?line=\d+$/)
-      end
-
       context 'the #create class method' do
         it 'has an arity that reflects optional arguments' do
           expect(PuppetSpec::RubyGenerator::FirstGenerated.method(:create).arity).to eql(-2)
@@ -336,28 +609,15 @@ describe 'Puppet Ruby Generator' do
 
       context 'the typeset' do
         it 'produces expected string representation' do
-          typeset.to_s == "TypeSet[{"+
-            "pcore_version => '1.0.0', "+
-            "name_authority => 'http://puppet.com/2016.1/runtime', "+
-            "name => 'OtherModule', "+
-            "version => '1.0.0', "+
-            "types => {"+
-            "MyFloat => Float, "+
-            "ThirdGenerated => Object[{"+
-            "attributes => {"+
-            "'first' => MyModule::FirstGenerated}}], "+
-            "FourthGenerated => Object[{"+
-            "parent => MyModule::SecondGenerated, "+
-            "attributes => {"+
-            "'complex' => {"+
-            "type => Optional[ThirdGenerated], "+
-            "value => ?}, "+
-            "'n1' => MyModule::MyInteger, "+
-            "'n2' => MyFloat}}]}, "+
-            "references => [{"+
-            "'name' => 'MyModule', "+
-            "'alias' => 'My', "+
-            "'version_range' => '1.x'}]}]"
+          expect(typeset.to_s).to eq(
+            "TypeSet[{pcore_version => '1.0.0', name_authority => 'http://puppet.com/2016.1/runtime', name => 'OtherModule', version => '1.0.0', types => {"+
+              "MyFloat => Float, "+
+              "ThirdGenerated => Object[{attributes => {'first' => My::FirstGenerated}}], "+
+              "FourthGenerated => Object[{parent => My::SecondGenerated, attributes => {"+
+                "'complex' => {type => Optional[ThirdGenerated], value => undef}, "+
+                "'n1' => My::MyInteger, "+
+                "'n2' => MyFloat"+
+              "}}]}, references => {My => {'name' => 'MyModule', 'version_range' => '1.x'}}}]")
         end
       end
 
@@ -513,20 +773,14 @@ describe 'Puppet Ruby Generator' do
         PuppetSpec.send(:remove_const, :RubyGenerator)
       end
 
-      it 'the #_ptype class method returns a resolved Type' do
-        first_type = PuppetSpec::RubyGenerator::My::FirstGenerated._ptype
+      it 'the #_pcore_type class method returns a resolved Type' do
+        first_type = PuppetSpec::RubyGenerator::My::FirstGenerated._pcore_type
         expect(first_type).to be_a(PObjectType)
-        second_type = PuppetSpec::RubyGenerator::My::SecondGenerated._ptype
+        second_type = PuppetSpec::RubyGenerator::My::SecondGenerated._pcore_type
         expect(second_type).to be_a(PObjectType)
         expect(second_type.parent).to eql(first_type)
       end
 
-      it 'the #_plocation class method returns a file URI' do
-        loc = PuppetSpec::RubyGenerator::My::SecondGenerated._plocation
-        expect(loc).to be_a(URI)
-        expect(loc.to_s).to match(/^file:\/.*ruby_generator_spec.rb\?line=\d+$/)
-      end
-
       context 'the #create class method' do
         it 'has an arity that reflects optional arguments' do
           expect(PuppetSpec::RubyGenerator::My::FirstGenerated.method(:create).arity).to eql(-2)
