@@ -5,11 +5,11 @@ require 'puppet/provider/cisco'
 
 describe Puppet::Provider::Cisco do
   it "should implement a device class method" do
-    Puppet::Provider::Cisco.should respond_to(:device)
+    expect(Puppet::Provider::Cisco).to respond_to(:device)
   end
 
   it "should create a cisco device instance" do
     Puppet::Util::NetworkDevice::Cisco::Device.expects(:new).returns :device
-    Puppet::Provider::Cisco.device(:url).should == :device
+    expect(Puppet::Provider::Cisco.device(:url)).to eq(:device)
   end
 end
