@@ -24,10 +24,10 @@ describe provider_class do
   describe "provider features" do
     subject { provider }
 
-    it { should be_installable }
-    it { should be_uninstallable }
-    it { should be_upgradeable }
-    it { should be_versionable }
+    it { is_expected.to be_installable }
+    it { is_expected.to be_uninstallable }
+    it { is_expected.to be_upgradeable }
+    it { is_expected.to be_versionable }
   end
 
   describe "when listing all instances" do
@@ -38,17 +38,17 @@ describe provider_class do
 
     it "should create instances from active ports" do
       provider_class.expects(:port).returns("foo @1.234.5_2 (active)")
-      provider_class.instances.size.should == 1
+      expect(provider_class.instances.size).to eq(1)
     end
 
     it "should ignore ports that aren't activated" do
       provider_class.expects(:port).returns("foo @1.234.5_2")
-      provider_class.instances.size.should == 0
+      expect(provider_class.instances.size).to eq(0)
     end
 
     it "should ignore variants" do
-      provider_class.parse_installed_query_line("bar @1.0beta2_38_1+x11+java (active)").
-        should == {:provider=>:macports, :revision=>"1", :name=>"bar", :ensure=>"1.0beta2_38"}
+      expect(provider_class.parse_installed_query_line("bar @1.0beta2_38_1+x11+java (active)")).
+        to eq({:provider=>:macports, :revision=>"1", :name=>"bar", :ensure=>"1.0beta2_38"})
     end
 
   end
@@ -57,7 +57,7 @@ describe provider_class do
    it "should not specify a version when ensure is set to latest" do
      resource[:ensure] = :latest
      provider.expects(:port).with { |flag, method, name, version|
-       version.should be_nil
+       expect(version).to be_nil
      }
      provider.install
    end
@@ -65,7 +65,7 @@ describe provider_class do
    it "should not specify a version when ensure is set to present" do
      resource[:ensure] = :present
      provider.expects(:port).with { |flag, method, name, version|
-       version.should be_nil
+       expect(version).to be_nil
      }
      provider.install
    end
@@ -73,7 +73,7 @@ describe provider_class do
    it "should specify a version when ensure is set to a version" do
      resource[:ensure] = "1.2.3"
      provider.expects(:port).with { |flag, method, name, version|
-       version.should be
+       expect(version).to be
      }
      provider.install
    end
@@ -95,28 +95,28 @@ describe provider_class do
     it "should return nil when the package cannot be found" do
       resource[:name] = resource_name
       provider.expects(:execute).with(infoargs, arguments).returns("")
-      provider.latest.should == nil
+      expect(provider.latest).to eq(nil)
     end
 
     it "should return the current version if the installed port has the same revision" do
       current_hash[:revision] = "2"
       provider.expects(:execute).with(infoargs, arguments).returns(new_info_line)
       provider.expects(:query).returns(current_hash)
-      provider.latest.should == current_hash[:ensure]
+      expect(provider.latest).to eq(current_hash[:ensure])
     end
 
     it "should return the new version_revision if the installed port has a lower revision" do
       current_hash[:revision] = "1"
       provider.expects(:execute).with(infoargs, arguments).returns(new_info_line)
       provider.expects(:query).returns(current_hash)
-      provider.latest.should == "1.2.3_2"
+      expect(provider.latest).to eq("1.2.3_2")
     end
 
     it "should return the newest version if the port is not installed" do
       resource[:name] = resource_name
       provider.expects(:execute).with(infoargs, arguments).returns(new_info_line)
       provider.expects(:execute).with(["/opt/local/bin/port", "-q", :installed, resource[:name]], arguments).returns("")
-      provider.latest.should == "1.2.3_2"
+      expect(provider.latest).to eq("1.2.3_2")
     end
   end
 
