@@ -21,27 +21,27 @@ describe provider_class do
 
   it "should have an install method" do
     @provider = provider_class.new
-    @provider.should respond_to(:install)
+    expect(@provider).to respond_to(:install)
   end
 
   it "should have an uninstall method" do
     @provider = provider_class.new
-    @provider.should respond_to(:uninstall)
+    expect(@provider).to respond_to(:uninstall)
   end
 
   it "should have an update method" do
     @provider = provider_class.new
-    @provider.should respond_to(:update)
+    expect(@provider).to respond_to(:update)
   end
 
   it "should have a latest method" do
     @provider = provider_class.new
-    @provider.should respond_to(:latest)
+    expect(@provider).to respond_to(:latest)
   end
 
   it "should have a install_options method" do
     @provider = provider_class.new
-    @provider.should respond_to(:install_options)
+    expect(@provider).to respond_to(:install_options)
   end
 
   describe "when installing with zypper version >= 1.0" do
@@ -115,12 +115,32 @@ describe provider_class do
   end
 
   describe "when getting latest version" do
-    it "should return a version string with valid list-updates data from SLES11sp1" do
-      fake_data = File.read(my_fixture('zypper-list-updates-SLES11sp1.out'))
+    after do described_class.reset! end
+    context "when the package has available update" do
+      it "should return a version string with valid list-updates data from SLES11sp1" do
+        fake_data = File.read(my_fixture('zypper-list-updates-SLES11sp1.out'))
+        @resource.stubs(:[]).with(:name).returns "at"
+        described_class.expects(:zypper).with("list-updates").returns fake_data
+        expect(@provider.latest).to eq("3.1.8-1069.18.2")
+      end
+    end
 
-      @resource.stubs(:[]).with(:name).returns "at"
-      @provider.expects(:zypper).with("list-updates").returns fake_data
-      @provider.latest.should == "3.1.8-1069.18.2"
+    context "when the package is in the latest version" do
+      it "should return nil with valid list-updates data from SLES11sp1" do
+        fake_data = File.read(my_fixture('zypper-list-updates-SLES11sp1.out'))
+        @resource.stubs(:[]).with(:name).returns "zypper-log"
+        described_class.expects(:zypper).with("list-updates").returns fake_data
+        expect(@provider.latest).to eq(nil)
+      end
+    end
+
+    context "when there are no updates available" do
+      it "should return nil" do
+        fake_data_empty = File.read(my_fixture('zypper-list-updates-empty.out'))
+        @resource.stubs(:[]).with(:name).returns "at"
+        described_class.expects(:zypper).with("list-updates").returns fake_data_empty
+        expect(@provider.latest).to eq(nil)
+      end
     end
   end
 
@@ -194,4 +214,18 @@ describe provider_class do
       @provider.install
     end
   end
+
+  describe 'when uninstalling' do
+    it 'should use remove to uninstall on zypper version 1.6 and above' do
+      @provider.stubs(:zypper_version).returns '1.6.308'
+      @provider.expects(:zypper).with(:remove, '--no-confirm', 'mypackage')
+      @provider.uninstall
+    end
+
+    it 'should use remove  --force-solution to uninstall on zypper versions between 1.0 and 1.6' do
+      @provider.stubs(:zypper_version).returns '1.0.2'
+      @provider.expects(:zypper).with(:remove, '--no-confirm', '--force-resolution', 'mypackage')
+      @provider.uninstall
+    end
+  end
 end
