@@ -240,7 +240,7 @@ describe Puppet::Type.type(:service).provider(:init) do
     describe "when starting a service on Solaris" do
       it "should use ctrun" do
         Facter.stubs(:value).with(:osfamily).returns 'Solaris'
-        provider.expects(:execute).with('/usr/bin/ctrun -l none /service/path/myservice start', {:failonfail => true, :override_locale => false, :squelch => false, :combine => true}).returns("")
+        provider.expects(:execute).with('/usr/bin/ctrun -l child /service/path/myservice start', {:failonfail => true, :override_locale => false, :squelch => false, :combine => true}).returns("")
         $CHILD_STATUS.stubs(:exitstatus).returns(0)
         provider.start
       end
