@@ -167,7 +167,7 @@ describe Puppet::SSL::CertificateAuthority do
       Puppet::FileSystem.expects(:exist?).with(Puppet[:capass]).returns false
 
       fh = StringIO.new
-      Puppet.settings.setting(:capass).expects(:open).with('w').yields fh
+      Puppet.settings.setting(:capass).expects(:open).with('w:ASCII').yields fh
 
       @ca.stubs(:sign)
 
@@ -795,6 +795,12 @@ describe Puppet::SSL::CertificateAuthority do
       expect(@ca.list_certificates).to eq([cert1, cert2])
     end
 
+    it "should print a deprecation when using #list_certificates" do
+      Puppet::SSL::Certificate.indirection.stubs(:search).with("*").returns [:foo, :bar]
+      Puppet.expects(:deprecation_warning).with(regexp_matches(/list_certificates is deprecated/))
+      @ca.list_certificates
+    end
+
     describe "and printing certificates" do
       it "should return nil if the certificate cannot be found" do
         Puppet::SSL::Certificate.indirection.expects(:find).with("myhost").returns nil
@@ -927,7 +933,7 @@ describe Puppet::SSL::CertificateAuthority do
           expect(@ca.certificate_is_alive?(@cert)).to be_truthy
         end
 
-        it "should used a cached instance of the x509 store" do
+        it "should use a cached instance of the x509 store" do
           OpenSSL::X509::Store.stubs(:new).returns(@store).once
 
           @cert.expects(:content).returns "mycert"
@@ -937,6 +943,11 @@ describe Puppet::SSL::CertificateAuthority do
           @ca.certificate_is_alive?(@cert)
           @ca.certificate_is_alive?(@cert)
         end
+
+        it "should be deprecated" do
+          Puppet.expects(:deprecation_warning).with(regexp_matches(/certificate_is_alive\? is deprecated/))
+          @ca.certificate_is_alive?(@cert)
+        end
       end
     end
 
@@ -1056,7 +1067,7 @@ describe "CertificateAuthority.generate" do
   end
 
   def expect_to_write_the_ca_password
-    Puppet.settings.setting(:capass).expects(:open).with('w')
+    Puppet.settings.setting(:capass).expects(:open).with('w:ASCII')
   end
 
   def expect_ca_initialization
