@@ -21,7 +21,7 @@ describe Puppet::Type.type(:computer), " when checking computer objects" do
   it "should be able to create an instance" do
     provider_class = Puppet::Type::Computer.provider(Puppet::Type::Computer.providers[0])
     Puppet::Type::Computer.expects(:defaultprovider).returns provider_class
-    computer.new(:name => "bar").should_not be_nil
+    expect(computer.new(:name => "bar")).not_to be_nil
   end
 
   properties = [:en_address, :ip_address]
@@ -29,27 +29,27 @@ describe Puppet::Type.type(:computer), " when checking computer objects" do
 
   properties.each do |property|
     it "should have a #{property} property" do
-      computer.attrclass(property).ancestors.should be_include(Puppet::Property)
+      expect(computer.attrclass(property).ancestors).to be_include(Puppet::Property)
     end
 
     it "should have documentation for its #{property} property" do
-      computer.attrclass(property).doc.should be_instance_of(String)
+      expect(computer.attrclass(property).doc).to be_instance_of(String)
     end
 
     it "should accept :absent as a value" do
       prop = computer.attrclass(property).new(:resource => @resource)
       prop.should = :absent
-      prop.should.must == :absent
+      expect(prop.should).to eq(:absent)
     end
   end
 
   params.each do |param|
     it "should have a #{param} parameter" do
-      computer.attrclass(param).ancestors.should be_include(Puppet::Parameter)
+      expect(computer.attrclass(param).ancestors).to be_include(Puppet::Parameter)
     end
 
     it "should have documentation for its #{param} parameter" do
-      computer.attrclass(param).doc.should be_instance_of(String)
+      expect(computer.attrclass(param).doc).to be_instance_of(String)
     end
   end
 
@@ -60,21 +60,21 @@ describe Puppet::Type.type(:computer), " when checking computer objects" do
     end
 
     it "should be nil for en_address" do
-      computer.new(:name => :en_address)[:en_address].should == nil
+      expect(computer.new(:name => :en_address)[:en_address]).to eq(nil)
     end
 
     it "should be nil for ip_address" do
-      computer.new(:name => :ip_address)[:ip_address].should == nil
+      expect(computer.new(:name => :ip_address)[:ip_address]).to eq(nil)
     end
   end
 
   describe "when managing the ensure property" do
     it "should support a :present value" do
-      lambda { @ensure.should = :present }.should_not raise_error
+      expect { @ensure.should = :present }.not_to raise_error
     end
 
     it "should support an :absent value" do
-      lambda { @ensure.should = :absent }.should_not raise_error
+      expect { @ensure.should = :absent }.not_to raise_error
     end
   end
 end
