@@ -3,6 +3,8 @@ require 'spec_helper'
 require 'puppet/util/http_proxy'
 
 describe Puppet::Util::HttpProxy do
+  include Puppet::Network::HTTP::Compression.module
+
   before(:all) do
     ENV['http_proxy'] = nil
     ENV['HTTP_PROXY'] = nil
@@ -213,4 +215,59 @@ describe Puppet::Util::HttpProxy do
       end
     end
   end
+
+  describe '.request_with_redirects' do
+    let(:dest) { URI.parse('http://mydomain.com/some/path') }
+    let(:http_ok) { stub('http ok', :code => 200, :message => 'HTTP OK') }
+
+    it 'generates accept and accept-encoding headers' do
+      Net::HTTP.any_instance.stubs(:head).returns(http_ok)
+      Net::HTTP.any_instance.expects(:get).with do |_, headers|
+        expect(headers)
+          .to match({'Accept' => '*/*',
+                     'Accept-Encoding' => 'gzip;q=1.0,deflate;q=0.6,identity;q=0.3',
+                     'User-Agent' => /Puppet/})
+      end.returns(http_ok)
+
+      subject.request_with_redirects(dest, :get, 0)
+    end
+
+    it 'can return a compressed response body' do
+      Net::HTTP.any_instance.stubs(:head).returns(http_ok)
+
+      compressed_body = [
+        0x1f, 0x8b, 0x08, 0x08, 0xe9, 0x08, 0x7a, 0x5a, 0x00, 0x03,
+        0x68, 0x65, 0x6c, 0x6c, 0x6f, 0x00, 0xcb, 0xc8, 0xe4, 0x02,
+        0x00, 0x7a, 0x7a, 0x6f, 0xed, 0x03, 0x00, 0x00, 0x00
+      ].pack('C*')
+
+      response = stub('http ok', :code => 200, :message => 'HTTP OK', :body => compressed_body)
+      response.stubs(:[]).with('content-encoding').returns('gzip')
+      Net::HTTP.any_instance.expects(:get).returns(response)
+
+      expect(
+        uncompress_body(subject.request_with_redirects(dest, :get, 0))
+      ).to eq("hi\n")
+    end
+
+    it 'generates accept and accept-encoding headers when a block is provided' do
+      Net::HTTP.any_instance.stubs(:head).returns(http_ok)
+      Net::HTTP.any_instance.expects(:request_get).with do |_, headers, &block|
+        expect(headers)
+          .to match({'Accept' => '*/*',
+                     'Accept-Encoding' => 'gzip;q=1.0,deflate;q=0.6,identity;q=0.3',
+                     'User-Agent' => /Puppet/})
+      end.returns(http_ok)
+
+      subject.request_with_redirects(dest, :get, 0) do
+        # unused
+      end
+    end
+
+    it 'only makes a single HEAD request' do
+      Net::HTTP.any_instance.expects(:head).with(anything, anything).returns(http_ok)
+
+      subject.request_with_redirects(dest, :head, 0)
+    end
+  end
 end
