@@ -189,7 +189,10 @@ describe Puppet::Util::Storage do
       Puppet::Util::Storage.cache(:yayness)
 
       if Puppet.features.microsoft_windows?
-        expect { Puppet::Util::Storage.store }.to raise_error(Puppet::Util::Windows::Error, /Access is denied/)
+        expect { Puppet::Util::Storage.store }.to raise_error do |error|
+          expect(error).to be_a(Puppet::Util::Windows::Error)
+          expect(error.code).to eq(5) # ERROR_ACCESS_DENIED
+        end
       else
         expect { Puppet::Util::Storage.store }.to raise_error(Errno::EISDIR, /Is a directory/)
       end
