@@ -11,15 +11,15 @@ describe UserAttr do
 
   describe "when getting attributes by name" do
     it "should return nil if there is no entry for that name" do
-      UserAttr.get_attributes_by_name('baz').should == nil
+      expect(UserAttr.get_attributes_by_name('baz')).to eq(nil)
     end
 
     it "should return a hash if there is an entry in /etc/user_attr" do
-      UserAttr.get_attributes_by_name('foo').class.should == Hash
+      expect(UserAttr.get_attributes_by_name('foo').class).to eq(Hash)
     end
 
     it "should return a hash with the name value from /etc/user_attr" do
-      UserAttr.get_attributes_by_name('foo')[:name].should == 'foo'
+      expect(UserAttr.get_attributes_by_name('foo')[:name]).to eq('foo')
     end
 
     #this test is contrived
@@ -27,19 +27,19 @@ describe UserAttr do
     #the role/normal is just a the convention of the file
     describe "when the name is a role" do
       it "should contain :type = role" do
-        UserAttr.get_attributes_by_name('foo')[:type].should == 'role'
+        expect(UserAttr.get_attributes_by_name('foo')[:type]).to eq('role')
       end
     end
 
     describe "when the name is not a role" do
       it "should contain :type = normal" do
-        UserAttr.get_attributes_by_name('bar')[:type].should == 'normal'
+        expect(UserAttr.get_attributes_by_name('bar')[:type]).to eq('normal')
       end
     end
 
     describe "when the name has more attributes" do
       it "should contain all the attributes" do
-        UserAttr.get_attributes_by_name('bar')[:profile].should == 'foobar'
+        expect(UserAttr.get_attributes_by_name('bar')[:profile]).to eq('foobar')
       end
     end
   end
