@@ -6,7 +6,7 @@ describe "Puppet::Util::Windows::RootCerts", :if => Puppet::Util::Platform.windo
   let(:x509_store) { Puppet::Util::Windows::RootCerts.instance.to_a }
 
   it "should return at least one X509 certificate" do
-    expect(x509_store.to_a).to have_at_least(1).items
+    expect(x509_store.to_a.size).to be >= 1
   end
 
   it "should return an X509 certificate with a subject" do
